@@ -222,7 +222,14 @@ static std::string get_nssdb_path() {
 #else
   std::string home_path = Glib::get_home_dir();
 #endif
+
+#if defined(_MACOSX)
+  std::string ff_home = home_path + G_DIR_SEPARATOR_S "Library" G_DIR_SEPARATOR_S "Application Support" G_DIR_SEPARATOR_S "Firefox";
+#elif defined(WIN32)
+  std::string ff_home = home_path + G_DIR_SEPARATOR_S "AppData" G_DIR_SEPARATOR_S "Roaming" G_DIR_SEPARATOR_S "Mozilla" G_DIR_SEPARATOR_S "Firefox";
+#else
   std::string ff_home = home_path + G_DIR_SEPARATOR_S ".mozilla" G_DIR_SEPARATOR_S "firefox";
+#endif
 
   struct stat st;
   if(::stat(ff_home.c_str(),&st) != 0) return std::string();
@@ -436,7 +443,7 @@ int main(int argc, char *argv[]) {
     res = AuthN::nssInit(configdir);
     std::cout<< Arc::IString("nss db to be accesses: %s\n", configdir.c_str());
 
-    char* slotpw = NULL; //"secretpw"; 
+    char* slotpw = NULL; //"secretpw";  //TODO: Input passphrase to nss db 
     //The nss db under firefox profile seems to not be protected by any passphrase by default
     bool ascii = true;
     const char* trusts = "p,p,p";
@@ -486,6 +493,11 @@ int main(int argc, char *argv[]) {
     proxy_cred_str.append(proxy_privk_str).append(eec_cert_str);
     write_proxy_file(proxy_path, proxy_cred_str);
 
+    Arc::Credential proxy_cred(proxy_path, proxy_path, "", "");
+    Arc::Time left = proxy_cred.GetEndTime();
+    std::cout << Arc::IString("Proxy generation succeeded") << std::endl;
+    std::cout << Arc::IString("Your proxy is valid until: %s", left.str(Arc::UserTime)) << std::endl;
+
     return EXIT_SUCCESS;
   }
 #endif
@@ -991,7 +1003,8 @@ int main(int argc, char *argv[]) {
 
       std::string proxy_cred_str_pem;
      
-      Arc::UserConfig usercfg_tmp(Arc::initializeCredentialsType(Arc::initializeCredentialsType::SkipCredentials));
+      Arc::initializeCredentialsType cred_type(Arc::initializeCredentialsType::SkipCredentials);
+      Arc::UserConfig usercfg_tmp(cred_type);
       usercfg_tmp.CACertificatesDirectory(usercfg.CACertificatesDirectory());
 
       Arc::CredentialStore cstore(usercfg_tmp,Arc::URL("myproxy://"+myproxy_server));
@@ -1293,13 +1306,15 @@ int main(int argc, char *argv[]) {
                 std::string tmp = str.substr(pos + tmp_str.size() + 1); 
                 std::cout << Arc::IString("The validity duration of VOMS AC is shortened from %s to %s, due to the validity constraint on voms server side.\n", voms_period, tmp);
               }
-              else
-              std::cout << Arc::IString("Cannot get any AC or attributes info from VOMS server: %s;\n       Returned message from VOMS server: %s\n", voms_server, str);
-              break; //since the voms servers with the same name should be looked as the same for robust reason, the other voms server should that can be reached could returned the same message. So we exists the loop, even if there are other backup voms server exist.
+              else {
+                std::cout << Arc::IString("Cannot get any AC or attributes info from VOMS server: %s;\n       Returned message from VOMS server: %s\n", voms_server, str);
+                break; //since the voms servers with the same name should be looked as the same for robust reason, the other voms server that can be reached could returned the same message. So we exists the loop, even if there are other backup voms server exist.
+              }
             }
-            else
+            else {
               std::cout << Arc::IString("Returned message from VOMS server %s is: %s\n", voms_server, ret_str);
-              break; 
+              break;
+            } 
           }
 
           //Put the return attribute certificate into proxy certificate as the extension part
@@ -1308,6 +1323,7 @@ int main(int argc, char *argv[]) {
             codedac = (std::string)(node["bitstr"]);
           else
             codedac = (std::string)(node["ac"]);
+
           std::string decodedac;
           int size;
           char *dec = NULL;
