@@ -16,10 +16,13 @@ namespace Arc
   ApelDestination::ApelDestination(JobLogFile& joblog):
     logger(Arc::Logger::rootLogger, "JURA.ApelDestination"),
     urn(0),
-    sequence(0)
+    sequence(0),
+    usagerecordset(Arc::NS("","http://eu-emi.eu/namespaces/2012/10/computerecord"),
+                   "UsageRecords")
+
   {
     //Get service URL, cert, key, CA path from job log file
-    std::string serviceurl=joblog["loggerurl"];
+    std::string serviceurl=joblog["loggerurl"].substr(5);
     topic=joblog["topic"];
     output_dir=joblog["outputdir"];
     std::string certfile=joblog["certificate_path"];
@@ -87,12 +90,10 @@ namespace Arc
         joblogs.push_back(joblog);
         //Create UR if can
         Arc::XMLNode usagerecord(Arc::NS(), "");
-        joblog.createUsageRecord(usagerecord);
+        joblog.createCARUsageRecord(usagerecord);
         if (usagerecord)
           {
-            std::map<std::string, std::string> usagerecord_apel;
-            XML2KeyValue(usagerecord, usagerecord_apel);
-            usagerecordset_apel.push_back(usagerecord_apel);
+            usagerecordset.NewChild(usagerecord);
             ++urn;
           }
         else
@@ -118,14 +119,7 @@ namespace Arc
   int ApelDestination::submit_batch()
   {
     std::string urstr;
-    urstr = "APEL-individual-job-message: v0.2\n";
-    std::map<std::string,std::string>::iterator it;
-    for (int i=0; i<(int)usagerecordset_apel.size(); i++){
-        for ( it=usagerecordset_apel[i].begin() ; it != usagerecordset_apel[i].end(); it++ ){
-            urstr += (*it).first + ": " + (*it).second + "\n";
-        }
-        urstr += "%%\n";
-    }
+    usagerecordset.GetDoc(urstr,false);
 
     logger.msg(Arc::INFO, 
                "Logging UR set of %d URs.",
@@ -254,6 +248,12 @@ namespace Arc
     // Ubuntu/Debian: /usr/lib/arc/ssm_master
     ssm_pathes.push_back("/usr/lib/arc/"+exec_cmd);
     ssm_pathes.push_back("/usr/local/lib/arc/"+exec_cmd);
+
+    // If you don't use non-standard prefix for a compilation you will 
+    // use this extra location.
+    std::ostringstream prefix;
+    prefix << INSTPREFIX << "/" << PKGLIBEXECSUBDIR << "/";
+    ssm_pathes.push_back(prefix.str()+exec_cmd);
     
     // Find the location of the ssm_master
     std::string ssm_command = "./ssm/"+exec_cmd;
@@ -297,7 +297,12 @@ namespace Arc
   {
     urn=0;
     joblogs.clear();
-    usagerecordset_apel.clear();
+    usagerecordset.Replace(
+        Arc::XMLNode(Arc::NS("",
+                             "http://eu-emi.eu/namespaces/2012/10/computerecord"
+                            ),
+                     "UsageRecords")
+                    );
   }
 
   ApelDestination::~ApelDestination()
