@@ -52,12 +52,14 @@ namespace Arc {
     : client(NULL),
       rurl(url),
       cfg(cfg),
+      timeout(timeout),
       arex_enabled(arex_extensions) {
 
     logger.msg(DEBUG, "Creating an A-REX client");
     client = new ClientSOAP(cfg, url, timeout);
-    if (!client)
+    if (!client) {
       logger.msg(VERBOSE, "Unable to create SOAP client used by AREXClient.");
+    }
     if(arex_enabled) {
       set_arex_namespaces(arex_ns);
     } else {
@@ -105,7 +107,23 @@ namespace Arc {
     return true;
   }
 
-  bool AREXClient::process(PayloadSOAP& req, bool delegate, XMLNode& response) {
+  bool AREXClient::reconnect(void) {
+    delete client; client = NULL;
+    logger.msg(DEBUG, "Re-creating an A-REX client");
+    client = new ClientSOAP(cfg, rurl, timeout);
+    if (!client) {
+      logger.msg(VERBOSE, "Unable to create SOAP client used by AREXClient.");
+      return false;
+    }
+    if(arex_enabled) {
+      set_arex_namespaces(arex_ns);
+    } else {
+      set_bes_namespaces(arex_ns);
+    }
+    return true;
+  }
+
+  bool AREXClient::process(PayloadSOAP& req, bool delegate, XMLNode& response, bool retry) {
     if (!client) {
       logger.msg(VERBOSE, "AREXClient was not created properly."); // Should not happen. Happens if client = null (out of memory?)
       return false;
@@ -115,7 +133,16 @@ namespace Arc {
 
     if (delegate) {
       XMLNode op = req.Child(0);
-      if(!delegation(op)) return false;
+      if(!delegation(op)) {
+        delete client; client = NULL;
+        // TODO: better way to check of retriable.
+        if(!retry) return false;
+        if(!reconnect()) return false;
+        if(!delegation(op)) {
+          delete client; client = NULL;
+          return false;
+        }
+      }
     }
 
     WSAHeader header(req);
@@ -123,25 +150,35 @@ namespace Arc {
     PayloadSOAP* resp = NULL;
     if (!client->process(header.Action(), &req, &resp)) {
       logger.msg(VERBOSE, "%s request failed", action);
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false;
+      if(!reconnect()) return false;
+      return process(req,false,response,false);
     }
 
     if (resp == NULL) {
       logger.msg(VERBOSE, "No response from %s", rurl.str());
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false;
+      if(!reconnect()) return false;
+      return process(req,false,response,false);
     }
 
     if (resp->IsFault()) {
       logger.msg(VERBOSE, "%s request to %s failed with response: %s", action, rurl.str(), resp->Fault()->Reason());
+      if(resp->Fault()->Code() != SOAPFault::Receiver) retry = false;
       std::string s;
       resp->GetXML(s);
       logger.msg(DEBUG, "XML response: %s", s);
       delete resp;
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false;
+      if(!reconnect()) return false;
+      return process(req,false,response,false);
     }
 
     if (!(*resp)[action + "Response"]) {
-      logger.msg(VERBOSE, "%s request to %s failed. Empty response.", action, rurl.str());
+      logger.msg(VERBOSE, "%s request to %s failed. No expected response.", action, rurl.str());
       delete resp;
       return false;
     }
@@ -479,4 +516,44 @@ namespace Arc {
     id.NewChild("wsa:ReferenceParameters").NewChild("a-rex:JobID") = pi.Rest();
     id.GetXML(activityIdentifier);
   }
+
+// -----------------------------------------------------------------------------
+
+  // TODO: does it need locking?
+
+  AREXClients::AREXClients(const UserConfig& usercfg):usercfg_(usercfg) {
+  }
+
+  AREXClients::~AREXClients(void) {
+    std::multimap<URL, AREXClient*>::iterator it;
+    for (it = clients_.begin(); it != clients_.end(); it = clients_.begin()) {
+      delete it->second;
+    }
+  }
+
+  AREXClient* AREXClients::acquire(const URL& url, bool arex_features) {
+    std::multimap<URL, AREXClient*>::iterator it = clients_.find(url);
+    if ( it != clients_.end() ) {
+      // If AREXClient is already existing for the
+      // given URL then return with that
+      AREXClient* client = it->second;
+      client->arexFeatures(arex_features);
+      clients_.erase(it);
+      return client;
+    }
+    // Else create a new one and return with that
+    MCCConfig cfg;
+    usercfg_.ApplyToConfig(cfg);
+    AREXClient* client = new AREXClient(url, cfg, usercfg_.Timeout(), arex_features);
+    return client;
+  }
+
+  void AREXClients::release(AREXClient* client) {
+    if(!client) return;
+    if(!*client) return;
+    // TODO: maybe strip path from URL?
+    clients_.insert(std::pair<URL, AREXClient*>(client->url(),client));
+  }
+
 }
+
