@@ -14,13 +14,19 @@
 #include <arc/data/DataHandle.h>
 #include <arc/data/URLMap.h>
 #include <arc/message/MCC.h>
+#include <arc/Utils.h>
 
 #include "AREXClient.h"
 #include "JobControllerPluginARC1.h"
+#include "JobStateARC1.h"
 
 namespace Arc {
 
   Logger JobControllerPluginARC1::logger(Logger::getRootLogger(), "JobControllerPlugin.ARC1");
+  
+  URL JobControllerPluginARC1::GetAddressOfResource(const Job& job) {
+    return URL(XMLNode(job.IDFromEndpoint)["Address"]); 
+  }
 
   bool JobControllerPluginARC1::isEndpointNotSupported(const std::string& endpoint) const {
     const std::string::size_type pos = endpoint.find("://");
@@ -28,57 +34,57 @@ namespace Arc {
   }
 
   void JobControllerPluginARC1::UpdateJobs(std::list<Job*>& jobs, std::list<URL>& IDsProcessed, std::list<URL>& IDsNotProcessed, bool isGrouped) const {
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
-
     for (std::list<Job*>::iterator it = jobs.begin(); it != jobs.end(); ++it) {
-      AREXClient ac((*it)->Cluster, cfg, usercfg.Timeout());
+      AutoPointer<AREXClient> ac(((AREXClients&)clients).acquire(GetAddressOfResource(**it), true));
       std::string idstr;
       AREXClient::createActivityIdentifier((*it)->JobID, idstr);
-      if (!ac.stat(idstr, **it)) {
+      if (!ac->stat(idstr, **it)) {
         logger.msg(WARNING, "Job information not found in the information system: %s", (*it)->JobID.fullstr());
         IDsNotProcessed.push_back((*it)->JobID);
+        ((AREXClients&)clients).release(ac.Release());
         continue;
       }
       IDsProcessed.push_back((*it)->JobID);
+      ((AREXClients&)clients).release(ac.Release());
     }
   }
 
   bool JobControllerPluginARC1::CleanJobs(const std::list<Job*>& jobs, std::list<URL>& IDsProcessed, std::list<URL>& IDsNotProcessed, bool isGrouped) const {
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
     bool ok = true;
     for (std::list<Job*>::const_iterator it = jobs.begin(); it != jobs.end(); ++it) {
       Job& job = **it;
-      AREXClient ac(job.Cluster, cfg, usercfg.Timeout());
+      AutoPointer<AREXClient> ac(((AREXClients&)clients).acquire(GetAddressOfResource(job), true));
       std::string idstr;
       AREXClient::createActivityIdentifier(job.JobID, idstr);
-      if (!ac.clean(idstr)) {
+      if (!ac->clean(idstr)) {
         ok = false;
         IDsNotProcessed.push_back(job.JobID);
+        ((AREXClients&)clients).release(ac.Release());
         continue;
       }
       IDsProcessed.push_back(job.JobID);
+      ((AREXClients&)clients).release(ac.Release());
     }
     
     return ok;
   }
 
   bool JobControllerPluginARC1::CancelJobs(const std::list<Job*>& jobs, std::list<URL>& IDsProcessed, std::list<URL>& IDsNotProcessed, bool isGrouped) const {
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
     bool ok = true;
     for (std::list<Job*>::const_iterator it = jobs.begin(); it != jobs.end(); ++it) {
       Job& job = **it;
-      AREXClient ac(job.Cluster, cfg, usercfg.Timeout());
+      AutoPointer<AREXClient> ac(((AREXClients&)clients).acquire(GetAddressOfResource(job), true));
       std::string idstr;
       AREXClient::createActivityIdentifier(job.JobID, idstr);
-      if (!ac.kill(idstr)) {
+      if (!ac->kill(idstr)) {
         ok = false;
         IDsNotProcessed.push_back(job.JobID);
+        ((AREXClients&)clients).release(ac.Release());
         continue;
       }
+      job.State = JobStateARC1("killed");
       IDsProcessed.push_back(job.JobID);
+      ((AREXClients&)clients).release(ac.Release());
     }
     
     return ok;
@@ -93,8 +99,6 @@ namespace Arc {
   }
 
   bool JobControllerPluginARC1::ResumeJobs(const std::list<Job*>& jobs, std::list<URL>& IDsProcessed, std::list<URL>& IDsNotProcessed, bool isGrouped) const {
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
     bool ok = true;
     for (std::list<Job*>::const_iterator it = jobs.begin(); it != jobs.end(); ++it) {
       Job& job = **it;
@@ -107,16 +111,18 @@ namespace Arc {
   
       logger.msg(VERBOSE, "Resuming job: %s at state: %s (%s)", job.JobID.fullstr(), job.RestartState.GetGeneralState(), job.RestartState());
   
-      AREXClient ac(job.Cluster, cfg, usercfg.Timeout());
+      AutoPointer<AREXClient> ac(((AREXClients&)clients).acquire(GetAddressOfResource(job), true));
       std::string idstr;
       AREXClient::createActivityIdentifier(job.JobID, idstr);
-      if (!ac.resume(idstr)) {
+      if (!ac->resume(idstr)) {
         ok = false;
         IDsNotProcessed.push_back(job.JobID);
+        ((AREXClients&)clients).release(ac.Release());
         continue;
       }
 
       IDsProcessed.push_back(job.JobID);
+      ((AREXClients&)clients).release(ac.Release());
       logger.msg(VERBOSE, "Job resuming successful");
     }
     
@@ -153,15 +159,17 @@ namespace Arc {
   bool JobControllerPluginARC1::GetJobDescription(const Job& job, std::string& desc_str) const {
     MCCConfig cfg;
     usercfg.ApplyToConfig(cfg);
-    AREXClient ac(job.Cluster, cfg, usercfg.Timeout());
+    AutoPointer<AREXClient> ac(((AREXClients&)clients).acquire(GetAddressOfResource(job), true));
     std::string idstr;
     AREXClient::createActivityIdentifier(job.JobID, idstr);
-    if (ac.getdesc(idstr, desc_str)) {
+    if (ac->getdesc(idstr, desc_str)) {
       std::list<JobDescription> descs;
       if (JobDescription::Parse(desc_str, descs) && !descs.empty()) {
+        ((AREXClients&)clients).release(ac.Release());
         return true;
       }
     }
+    ((AREXClients&)clients).release(ac.Release());
 
     logger.msg(ERROR, "Failed retrieving job description for job: %s", job.JobID.fullstr());
     return false;
