@@ -5,11 +5,13 @@
 
 #include <arc/client/JobControllerPlugin.h>
 
+#include "AREXClient.h"
+
 namespace Arc {
 
   class JobControllerPluginARC1 : public JobControllerPlugin {
   public:
-    JobControllerPluginARC1(const UserConfig& usercfg, PluginArgument* parg) : JobControllerPlugin(usercfg, parg) { supportedInterfaces.push_back("org.nordugrid.xbes"); }
+    JobControllerPluginARC1(const UserConfig& usercfg, PluginArgument* parg) : JobControllerPlugin(usercfg, parg),clients(this->usercfg) { supportedInterfaces.push_back("org.nordugrid.xbes"); }
     ~JobControllerPluginARC1() {}
 
     static Plugin* Instance(PluginArgument *arg) {
@@ -30,7 +32,9 @@ namespace Arc {
     virtual bool GetJobDescription(const Job& job, std::string& desc_str) const;
 
   private:
+    static URL GetAddressOfResource(const Job& job);
     static Logger logger;
+    AREXClients clients;
   };
 
 } // namespace Arc
