@@ -69,7 +69,8 @@ namespace Arc {
                          int timeout)
     : client(NULL),
       rurl(url),
-      cfg(cfg) {
+      cfg(cfg),
+      timeout(timeout) {
 
     logger.msg(DEBUG, "Creating an EMI ES client");
     client = new ClientSOAP(cfg, url, timeout);
@@ -130,7 +131,19 @@ namespace Arc {
     return true;
   }
 
-  bool EMIESClient::process(PayloadSOAP& req, bool delegate, XMLNode& response) {
+   bool EMIESClient::reconnect(void) { 
+    delete client; client = NULL; 
+    logger.msg(DEBUG, "Re-creating an EMI ES client");
+    client = new ClientSOAP(cfg, rurl, timeout);
+    if (!client) {
+      logger.msg(VERBOSE, "Unable to create SOAP client used by EMIESClient.");
+      return false;
+    }
+    set_namespaces(ns);
+    return true; 
+  } 
+
+  bool EMIESClient::process(PayloadSOAP& req, bool delegate, XMLNode& response, bool retry) {
     if (!client) {
       logger.msg(VERBOSE, "EMIESClient was not created properly.");
       return false;
@@ -140,7 +153,16 @@ namespace Arc {
 
     if (delegate) {
       XMLNode op = req.Child(0);
-      if(!delegation(op)) return false;
+      if(!delegation(op)) {
+        delete client; client = NULL;
+        // TODO: better way to check of retriable. 
+        if(!retry) return false; 
+        if(!reconnect()) return false; 
+        if(!delegation(op)) {
+          delete client; client = NULL;
+          return false; 
+        }
+      }
     }
 
     std::string action = req.Child(0).Name();
@@ -148,25 +170,35 @@ namespace Arc {
     PayloadSOAP* resp = NULL;
     if (!client->process(&req, &resp)) {
       logger.msg(VERBOSE, "%s request failed", req.Child(0).FullName());
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false; 
+      if(!reconnect()) return false; 
+      return process(req,false,response,false);
     }
 
     if (resp == NULL) {
       logger.msg(VERBOSE, "No response from %s", rurl.str());
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false; 
+      if(!reconnect()) return false; 
+      return process(req,false,response,false);
     }
 
     if (resp->IsFault()) {
       logger.msg(VERBOSE, "%s request to %s failed with response: %s", req.Child(0).FullName(), rurl.str(), resp->Fault()->Reason());
+      if(resp->Fault()->Code() != SOAPFault::Receiver) retry = false;
       std::string s;
       resp->GetXML(s);
       logger.msg(DEBUG, "XML response: %s", s);
       delete resp;
-      return false;
+      delete client; client = NULL;
+      if(!retry) return false; 
+      if(!reconnect()) return false; 
+      return process(req,false,response,false);
     }
 
     if (!(*resp)[action + "Response"]) {
-      logger.msg(VERBOSE, "%s request to %s failed. Empty response.", action, rurl.str());
+      logger.msg(VERBOSE, "%s request to %s failed. No expected response.", action, rurl.str());
       delete resp;
       return false;
     }
@@ -659,6 +691,42 @@ namespace Arc {
     return id.empty();
   }
 
+// -----------------------------------------------------------------------------
+
+  // TODO: does it need locking?
+
+  EMIESClients::EMIESClients(const UserConfig& usercfg):usercfg_(usercfg) {
+  }
+
+  EMIESClients::~EMIESClients(void) {
+    std::multimap<URL, EMIESClient*>::iterator it;
+    for (it = clients_.begin(); it != clients_.end(); it = clients_.begin()) {
+      delete it->second;
+    }
+  }
+
+  EMIESClient* EMIESClients::acquire(const URL& url) {
+    std::multimap<URL, EMIESClient*>::iterator it = clients_.find(url);
+    if ( it != clients_.end() ) {
+      // If EMIESClient is already existing for the
+      // given URL then return with that
+      EMIESClient* client = it->second;
+      clients_.erase(it);
+      return client;
+    }
+    // Else create a new one and return with that
+    MCCConfig cfg;
+    usercfg_.ApplyToConfig(cfg);
+    EMIESClient* client = new EMIESClient(url, cfg, usercfg_.Timeout());
+    return client;
+  }
+
+  void EMIESClients::release(EMIESClient* client) {
+    if(!client) return;
+    if(!*client) return;
+    // TODO: maybe strip path from URL?
+    clients_.insert(std::pair<URL, EMIESClient*>(client->url(),client));
+  }
 
 }
 
