@@ -9,6 +9,7 @@
 #include <arc/XMLNode.h>
 #include <arc/DateTime.h>
 #include <arc/message/MCC.h>
+#include <arc/UserConfig.h>
 /*
 #include <utility>
 
@@ -114,6 +115,14 @@ namespace Arc {
      */
     ~EMIESClient();
 
+    operator bool(void) {
+      return (client != NULL);
+    }
+
+    bool operator!(void) {
+      return (client == NULL);
+    }
+
     //! Submit a job.
     /*! This method submits a job to the EM IES service corresponding
        to this client instance. It does not do data staging.
@@ -197,10 +206,16 @@ namespace Arc {
       return client;
     }
 
+    const URL& url(void) {
+      return rurl;
+    }
+
     bool delegation(XMLNode& operation);
 
   private:
-    bool process(PayloadSOAP& req, bool delegate, XMLNode& response);
+    bool process(PayloadSOAP& req, bool delegate, XMLNode& response, bool retry = true);
+
+    bool reconnect();
 
     bool dosimple(const std::string& action, const std::string& id);
 
@@ -215,6 +230,8 @@ namespace Arc {
 
     const MCCConfig cfg;
 
+    int timeout;
+
     //! A logger for the A-REX client.
     /*! This is a logger to which all logging messages from the EMI ES
        client are sent.
@@ -222,6 +239,16 @@ namespace Arc {
     static Logger logger;
   };
 
+  class EMIESClients {
+    std::multimap<URL, EMIESClient*> clients_;
+    const UserConfig& usercfg_;
+  public:
+    EMIESClients(const UserConfig& usercfg);
+    ~EMIESClients(void);
+    EMIESClient* acquire(const URL& url);
+    void release(EMIESClient* client);
+  };
+
 }
 
 #endif
