@@ -10,10 +10,11 @@ namespace Arc {
   class JobStateEMIES
     : public JobState {
   public:
-    JobStateEMIES(const std::string& state): JobState(state, &StateMap) {}
+    JobStateEMIES(const std::string& state): JobState(state, &StateMapS) {}
     // TODO: extremely suboptimal
-    JobStateEMIES(XMLNode state): JobState(xml_to_string(state), &StateMap) {}
-    static JobState::StateType StateMap(const std::string& state);
+    JobStateEMIES(XMLNode state): JobState(xml_to_string(state), &StateMapX) {}
+    static JobState::StateType StateMapS(const std::string& state);
+    static JobState::StateType StateMapX(const std::string& state);
     static JobState::StateType StateMapInt(const EMIESJobState& st);
   private:
     std::string xml_to_string(XMLNode xml) {
