@@ -358,7 +358,7 @@ namespace Arc {
 
     // XMLNode AccessControl;
     if (bool(xmlApplication["AccessControl"]))
-      xmlApplication["AccessControl"][0].New(job.Application.AccessControl);
+      xmlApplication["AccessControl"].Child().New(job.Application.AccessControl);
 
     if (bool(xmlApplication["DryRun"]) && lower((std::string)xmlApplication["DryRun"]) == "yes") {
       job.Application.DryRun = true;
@@ -451,8 +451,8 @@ namespace Arc {
 
     // Range<int> IndividualWallTime;
     if (bool(resource["IndividualWallTime"]["Value"])) {
-      parseRange<int>(resource["IndividualWallTime"]["Value"], job.Resources.IndividualWallTime.range, -1);
-      parseBenchmark(resource["IndividualCPUTime"], job.Resources.IndividualWallTime.benchmark);
+      parseRange<int>(resource["IndividualWallTime"]["Value"], job.Resources.TotalWallTime.range, -1);
+      parseBenchmark(resource["IndividualCPUTime"], job.Resources.TotalWallTime.benchmark);
     }
 
     // Range<int> TotalWallTime;
@@ -479,8 +479,10 @@ namespace Arc {
     else if (bool(resource["FileSystem"]["DiskSpace"])) {
       Range<long long int> diskspace = -1;
       parseRange<long long int>(resource["FileSystem"]["DiskSpace"], diskspace, -1);
-      if (diskspace > -1) {
+      if (diskspace.max > -1) {
         job.Resources.DiskSpaceRequirement.DiskSpace.max = diskspace.max/(1024*1024);
+      }
+      if (diskspace.min > -1) {
         job.Resources.DiskSpaceRequirement.DiskSpace.min = diskspace.min/(1024*1024);
       }
     }
