@@ -187,6 +187,35 @@ namespace Arc {
     return true;
   }
 
+  bool XRSLParser::ParseGridTimeAttribute(JobDescription& j) { // Must be called after the 'count' attribute has been parsed.
+    std::map<std::string, std::string>::iterator itAtt;
+    itAtt = j.OtherAttributes.find("nordugrid:xrsl;gridtime");
+
+    if (itAtt == j.OtherAttributes.end()) {
+      return true;
+    }
+
+    if (j.Resources.TotalCPUTime.range.max != -1) {
+      logger.msg(ERROR, "The XRSL attributes gridtime and cputime cannot be specified together.");
+      return false;
+    }
+    if (j.Resources.TotalWallTime.range.max != -1) {
+      logger.msg(ERROR, "The XRSL attributes gridtime and walltime cannot be specified together.");
+      return false;
+    }
+
+    j.Resources.TotalCPUTime.range = Period(itAtt->second, PeriodMinutes).GetPeriod();
+    j.Resources.TotalCPUTime.benchmark = std::pair<std::string, double>("clock rate", 2800);
+
+    int slots = (j.Resources.SlotRequirement.NumberOfSlots > 0 ? j.Resources.SlotRequirement.NumberOfSlots : 1);
+    j.Resources.TotalWallTime.range = Period(itAtt->second, PeriodMinutes).GetPeriod()*slots;
+    j.Resources.TotalWallTime.benchmark = std::pair<std::string, double>("clock rate", 2800);
+
+    j.OtherAttributes.erase(itAtt);
+    
+    return true;
+  }
+
   JobDescriptionParserResult XRSLParser::Parse(const std::string& source, std::list<JobDescription>& jobdescs, const std::string& language, const std::string& dialect) const {
     if (language != "" && !IsLanguageSupported(language)) {
       return false;
@@ -227,6 +256,9 @@ namespace Arc {
       if (dialect != "GRIDMANAGER" && !ParseJoinAttribute(jobdescs.back())) { // join is a client side attribute
         return false;
       }
+      if (dialect != "GRIDMANAGER" && !ParseGridTimeAttribute(jobdescs.back())) { // gridtime is a client side attribute
+        return false;
+      }
       for (std::list<JobDescription>::iterator itJob = jobdescs.back().GetAlternatives().begin();
            itJob != jobdescs.back().GetAlternatives().end(); itJob++) {
         if (!ParseExecutablesAttribute(*itJob)) {
@@ -241,11 +273,20 @@ namespace Arc {
         if (dialect != "GRIDMANAGER" && !ParseJoinAttribute(*itJob)) { // join is a client side attribute
           return false;
         }
+        if (dialect != "GRIDMANAGER" && !ParseGridTimeAttribute(*itJob)) { // gridtime is a client side attribute
+          return false;
+        }
       }
 
       std::stringstream ss;
       ss << **it;
       jobdescs.back().OtherAttributes["nordugrid:xrsl;clientxrsl"] = ss.str();
+      SourceLanguage(jobdescs.back()) = (!language.empty() ? language : supportedLanguages.front());
+      for (std::list<JobDescription>::iterator itAltJob = jobdescs.back().GetAlternatives().begin();
+         itAltJob != jobdescs.back().GetAlternatives().end(); ++itAltJob) {
+        itAltJob->OtherAttributes["nordugrid:xrsl;clientxrsl"] = ss.str();
+        SourceLanguage(*itAltJob) = jobdescs.back().GetSourceLanguage();
+      }
     }
 
     if(jobdescs.empty()) {
@@ -273,8 +314,6 @@ namespace Arc {
           return false;
         }
       }
-
-      SourceLanguage(jobdescs.front()) = (!language.empty() ? language : supportedLanguages.front());
     }
     else {
       // action is not expected in client side job request
@@ -287,7 +326,6 @@ namespace Arc {
           jobdescs.clear();
           return false;
         }
-        SourceLanguage(*it) = (!language.empty() ? language : supportedLanguages.front());
       }
     }
 
@@ -824,18 +862,16 @@ namespace Arc {
         std::string time;
         if (!SingleValue(c, time))
           return false;
-        if(dialect == "GRIDMANAGER") {
-          j.Resources.TotalCPUTime.range = Period(time, PeriodSeconds).GetPeriod();
-        } else {
-          j.Resources.TotalCPUTime.range = Period(time, PeriodMinutes).GetPeriod();
-          for (std::list<JobDescription>::iterator it = j.GetAlternatives().begin();
-               it != j.GetAlternatives().end(); it++) {
-            it->Resources.TotalCPUTime.range = j.Resources.TotalCPUTime.range;
-            it->Resources.TotalCPUTime.benchmark = std::pair<std::string, double>("clock rate", 2800);
-          }
+
+        /* Store value in the OtherAttributes member and set it later when all
+         * the attributes it depends on has been parsed.
+         */
+        j.OtherAttributes["nordugrid:xrsl;gridtime"] = time;
+        for (std::list<JobDescription>::iterator it = j.GetAlternatives().begin();
+             it != j.GetAlternatives().end(); it++) {
+          it->OtherAttributes["nordugrid:xrsl;gridtime"] = time;
         }
 
-        j.Resources.TotalCPUTime.benchmark = std::pair<std::string, double>("clock rate", 2800);
         return true;
       }
 
@@ -991,8 +1027,13 @@ namespace Arc {
         std::string acl;
         if (!SingleValue(c, acl))
           return false;
-        XMLNode node(acl);
 
+        XMLNode node(acl);
+        if (!node) {
+          logger.msg(ERROR, "The value of the acl XRSL attribute isn't valid XML.");
+          return false;
+        }
+        
         node.New(j.Application.AccessControl);
         for (std::list<JobDescription>::iterator it = j.GetAlternatives().begin();
              it != j.GetAlternatives().end(); it++) {
@@ -1150,10 +1191,10 @@ namespace Arc {
         std::string count;
         if (!SingleValue(c, count))
           return false;
-        j.Resources.SlotRequirement.SlotsPerHost = stringtoi(count);
+        j.Resources.SlotRequirement.NumberOfSlots = stringtoi(count);
         for (std::list<JobDescription>::iterator it = j.GetAlternatives().begin();
-             it != j.GetAlternatives().end(); it++) {
-          it->Resources.SlotRequirement.SlotsPerHost = j.Resources.SlotRequirement.SlotsPerHost;
+             it != j.GetAlternatives().end(); ++it) {
+          it->Resources.SlotRequirement.NumberOfSlots = j.Resources.SlotRequirement.NumberOfSlots;
         }
         return true;
       }
@@ -1607,9 +1648,9 @@ namespace Arc {
       r.Add(new RSLCondition("architecture", RSLEqual, l));
     }
 
-    if (j.Resources.SlotRequirement.SlotsPerHost > -1) {
+    if (j.Resources.SlotRequirement.NumberOfSlots > -1) {
       RSLList *l = new RSLList;
-      l->Add(new RSLLiteral(tostring(j.Resources.SlotRequirement.SlotsPerHost)));
+      l->Add(new RSLLiteral(tostring(j.Resources.SlotRequirement.NumberOfSlots)));
       r.Add(new RSLCondition("count", RSLEqual, l));
     }
 
@@ -1634,7 +1675,7 @@ namespace Arc {
     if (j.Application.AccessControl) {
       RSLList *l = new RSLList;
       std::string acl;
-      j.Application.AccessControl.GetXML(acl, true);
+      j.Application.AccessControl.GetXML(acl, false);
       l->Add(new RSLLiteral(acl));
       r.Add(new RSLCondition("acl", RSLEqual, l));
     }
