@@ -27,6 +27,8 @@ class ARCJSDLParserTest
   CPPUNIT_TEST(TestURIOptionsOutput);
   CPPUNIT_TEST(TestQueue);
   CPPUNIT_TEST(TestDryRun);
+  CPPUNIT_TEST(TestAccessControl);
+  CPPUNIT_TEST(TestBasicJSDLCompliance);
   CPPUNIT_TEST(TestPOSIXCompliance);
   CPPUNIT_TEST(TestHPCCompliance);
   CPPUNIT_TEST_SUITE_END();
@@ -46,6 +48,8 @@ public:
   void TestURIOptionsOutput();
   void TestQueue();
   void TestDryRun();
+  void TestAccessControl();
+  void TestBasicJSDLCompliance();
   void TestPOSIXCompliance();
   void TestHPCCompliance();
 
@@ -193,7 +197,8 @@ void ARCJSDLParserTest::TestOutputFileServiceStageable() {
 
 void ARCJSDLParserTest::TestURIOptionsInput() {
   std::string jsdl = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
   "<JobDescription>"
     "<Application>"
       "<posix-jsdl:POSIXApplication>"
@@ -222,7 +227,8 @@ void ARCJSDLParserTest::TestURIOptionsInput() {
 
 void ARCJSDLParserTest::TestURIOptionsOutput() {
   std::string jsdl = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
   "<JobDescription>"
     "<Application>"
       "<posix-jsdl:POSIXApplication>"
@@ -269,7 +275,8 @@ void ARCJSDLParserTest::TestURIOptionsOutput() {
 
 void ARCJSDLParserTest::TestQueue() {
   std::string jsdl = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
 "<JobDescription>"
 "<Application>"
 "<posix-jsdl:POSIXApplication>"
@@ -296,7 +303,8 @@ void ARCJSDLParserTest::TestQueue() {
   CPPUNIT_ASSERT_EQUAL(0, (int)OUTJOBS.front().GetAlternatives().size());
 
   jsdl = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
 "<JobDescription>"
 "<Application>"
 "<posix-jsdl:POSIXApplication>"
@@ -380,12 +388,93 @@ void ARCJSDLParserTest::TestDryRun() {
   CPPUNIT_ASSERT_EQUAL(0, (int)OUTJOBS.front().GetAlternatives().size());
 }
 
+void ARCJSDLParserTest::TestAccessControl() {
+  std::string jsdl = "<?xml version=\"1.0\"?>"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDescription>"
+"<Application>"
+"<Executable>"
+"<Path>executable</Path>"
+"</Executable>"
+"<AccessControl>"
+"<gacl version=\"0.0.1\">"
+"<entry>"
+"<any-user></any-user>"
+"<allow>"
+"<write/>"
+"<read/>"
+"<list/>"
+"<admin/>"
+"</allow>"
+"</entry>"
+"</gacl>"
+"</AccessControl>"
+"</Application>"
+"</JobDescription>"
+"</JobDefinition>";
+
+  CPPUNIT_ASSERT_MESSAGE(MESSAGE, PARSER.Parse(jsdl, OUTJOBS));
+  CPPUNIT_ASSERT_EQUAL(1, (int)OUTJOBS.size());
+
+  CPPUNIT_ASSERT(OUTJOBS.front().Application.AccessControl);
+  CPPUNIT_ASSERT_EQUAL((std::string)"gacl", OUTJOBS.front().Application.AccessControl.Name());
+  CPPUNIT_ASSERT_EQUAL(1, OUTJOBS.front().Application.AccessControl.Size());
+  CPPUNIT_ASSERT_EQUAL((std::string)"entry", OUTJOBS.front().Application.AccessControl.Child().Name());
+  
+  std::string tempjobdesc;
+  CPPUNIT_ASSERT_MESSAGE(MESSAGE, PARSER.UnParse(OUTJOBS.front(), tempjobdesc, "nordugrid:jsdl"));
+  OUTJOBS.clear();
+
+  CPPUNIT_ASSERT_MESSAGE(MESSAGE, PARSER.Parse(tempjobdesc, OUTJOBS));
+  CPPUNIT_ASSERT_EQUAL(1, (int)OUTJOBS.size());
+
+  CPPUNIT_ASSERT(OUTJOBS.front().Application.AccessControl);
+  CPPUNIT_ASSERT_EQUAL((std::string)"gacl", OUTJOBS.front().Application.AccessControl.Name());
+  CPPUNIT_ASSERT_EQUAL(1, OUTJOBS.front().Application.AccessControl.Size());
+  CPPUNIT_ASSERT_EQUAL((std::string)"entry", OUTJOBS.front().Application.AccessControl.Child().Name());
+}
+
+void ARCJSDLParserTest::TestBasicJSDLCompliance() {
+  /** Testing compliance with GFD 56 **/
+  MESSAGE = "Error: The parser does not comply with the JDSL specification.";
+
+  const std::string jsdlStr = "<?xml version=\"1.0\"?>"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
+"<JobDescription>"
+"<Application>"
+"<posix-jsdl:POSIXApplication>"
+"<posix-jsdl:Executable>executable</posix-jsdl:Executable>"
+"</posix-jsdl:POSIXApplication>"
+"</Application>"
+"<Resources>"
+"<FileSystem>"
+"<DiskSpace>"
+"<LowerBoundedRange>128974848</LowerBoundedRange>" // 1024*1024*123
+"</DiskSpace>"
+"</FileSystem>"
+"</Resources>"
+"</JobDescription>"
+"</JobDefinition>";
+
+  CPPUNIT_ASSERT_MESSAGE(MESSAGE, PARSER.Parse(jsdlStr, OUTJOBS));
+  CPPUNIT_ASSERT_EQUAL_MESSAGE(MESSAGE, 1, (int)OUTJOBS.size());
+
+  CPPUNIT_ASSERT_EQUAL_MESSAGE(MESSAGE, 123, OUTJOBS.front().Resources.DiskSpaceRequirement.DiskSpace.min);
+  
+  std::string tempjobdesc;
+  CPPUNIT_ASSERT_MESSAGE(MESSAGE, PARSER.UnParse(OUTJOBS.front(), tempjobdesc, "nordugrid:jsdl"));
+
+  Arc::XMLNode xmlArcJSDL(tempjobdesc);
+}
+
 void ARCJSDLParserTest::TestPOSIXCompliance() {
   /** Testing compliance with GFD 56 - the POSIX extension **/
   MESSAGE = "Error: The parser does not comply with the JDSL POSIX specification.";
 
   const std::string posixJSDLStr = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:posix-jsdl=\"http://schemas.ggf.org/jsdl/2005/11/jsdl-posix\">"
 "<JobDescription>"
 "<Application>"
 "<posix-jsdl:POSIXApplication>"
@@ -477,7 +566,8 @@ void ARCJSDLParserTest::TestHPCCompliance() {
   MESSAGE = "Error: The parser does not comply with the JSDL HPC Profile Application Extension specification.";
 
   const std::string hpcJSDLStr = "<?xml version=\"1.0\"?>"
-"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\">"
+"<JobDefinition xmlns=\"http://schemas.ggf.org/jsdl/2005/11/jsdl\""
+" xmlns:HPC-jsdl=\"http://schemas.ggf.org/jsdl/2006/07/jsdl-hpcpa\">"
 "<JobDescription>"
 "<Application>"
 "<HPC-jsdl:HPCProfileApplication>"
