@@ -35,10 +35,8 @@ namespace Arc {
     std::string::size_type pos2 = service.find(":", pos1 + 3);
     std::string::size_type pos3 = service.find("/", pos1 + 3);
     if (pos3 == std::string::npos) {
-      if (pos2 == std::string::npos)
-        service += ":2170";
-      // Is this a good default path?
-      service += "/o=Grid";
+      if (pos2 == std::string::npos) service += ":2170";
+      service += "/o=grid";
     }
     else if (pos2 == std::string::npos || pos2 > pos3)
       service.insert(pos3, ":2170");
@@ -56,8 +54,8 @@ namespace Arc {
       return s;
     }
 
-    DataHandle handler(url, uc);
     DataBuffer buffer;
+    DataHandle handler(url, uc);
 
     if (!handler) {
       logger.msg(INFO, "Can't create information handle - "
