@@ -96,33 +96,18 @@ namespace Arc {
     }
 
     bool set(const std::string name, int& integer) {
-      std::string value = get(name);
-      if (!value.empty()) {
-        integer = stringtoi(value);
-        return true;
-      } else {
-        return false;
-      }
+      const std::string value = get(name);
+      return !value.empty() && stringto(value, integer);
     }
 
     bool set(const std::string name, float& number) {
       std::string value = get(name);
-      if (!value.empty()) {
-        number = stringtof(value);
-        return true;
-      } else {
-        return false;
-      }
+      return !value.empty() && stringto(value, number);
     }
 
     bool set(const std::string name, double& number) {
       std::string value = get(name);
-      if (!value.empty()) {
-        number = stringtod(value);
-        return true;
-      } else {
-        return false;
-      }
+      return !value.empty() && stringto(value, number);
     }
 
     bool set(const std::string name, URL& url) {
@@ -198,13 +183,14 @@ namespace Arc {
 
     URL url(CreateURL(ce.URLString));
     url.ChangeLDAPScope(URL::subtree);
+    url.ChangeLDAPFilter("(&(!(GLUE2GroupID=ComputingActivities))(!(ObjectClass=GLUE2ComputingActivity)))");
 
     if (!url) {
       return s;
     }
 
-    DataHandle handler(url, uc);
     DataBuffer buffer;
+    DataHandle handler(url, uc);
 
     if (!handler) {
       logger.msg(INFO, "Can't create information handle - "
@@ -242,6 +228,9 @@ namespace Arc {
       LocationType& Location = cs.Location;
 
       cs->Cluster = url; // contains the URL of the infosys that provided the info
+      cs->Cluster.ChangeLDAPScope(URL::base); // Reset scope
+      cs->Cluster.ChangeLDAPFilter(""); // and filter.
+
       cs->OriginalEndpoint = ce;
 
       // GFD.147 GLUE2 5.3 Location
