@@ -43,7 +43,7 @@ namespace Arc {
     if (pos3 == std::string::npos) {
       if (pos2 == std::string::npos)
         service += ":2135";
-      service += "/Mds-Vo-name=local, o=Grid";
+      service += "/Mds-Vo-name=local,o=Grid";
     }
     else if (pos2 == std::string::npos || pos2 > pos3)
       service.insert(pos3, ":2135");
@@ -64,15 +64,15 @@ namespace Arc {
 
     //Create credential object in order to get the user DN
     std::string emptycadir, emptycafile;
-    Credential credential(uc.ProxyPath().empty() ? uc.ProxyPath() : uc.CertificatePath(), "", emptycadir, emptycafile);
+    Credential credential(!uc.ProxyPath().empty() ? uc.ProxyPath() : uc.CertificatePath(), "", emptycadir, emptycafile);
     std::string escaped_dn = escape_chars(credential.GetIdentityName(), filter_esc, '\\', false, escape_hex);
 
     url.ChangeLDAPFilter("(|(objectclass=nordugrid-cluster)"
                          "(objectclass=nordugrid-queue)"
                          "(nordugrid-authuser-sn=" + escaped_dn + "))");
 
-    DataHandle handler(url, uc);
     DataBuffer buffer;
+    DataHandle handler(url, uc);
 
     if (!handler) {
       logger.msg(INFO, "Can't create information handle - "
@@ -108,6 +108,9 @@ namespace Arc {
       LocationType& Location = cs.Location;
 
       cs->Cluster = url;
+      cs->Cluster.ChangeLDAPScope(URL::base); // Reset scope
+      cs->Cluster.ChangeLDAPFilter(""); // and filter.
+
       cs->OriginalEndpoint = cie;
       // Computing Service attributes
       if ((*it)["nordugrid-cluster-name"]) {
@@ -197,6 +200,9 @@ namespace Arc {
         if (queue["nordugrid-queue-defaultwalltime"]) {
           ComputingShare->DefaultWallTime = Period((std::string)queue["nordugrid-queue-defaultwalltime"], PeriodMinutes);
         }
+        if (queue["nordugrid-queue-maxtotalcputime"]) {
+          ComputingShare->MaxTotalCPUTime = Period((std::string)queue["nordugrid-queue-maxtotalcputime"], PeriodMinutes);
+        }
         if (queue["nordugrid-queue-maxcputime"]) {
           ComputingShare->MaxCPUTime = Period((std::string)queue["nordugrid-queue-maxcputime"], PeriodMinutes);
         }
@@ -214,6 +220,8 @@ namespace Arc {
         }
         EntryToInt(url, queue["nordugrid-queue-nodememory"], ComputingShare->MaxVirtualMemory) || 
           EntryToInt(url, (*it)["nordugrid-cluster-nodememory"], ComputingShare->MaxVirtualMemory);
+        EntryToInt(url, queue["nordugrid-queue-nodememory"], ComputingShare->MaxMainMemory) || 
+          EntryToInt(url, (*it)["nordugrid-cluster-nodememory"], ComputingShare->MaxMainMemory);
         EntryToInt(url, authuser["nordugrid-authuser-diskspace"], ComputingShare->MaxDiskSpace);
         if ((*it)["nordugrid-cluster-localse"]) {
           ComputingShare->DefaultStorageService = (std::string)(*it)["nordugrid-cluster-localse"];
