@@ -11,6 +11,12 @@
 namespace Arc {
 
   /**
+   * Provides access to the gLite Grid File Access Library through ARC's API.
+   * Only rfio:// protocol is supported at the moment.
+   *
+   * Notes on env variables:
+   *  - If LFC plugin is installed LFC_HOST must be set (lcgutils bug 322)
+   *  - If SRM is used LCG_GFAL_INFOSYS must be set to BDII host:port
    *
    * This class is a loadable module and cannot be used directly. The DataHandle
    * class loads modules at runtime and should be used instead of this.
@@ -31,6 +37,8 @@ namespace Arc {
     virtual DataStatus Remove();
     virtual DataStatus CreateDirectory(bool with_parents=false);
   private:
+    DataStatus do_stat(const URL& stat_url, FileInfo& file);
+    void log_gfal_err();
     static void read_file_start(void *object);
     void read_file();
     static void write_file_start(void *object);
@@ -39,7 +47,8 @@ namespace Arc {
     int fd;
     bool reading;
     bool writing;
-    SimpleCondition transfer_condition;
+    SimpleCounter transfer_condition;
+    std::string lfc_host;
   };
 
 } // namespace Arc
