@@ -16,7 +16,7 @@
 #include <arc/data/DataBuffer.h>
 #include <arc/message/MCC.h>
 #include <arc/message/PayloadRaw.h>
-#include <arc/client/ClientInterface.h>
+#include <arc/Utils.h>
 
 #include "DataPointHTTP.h"
 
@@ -26,7 +26,7 @@ namespace Arc {
 
   typedef struct {
     DataPointHTTP *point;
-    ClientHTTP *client;
+    //ClientHTTP *client;
   } HTTPInfo_t;
 
   class ChunkControl {
@@ -262,14 +262,18 @@ namespace Arc {
 
   DataPointHTTP::DataPointHTTP(const URL& url, const UserConfig& usercfg, PluginArgument* parg)
     : DataPointDirect(url, usercfg, parg),
+      reading(false),
+      writing(false),
       chunks(NULL),
       transfers_tofinish(0) {}
 
   DataPointHTTP::~DataPointHTTP() {
     StopReading();
     StopWriting();
-    if (chunks)
-      delete chunks;
+    if (chunks) delete chunks;
+    for(std::multimap<std::string,ClientHTTP*>::iterator cl = clients.begin(); cl != clients.end(); ++cl) {
+      delete cl->second;
+    };
   }
 
   Plugin* DataPointHTTP::Instance(PluginArgument *arg) {
@@ -288,49 +292,43 @@ namespace Arc {
     for (const char *pos = html;;) {
       // Looking for tag
       const char *tag_start = strchr(pos, '<');
-      if (!tag_start)
-        break;              // No more tags
+      if (!tag_start) break;              // No more tags
       // Looking for end of tag
       const char *tag_end = strchr(tag_start + 1, '>');
-      if (!tag_end)
-        return false;            // Broken html?
+      if (!tag_end) return false;         // Broken html?
       // 'A' tag?
       if (strncasecmp(tag_start, "<A ", 3) == 0) {
         // Lookig for HREF
         const char *href = strstr(tag_start + 3, "href=");
-        if (!href)
-          href = strstr(tag_start + 3, "HREF=");
+        if (!href) href = strstr(tag_start + 3, "HREF=");
         if (href) {
           const char *url_start = href + 5;
           const char *url_end = NULL;
           if ((*url_start) == '"') {
             ++url_start;
             url_end = strchr(url_start, '"');
-            if ((!url_end) || (url_end > tag_end))
-              url_end = NULL;
+            if ((!url_end) || (url_end > tag_end)) url_end = NULL;
           }
           else if ((*url_start) == '\'') {
             ++url_start;
             url_end = strchr(url_start, '\'');
-            if ((!url_end) || (url_end > tag_end))
-              url_end = NULL;
+            if ((!url_end) || (url_end > tag_end)) url_end = NULL;
           }
           else {
             url_end = strchr(url_start, ' ');
-            if ((!url_end) || (url_end > tag_end))
-              url_end = tag_end;
+            if ((!url_end) || (url_end > tag_end)) url_end = tag_end;
           }
-          if (!url_end)
-            return false; // Broken HTML
+          if (!url_end) return false; // Broken HTML
           std::string url(url_start, url_end - url_start);
           url = uri_unencode(url);
+          if(url[0] == '/') {
+            url = base.ConnectionURL()+url;
+          }
           if (url.find("://") != std::string::npos) {
             URL u(url);
             std::string b = base.str();
-            if (b[b.size() - 1] != '/')
-              b += '/';
-            if (u.str().substr(0, b.size()) == b)
-              url = u.str().substr(b.size());
+            if (b[b.size() - 1] != '/') b += '/';
+            if (u.str().substr(0, b.size()) == b) url = u.str().substr(b.size());
           }
           if (url[0] != '?' && url[0] != '/') {
             if (url.find('/') == url.size() - 1) {
@@ -349,53 +347,69 @@ namespace Arc {
     return true;
   }
 
-  static DataStatus do_stat(const std::string& path, ClientHTTP& client, FileInfo& file) {
+  DataStatus DataPointHTTP::do_stat(URL& rurl, FileInfo& file) {
     PayloadRaw request;
-    PayloadRawInterface *inbuf;
+    PayloadRawInterface *inbuf = NULL;
     HTTPClientInfo info;
-    info.lastModified = (time_t)(-1);
-    // Do HEAD to obtain some metadata
-    MCC_Status r = client.process("HEAD", path, &request, &info, &inbuf);
-    if (inbuf) delete inbuf;
-    // TODO: handle redirects
-    if ((!r) || (info.code != 200)) {
-      if(info.code == 404) return DataStatus::StatNotPresentError;
-      return DataStatus::StatError;
-    }
-    // Fetch known metadata
-    file.SetMetaData("path", path);
-    std::string type = info.type;
-    std::string::size_type pos = type.find(';');
-    if (pos != std::string::npos) type = type.substr(0, pos);
+    for(int redirects_max = 10;redirects_max>=0;--redirects_max) {
+      std::string path = rurl.FullPathURIEncoded();
+      info.lastModified = (time_t)(-1);
+      AutoPointer<ClientHTTP> client(acquire_client(rurl));
+      if (!client) return DataStatus::StatError;
+      // Do HEAD to obtain some metadata
+      MCC_Status r = client->process("HEAD", path, &request, &info, &inbuf);
+      if (inbuf) delete inbuf;
+      if (!r) {
+        return DataStatus::StatError;
+      }
+      release_client(rurl,client.Release());
+      if (info.code != 200) {
+        if((info.code == 301) || // permanent redirection
+           (info.code == 302) || // temporary redirection
+           (info.code == 303) || // POST to GET redirection
+           (info.code == 304)) { // redirection to cache
+          // 305 - redirection to proxy - unhandled
+          // Recreate connection now to new URL
+          rurl = info.location;
+          logger.msg(VERBOSE,"Redirecting to %s",info.location);
+          continue;
+        }
+        if(info.code == 404) return DataStatus::StatNotPresentError;
+        return DataStatus::StatError;
+      }
+      // Fetch known metadata
+      file.SetMetaData("path", path);
+      std::string type = info.type;
+      std::string::size_type pos = type.find(';');
+      if (pos != std::string::npos) type = type.substr(0, pos);
 
-    // Treat every html as potential directory/set of links
-    if(type == "text/html") {
-      file.SetType(FileInfo::file_type_dir);
-      file.SetMetaData("type", "dir");
-    } else {
-      file.SetType(FileInfo::file_type_file);
-      file.SetMetaData("type", "file");
+      // Treat every html as potential directory/set of links
+      if(type == "text/html") {
+        file.SetType(FileInfo::file_type_dir);
+        file.SetMetaData("type", "dir");
+      } else {
+        file.SetType(FileInfo::file_type_file);
+        file.SetMetaData("type", "file");
+      }
+      if(info.size != (uint64_t)(-1)) {
+        file.SetSize(info.size);
+        file.SetMetaData("size", tostring(info.size));
+      }
+      if(info.lastModified != (time_t)(-1)) {
+        file.SetCreated(info.lastModified);
+        file.SetMetaData("mtime", info.lastModified.str());
+      }
+      // Not sure
+      if(!info.location.empty()) file.AddURL(info.location);
+      return DataStatus::Success;
     }
-    if(info.size != (uint64_t)(-1)) {
-      file.SetSize(info.size);
-      file.SetMetaData("size", tostring(info.size));
-    }
-    if(info.lastModified != (time_t)(-1)) {
-      file.SetCreated(info.lastModified);
-      file.SetMetaData("mtime", info.lastModified.str());
-    }
-    // Not sure
-    if(!info.location.empty()) file.AddURL(info.location);
-    return DataStatus::Success;
+    return DataStatus(DataStatus::StatError,"Too many redirects");
   }
 
   DataStatus DataPointHTTP::Stat(FileInfo& file, DataPointInfoType verb) {
     // verb is not used
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
-    ClientHTTP client(cfg, url, usercfg.Timeout());
-
-    DataStatus r = do_stat(url.FullPathURIEncoded(), client, file);
+    URL curl = url;
+    DataStatus r = do_stat(curl, file);
     if(!r) return r;
     std::string name = url.FullPath();
     std::string::size_type p = name.rfind('/');
@@ -422,14 +436,10 @@ namespace Arc {
   DataStatus DataPointHTTP::List(std::list<FileInfo>& files, DataPointInfoType verb) {
     if (transfers_started.get() != 0) return DataStatus::ListError;
     URL curl = url;
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
 
     {
-      ClientHTTP client(cfg, curl, usercfg.Timeout());
       FileInfo file;
-      DataStatus r = do_stat(curl.FullPathURIEncoded(), client, file);
-      if(r) {
+      if(do_stat(curl, file)) {
         if(file.CheckSize()) size = file.GetSize();
         if(file.CheckCreated()) created = file.GetCreated();
         if(file.GetType() != FileInfo::file_type_dir) return DataStatus::ListError;
@@ -438,24 +448,29 @@ namespace Arc {
 
     DataBuffer buffer;
 
-    // TODO: Reuse connection
+    // Read content of file
+    // TODO: Reuse already redirected URL stored in curl
     if (!StartReading(buffer)) return DataStatus::ListError;
 
     int handle;
     unsigned int length;
     unsigned long long int offset;
     std::string result;
+    unsigned long long int maxsize = (10*1024*1024); // 10MB seems reasonable limit
 
-    // TODO: limit size
     while (buffer.for_write() || !buffer.eof_read()) {
       if (buffer.for_write(handle, length, offset, true)) {
-        result.append(buffer[handle], length);
+        if(offset >= maxsize) { buffer.is_written(handle); break; };
+        if((offset+length) > maxsize) length = maxsize-offset;
+        if((offset+length) > result.size()) result.resize(offset+length,'\0');
+        result.replace(offset,length,buffer[handle], length);
         buffer.is_written(handle);
       }
     }
 
     if (!StopReading()) return DataStatus::ListError;
 
+    // Convert obtained HTML into set of links
     bool is_html = false;
     bool is_body = false;
     std::string::size_type tagstart = 0;
@@ -477,25 +492,17 @@ namespace Arc {
     } while (!is_body);
 
     std::string title;
-    if (titlestart != std::string::npos && titleend != std::string::npos)
+    if (titlestart != std::string::npos && titleend != std::string::npos) {
       title = result.substr(titlestart, titleend - titlestart + 1);
+    }
 
     if (is_body) {
-      html2list(result.c_str(), url, files);
+      // If it was redirected then links must be relative to new location. Or not?
+      html2list(result.c_str(), curl, files);
       if(verb & (INFO_TYPE_TYPE | INFO_TYPE_TIMES | INFO_TYPE_CONTENT)) {
         for(std::list<FileInfo>::iterator f = files.begin(); f != files.end(); ++f) {
-          URL furl(url.str()+'/'+(f->GetName()));
-          /* for future use
-          if((furl.Host() != curl.Host()) ||
-             (furl.Port() != curl.Port()) ||
-             (furl.Protocol() != curl.Protocol())) {
-            curl = furl;
-            delete client;
-            client = new ClientHTTP(cfg, curl, usercfg.Timeout());
-          }
-          */
-          ClientHTTP client(cfg, curl, usercfg.Timeout());
-          do_stat(furl.FullPathURIEncoded(), client, *f);
+          URL furl(curl.str()+'/'+(f->GetName()));
+          do_stat(furl, *f);
         }
       }
     }
@@ -503,19 +510,22 @@ namespace Arc {
   }
 
   DataStatus DataPointHTTP::StartReading(DataBuffer& buffer) {
+    if (reading) return DataStatus::IsReadingError;
+    if (writing) return DataStatus::IsWritingError;
     if (transfers_started.get() != 0) return DataStatus::ReadStartError;
+    reading = true;
     int transfer_streams = 1;
+    strtoint(url.Option("threads"),transfer_streams);
+    if (transfer_streams < 1) transfer_streams = 1;
+    if (transfer_streams > MAX_PARALLEL_STREAMS) transfer_streams = MAX_PARALLEL_STREAMS;
     DataPointHTTP::buffer = &buffer;
     if (chunks) delete chunks;
     chunks = new ChunkControl;
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
     transfer_lock.lock();
     transfers_tofinish = 0;
     for (int n = 0; n < transfer_streams; ++n) {
       HTTPInfo_t *info = new HTTPInfo_t;
       info->point = this;
-      info->client = new ClientHTTP(cfg, url, usercfg.Timeout());
       if (!CreateThreadFunction(&read_thread, info, &transfers_started)) {
         delete info;
       } else {
@@ -532,7 +542,10 @@ namespace Arc {
   }
 
   DataStatus DataPointHTTP::StopReading() {
+    if (!reading) return DataStatus::ReadStopError;
+    reading = false;
     if (!buffer) return DataStatus::ReadStopError;
+    if(!buffer->eof_read()) buffer->error_read(true);
     while (transfers_started.get()) {
       transfers_started.wait(10000); // Just in case
     }
@@ -549,20 +562,22 @@ namespace Arc {
 
   DataStatus DataPointHTTP::StartWriting(DataBuffer& buffer,
                                          DataCallback*) {
+    if (reading) return DataStatus::IsReadingError;
+    if (writing) return DataStatus::IsWritingError;
     if (transfers_started.get() != 0) return DataStatus::WriteStartError;
+    writing = true;
     int transfer_streams = 1;
+    strtoint(url.Option("threads"),transfer_streams);
+    if (transfer_streams < 1) transfer_streams = 1;
+    if (transfer_streams > MAX_PARALLEL_STREAMS) transfer_streams = MAX_PARALLEL_STREAMS;
     DataPointHTTP::buffer = &buffer;
-    if (chunks)
-      delete chunks;
+    if (chunks) delete chunks;
     chunks = new ChunkControl;
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
     transfer_lock.lock();
     transfers_tofinish = 0;
     for (int n = 0; n < transfer_streams; ++n) {
       HTTPInfo_t *info = new HTTPInfo_t;
       info->point = this;
-      info->client = new ClientHTTP(cfg, url, usercfg.Timeout());
       if (!CreateThreadFunction(&write_thread, info, &transfers_started)) {
         delete info;
       } else {
@@ -579,7 +594,10 @@ namespace Arc {
   }
 
   DataStatus DataPointHTTP::StopWriting() {
+    if (!writing) return DataStatus::WriteStopError;
+    writing = false;
     if (!buffer) return DataStatus::WriteStopError;
+    if(!buffer->eof_write()) buffer->error_write(true);
     while (transfers_started.get()) {
       transfers_started.wait(); // Just in case
     }
@@ -596,20 +614,21 @@ namespace Arc {
   }
 
   DataStatus DataPointHTTP::Check() {
-    MCCConfig cfg;
-    usercfg.ApplyToConfig(cfg);
-    ClientHTTP client(cfg, url, usercfg.Timeout());
     PayloadRaw request;
-    PayloadRawInterface *inbuf;
+    PayloadRawInterface *inbuf = NULL;
     HTTPClientInfo info;
-    MCC_Status r = client.process("GET", url.FullPathURIEncoded(), 0, 15,
+    AutoPointer<ClientHTTP> client(acquire_client(url));
+    if (!client) return DataStatus::CheckError;
+    MCC_Status r = client->process("GET", url.FullPathURIEncoded(), 0, 15,
                                   &request, &info, &inbuf);
     PayloadRawInterface::Size_t logsize = 0;
     if (inbuf){
       logsize = inbuf->Size();
       delete inbuf;
     }
-    if ((!r) || ((info.code != 200) && (info.code != 206))) return DataStatus::CheckError;
+    if (!r) return DataStatus::CheckError;
+    release_client(url,client.Release());
+    if ((info.code != 200) && (info.code != 206)) return DataStatus::CheckError;
     size = logsize;
     logger.msg(VERBOSE, "Check: obtained size %llu", size);
     created = info.lastModified;
@@ -618,7 +637,17 @@ namespace Arc {
   }
 
   DataStatus DataPointHTTP::Remove() {
-    return DataStatus::DeleteError;
+    AutoPointer<ClientHTTP> client(acquire_client(url));
+    PayloadRaw request;
+    PayloadRawInterface *inbuf = NULL;
+    HTTPClientInfo info;
+    MCC_Status r = client->process("DELETE", url.FullPathURIEncoded(),
+                                  &request, &info, &inbuf);
+    if (inbuf) delete inbuf;
+    if(!r) return DataStatus::DeleteError;
+    release_client(url,client.Release());
+    if ((info.code != 200) && (info.code != 202) && (info.code != 204)) return DataStatus::DeleteError;
+    return DataStatus::Success;
   }
 
   void DataPointHTTP::read_thread(void *arg) {
@@ -626,12 +655,16 @@ namespace Arc {
     DataPointHTTP& point = *(info.point);
     point.transfer_lock.lock();
     point.transfer_lock.unlock();
-    ClientHTTP *client = info.client;
     URL client_url = point.url;
+    ClientHTTP* client = point.acquire_client(client_url);
     bool transfer_failure = false;
     int retries = 0;
     std::string path = point.CurrentLocation().FullPathURIEncoded();
     for (;;) {
+      if (!client) {
+        transfer_failure = true;
+        break;
+      }
       unsigned int transfer_size = 0;
       int transfer_handle = -1;
       // get first buffer
@@ -651,7 +684,7 @@ namespace Arc {
       // Read chunk
       HTTPClientInfo transfer_info;
       PayloadRaw request;
-      PayloadRawInterface *inbuf;
+      PayloadRawInterface *inbuf = NULL;
       MCC_Status r = client->process("GET", path, transfer_offset,
                                      transfer_end, &request, &transfer_info,
                                      &inbuf);
@@ -660,6 +693,7 @@ namespace Arc {
         point.buffer->is_read(transfer_handle, 0, 0);
         point.chunks->Unclaim(transfer_offset, chunk_length);
         if (inbuf) delete inbuf;
+        delete client; client = NULL;
         // Failed to transfer chunk - retry.
         // 10 times in a row seems to be reasonable number
         // TODO: mark failure?
@@ -669,11 +703,7 @@ namespace Arc {
           break;
         }
         // Recreate connection
-        delete client;
-        client = NULL;
-        MCCConfig cfg;
-        point.usercfg.ApplyToConfig(cfg);
-        client = new ClientHTTP(cfg, client_url, point.usercfg.Timeout());
+        client = point.acquire_client(client_url);
         continue;
       }
       if (transfer_info.code == 416) { // EOF
@@ -692,17 +722,11 @@ namespace Arc {
         point.chunks->Unclaim(transfer_offset, chunk_length);
         if (inbuf) delete inbuf;
         // Recreate connection now to new URL
-        delete client;
-        client = NULL;
-        MCCConfig cfg;
-        point.usercfg.ApplyToConfig(cfg);
+        point.release_client(client_url,client); client = NULL;
         client_url = transfer_info.location;
         logger.msg(VERBOSE,"Redirecting to %s",transfer_info.location);
-        if(client_url && (
-            (client_url.Protocol() == "http") ||
-            (client_url.Protocol() == "https") ||
-            (client_url.Protocol() == "httpg"))) {
-          client = new ClientHTTP(cfg, client_url, point.usercfg.Timeout());
+        client = point.acquire_client(client_url);
+        if (client) {
           path = client_url.FullPathURIEncoded();
           continue;
         }
@@ -820,7 +844,7 @@ namespace Arc {
       // TODO: process/report failure?
       point.buffer->eof_read(true);
     }
-    if (client) delete client;
+    point.release_client(client_url,client); client = NULL;
     delete &info;
     point.transfer_lock.unlock();
   }
@@ -830,11 +854,16 @@ namespace Arc {
     DataPointHTTP& point = *(info.point);
     point.transfer_lock.lock();
     point.transfer_lock.unlock();
-    ClientHTTP *client = info.client;
+    URL client_url = point.url;
+    ClientHTTP *client = point.acquire_client(client_url);
     bool transfer_failure = false;
     int retries = 0;
-    std::string path = point.CurrentLocation().FullPathURIEncoded();
+    std::string path = client_url.FullPathURIEncoded();
     for (;;) {
+      if (!client) {
+        transfer_failure = true;
+        break;
+      }
       unsigned int transfer_size = 0;
       int transfer_handle = -1;
       unsigned long long int transfer_offset = 0;
@@ -853,9 +882,9 @@ namespace Arc {
       PayloadRawInterface *response;
       MCC_Status r = client->process("PUT", path, &request, &transfer_info,
                                      &response);
-      if (response)
-        delete response;
+      if (response) delete response;
       if (!r) {
+        delete client; client = NULL;
         // Failed to transfer chunk - retry.
         // 10 times in a row seems to be reasonable number
         // TODO: mark failure?
@@ -867,11 +896,7 @@ namespace Arc {
         // Return buffer
         point.buffer->is_notwritten(transfer_handle);
         // Recreate connection
-        delete client;
-        client = NULL;
-        MCCConfig cfg;
-        point.usercfg.ApplyToConfig(cfg);
-        client = new ClientHTTP(cfg, point.url, point.usercfg.Timeout());
+        client = point.acquire_client(client_url);
         continue;
       }
       if ((transfer_info.code != 201) &&
@@ -880,9 +905,9 @@ namespace Arc {
         point.buffer->is_notwritten(transfer_handle);
         if ((transfer_info.code == 500) ||
             (transfer_info.code == 503) ||
-            (transfer_info.code == 504))
-          if ((++retries) <= 10)
-            continue;
+            (transfer_info.code == 504)) {
+          if ((++retries) <= 10) continue;
+        }
         transfer_failure = true;
         break;
       }
@@ -895,27 +920,28 @@ namespace Arc {
     if (point.transfers_tofinish == 0) {
       // TODO: process/report failure?
       point.buffer->eof_write(true);
-      if ((!(point.buffer->error())) && (point.buffer->eof_position() == 0))
+      if ((!(point.buffer->error())) && (point.buffer->eof_position() == 0)) {
         // Zero size data was trasfered - must send at least one empty packet
         for (;;) {
+          if (!client) client = point.acquire_client(client_url);
+          if (!client) {
+            point.buffer->error_write(true);
+            break;
+          }
           HTTPClientInfo transfer_info;
           PayloadMemConst request(NULL, 0, 0, 0);
           PayloadRawInterface *response;
           MCC_Status r = client->process("PUT", path, &request, &transfer_info,
                                          &response);
-          if (response)
-            delete response;
+          if (response) delete response;
           if (!r) {
+            delete client; client = NULL;
             if ((++retries) > 10) {
               point.buffer->error_write(true);
               break;
             }
             // Recreate connection
-            delete client;
-            client = NULL;
-            MCCConfig cfg;
-            point.usercfg.ApplyToConfig(cfg);
-            client = new ClientHTTP(cfg, point.url, point.usercfg.Timeout());
+            client = point.acquire_client(client_url);;
             continue;
           }
           if ((transfer_info.code != 201) &&
@@ -924,15 +950,15 @@ namespace Arc {
             if ((transfer_info.code == 500) ||
                 (transfer_info.code == 503) ||
                 (transfer_info.code == 504))
-              if ((++retries) <= 10)
-                continue;
+              if ((++retries) <= 10) continue;
             point.buffer->error_write(true);
             break;
           }
           break;
         }
+      }
     }
-    if (client) delete client;
+    point.release_client(client_url,client); client = NULL;
     delete &info;
     point.transfer_lock.unlock();
   }
@@ -942,9 +968,41 @@ namespace Arc {
     if(url.Host() != this->url.Host()) return false;
     if(url.Port() != this->url.Port()) return false;
     this->url = url;
+    if(triesleft < 1) triesleft = 1;
     return true;
   }
 
+  ClientHTTP* DataPointHTTP::acquire_client(const URL& curl) {
+    // TODO: lock
+    if(!curl) return NULL;
+    if((curl.Protocol() != "http") &&
+       (curl.Protocol() != "https") &&
+       (curl.Protocol() != "httpg")) return NULL;
+    ClientHTTP* client = NULL;
+    std::string key = curl.ConnectionURL();
+    clients_lock.lock();
+    std::multimap<std::string,ClientHTTP*>::iterator cl = clients.find(key);
+    if(cl != clients.end()) {
+      client = cl->second;
+      clients.erase(cl);
+      clients_lock.unlock();
+    } else {
+      clients_lock.unlock();
+      MCCConfig cfg;
+      usercfg.ApplyToConfig(cfg);
+      client = new ClientHTTP(cfg, curl, usercfg.Timeout());
+    };
+    return client;
+  }
+
+  void DataPointHTTP::release_client(const URL& curl, ClientHTTP* client) {
+    if(!client) return;
+    std::string key = curl.ConnectionURL();
+    //if(!*client) return;
+    clients_lock.lock();
+    clients.insert(std::pair<std::string,ClientHTTP*>(key,client));
+    clients_lock.unlock();
+  }
 
 } // namespace Arc
 
