@@ -154,27 +154,65 @@ namespace Arc {
   }
 
   DataStatus DataPointLFC::Check() {
-    // simply check that the file can be listed
-    std::list<FileInfo> files;
-    DataStatus r = ListFiles(files,INFO_TYPE_MINIMAL,false);
-    if(!r) {
-      if(r == DataStatus::ListErrorRetryable) r = DataStatus::CheckErrorRetryable;
-      if(r == DataStatus::ListError) r = DataStatus::CheckError;
-      return r;
+    // simply check that the file can be resolved
+    DataStatus r = Resolve(true);
+    if (!r) {
+      if (r == DataStatus::ReadResolveErrorRetryable) r = DataStatus::CheckErrorRetryable;
+      else r = DataStatus::CheckError;
+    }
+    return r;
+  }
+
+  /// Class for passing resolve arguments to separate thread function
+  class ResolveArgs {
+  public:
+    ResolveArgs(const char** lfns, const char** guids, int size, int* nbentries, struct lfc_filereplicas** entries) :
+      lfns(lfns), guids(guids), size(size), nbentries(nbentries), entries(entries), result(0), serrno_(0) {}
+    ~ResolveArgs() { delete[] lfns; delete[] guids; }
+    const char** lfns;
+    const char** guids;
+    int size; // size of the lfn or guid list
+    int* nbentries;
+    struct lfc_filereplicas** entries;
+    int result;
+    int serrno_;
+    SimpleCounter count;
+  };
+
+  /// Function for resolving in a separate thread
+  void do_resolve(void* arg) {
+    ResolveArgs* args = (ResolveArgs*)arg;
+    // If guid is supplied it is preferred over LFN
+    if (args->guids && *(args->guids) && **(args->guids)) {
+      args->result = lfc_getreplicas(args->size, args->guids, NULL, args->nbentries, args->entries);
+      args->serrno_ = serrno;
+    } else if (args->lfns && *(args->lfns) && **(args->lfns)) {
+      args->result = lfc_getreplicasl(args->size, args->lfns, NULL, args->nbentries, args->entries);
+      args->serrno_ = serrno;
+    } else {
+      // this case should never happen, but just in case...
+      args->result = -1;
+      args->serrno_ = EINVAL;
     }
-    if(files.empty()) return DataStatus::CheckError;
-    return DataStatus::Success;
   }
 
   DataStatus DataPointLFC::Resolve(bool source) {
-    int lfc_r;
 
     // NOTE: Sessions are not used in Resolve(), because under heavy load in A-REX
     // it can end up using all the LFC server threads. See bug 2576 for more info.
+    //
+    // Resolving is also carried out using a separate thread wrapped in a timeout
+    // in order to avoid hanging caused by misbehaving DNS, which LFC client does
+    // not (and will not) handle. See bug 2762.
 
+    int lfc_r = 0;
     std::string path = url.Path();
 
-    if (source || path.empty() || path == "/") {
+    if (source) {
+      // check for guid in the attributes
+      if (!url.MetaDataOption("guid").empty()) guid = url.MetaDataOption("guid");
+    }
+    else if (path.empty() || path == "/") {
       path = ResolveGUIDToLFN();
       if (path.empty()) {
         if (source) return IsTempError() ? DataStatus::ReadResolveErrorRetryable : DataStatus::ReadResolveError;
@@ -188,24 +226,61 @@ namespace Arc {
 
     resolved = false;
     registered = false;
-    int nbentries = 0;
-    struct lfc_filereplica *entries = NULL;
-    LFCLOCKINT(lfc_r,lfc_getreplica(path.c_str(), NULL, NULL, &nbentries, &entries), url);
-    if(lfc_r != 0) {
-      if (source || ((serrno != ENOENT) && (serrno != ENOTDIR))) {
-        logger.msg(ERROR, "Error finding replicas: %s", sstrerror(serrno));
-        if (source) return IsTempError() ? DataStatus::ReadResolveErrorRetryable : DataStatus::ReadResolveError;
-        return IsTempError() ? DataStatus::WriteResolveErrorRetryable : DataStatus::WriteResolveError;
+    int* nbentries = new int(0);
+    struct lfc_filereplicas **lfc_entries = new struct lfc_filereplicas*;
+    const char** lfns = new const char*[1];
+    lfns[0] = path.c_str();
+    const char** guids = new const char*[1];
+    guids[0] = guid.c_str();
+    ResolveArgs* args = new ResolveArgs(lfns, guids, 1, nbentries, lfc_entries);
+    bool res;
+    {
+      LFCEnvLocker lfc_env(usercfg, url);
+      res = CreateThreadFunction(&do_resolve, args, &args->count);
+      if (res) {
+        res = args->count.wait(300*1000);
+      }
+    }
+    if (!res) {
+      // error or timeout. Timeout will leave the thread hanging, and create
+      // a memory leak since the ResolveArgs object is not deleted.
+      logger.msg(WARNING, "LFC resolve timed out");
+      if (source) return DataStatus::ReadResolveErrorRetryable;
+      return DataStatus::WriteResolveErrorRetryable;
+    }
+    lfc_r = args->result;
+    serrno = args->serrno_;
+    delete args;
+    int nentries = *nbentries;
+    delete nbentries;
+    struct lfc_filereplicas *entries = NULL;
+    if (lfc_entries) entries = *lfc_entries;
+    delete lfc_entries;
+
+    if (lfc_r != 0) {
+      logger.msg(ERROR, "Error finding replicas: %s", sstrerror(serrno));
+      if (source) return IsTempError() ? DataStatus::ReadResolveErrorRetryable : DataStatus::ReadResolveError;
+      return IsTempError() ? DataStatus::WriteResolveErrorRetryable : DataStatus::WriteResolveError;
+    }
+    if (nentries == 0 || !entries) {
+      // Even if file doesn't exist in LFC an entry should be returned
+      logger.msg(ERROR, "LFC resolve returned no entries");
+      if (entries) free(entries);
+      return DataStatus(DataStatus::ReadResolveError);
+    }
+    if (entries[0].sfn[0] == '\0') {
+      if (source) {
+        logger.msg(ERROR, "File does not exist in LFC");
+        free(entries);
+        return DataStatus(DataStatus::ReadResolveError);
       }
-      nbentries = 0;
-      entries = NULL;
     }
     else {
       registered = true;
     }
 
     if (source) { // add locations resolved above
-      for (int n = 0; n < nbentries; n++) {
+      for (int n = 0; n < nentries; n++) {
         URL uloc(entries[n].sfn);
         if (!uloc) {
           logger.msg(WARNING, "Skipping invalid location: %s - %s", url.ConnectionURL(), entries[n].sfn);
@@ -230,9 +305,10 @@ namespace Arc {
         }
 
         // check that this replica doesn't exist already
-        for (int n = 0; n < nbentries; n++) {
+        for (int n = 0; n < nentries; n++) {
           if (std::string(entries[n].sfn) == uloc.plainstr()) {
             logger.msg(ERROR, "Replica %s already exists for LFN %s", entries[n].sfn, url.plainstr());
+            free(entries);
             return DataStatus::WriteResolveError;
           }
         }
@@ -250,34 +326,31 @@ namespace Arc {
           logger.msg(VERBOSE, "Adding location: %s - %s", url.ConnectionURL(), uloc.plainstr());
       }
     }
-    if (entries)
-      free(entries);
 
-    struct lfc_filestatg st;
-    LFCLOCKINT(lfc_r,lfc_statg(path.c_str(), NULL, &st), url);
-    if(lfc_r == 0) {
-      if (st.filemode & S_IFDIR) { // directory
-        return DataStatus::Success;
-      }
-      registered = true;
-      SetSize(st.filesize);
-      SetCreated(st.mtime);
-      if (st.csumtype[0] && st.csumvalue[0]) {
-        std::string csum = st.csumtype;
+    if (!HaveLocations()) {
+      logger.msg(ERROR, "No locations found for %s", url.str());
+      free(entries);
+      if (source) return DataStatus(DataStatus::ReadResolveError, "No valid locations found");
+      return DataStatus(DataStatus::WriteResolveError, "No valid locations found");
+    }
+
+    // Set meta-attributes
+    if (registered) {
+      SetSize(entries[0].filesize);
+      SetCreated(entries[0].ctime);
+      if (entries[0].csumtype[0] && entries[0].csumvalue[0]) {
+        std::string csum = entries[0].csumtype;
         if (csum == "MD")
           csum = "md5";
         else if (csum == "AD") 
           csum = "adler32";
         csum += ":";
-        csum += st.csumvalue;
+        csum += entries[0].csumvalue;
         SetCheckSum(csum);
       }
-      guid = st.guid;
-    }
-    if (!HaveLocations()) {
-      logger.msg(ERROR, "No locations found for %s", url.str());
-      return source ? DataStatus::ReadResolveError : DataStatus::WriteResolveError;
+      guid = entries[0].guid;
     }
+    free(entries);
     if (CheckCheckSum()) logger.msg(VERBOSE, "meta_get_data: checksum: %s", GetCheckSum());
     if (CheckSize()) logger.msg(VERBOSE, "meta_get_data: size: %llu", GetSize());
     if (CheckCreated()) logger.msg(VERBOSE, "meta_get_data: created: %s", GetCreated().str());
@@ -908,32 +981,57 @@ namespace Arc {
       }
     }
 
-    int nbentries = 0;
-    struct lfc_filereplicas *entries = NULL;
+    int* nbentries = new int(0);
+    struct lfc_filereplicas **lfc_entries = new struct lfc_filereplicas*;
     int lfc_r;
 
+    const char ** guids = new const char*[urls.size()];
+    const char ** paths = new const char*[urls.size()];
     if (use_guids) {
-      const char * guids[urls.size()];
       unsigned int n = 0;
       for (std::list<DataPoint*>::const_iterator i = urls.begin(); i != urls.end(); ++i, ++n) {
         guids[n] = (*i)->GetURL().MetaDataOption("guid").c_str();
       }
-      LFCLOCKINT(lfc_r,lfc_getreplicas(urls.size(), guids, NULL, &nbentries, &entries), url);
+      paths[0] = NULL;
     }
     else {
-      const char * paths[urls.size()];
       unsigned int n = 0;
       for (std::list<DataPoint*>::const_iterator i = urls.begin(); i != urls.end(); ++i, ++n) {
         paths[n] = (*i)->GetURL().Path().c_str();
       }
-      LFCLOCKINT(lfc_r,lfc_getreplicasl(urls.size(), paths, NULL, &nbentries, &entries), url);
+      guids[0] = NULL;
     }
 
+    // See Resolve(bool) for explanation
+    ResolveArgs* args = new ResolveArgs(paths, guids, urls.size(), nbentries, lfc_entries);
+    bool res;
+    {
+      LFCEnvLocker lfc_env(usercfg, url);
+      res = CreateThreadFunction(&do_resolve, args, &args->count);
+      if (res) {
+        res = args->count.wait(300*1000);
+      }
+    }
+    if (!res) {
+      // error or timeout. Timeout will leave the thread hanging, and create
+      // a memory leak since the ResolveArgs object is not deleted.
+      logger.msg(WARNING, "LFC resolve timed out");
+      return DataStatus::ReadResolveErrorRetryable;
+    }
+    lfc_r = args->result;
+    serrno = args->serrno_;
+    delete args;
+    int nentries = *nbentries;
+    delete nbentries;
+    struct lfc_filereplicas *entries = NULL;
+    if (lfc_entries) entries = *lfc_entries;
+    delete lfc_entries;
+
     if(lfc_r != 0) {
       logger.msg(ERROR, "Error finding replicas: %s", sstrerror(serrno));
       return IsTempError() ? DataStatus::ReadResolveErrorRetryable : DataStatus::ReadResolveError;
     }
-    if (nbentries == 0) {
+    if (nentries == 0 || !entries) {
       logger.msg(ERROR, "Bulk resolve returned no entries");
       return DataStatus::ReadResolveError;
     }
@@ -947,7 +1045,7 @@ namespace Arc {
     std::list<DataPoint*>::const_iterator datapoint = urls.begin();
     DataPoint* dp = *datapoint;
 
-    for (int n = 0; n < nbentries; n++) {
+    for (int n = 0; n < nentries; n++) {
       logger.msg(DEBUG, "GUID %s, SFN %s", entries[n].guid, entries[n].sfn);
 
       if (previous_guid != entries[n].guid) {
