@@ -29,10 +29,9 @@ namespace Arc {
 
   Logger DataPointRLS::logger(Logger::getRootLogger(), "DataPoint.RLS");
 
-  DataPointRLS::DataPointRLS(const URL& url, const UserConfig& usercfg)
-    : DataPointIndex(url, usercfg),
+  DataPointRLS::DataPointRLS(const URL& url, const UserConfig& usercfg, PluginArgument* parg)
+    : DataPointIndex(url, usercfg, parg),
       guid_enabled(false) {
-    valid_url_options.push_back("guid");
     if(!proxy_initialized) {
 #ifdef HAVE_GLOBUS_THREAD_SET_MODEL
       globus_thread_set_model("pthread");
@@ -69,7 +68,7 @@ namespace Arc {
     factory->makePersistent(module);
     OpenSSLInit();
     persistent_initialized = true;
-    return new DataPointRLS(*dmcarg, *dmcarg);
+    return new DataPointRLS(*dmcarg, *dmcarg, dmcarg);
   }
 
   static const char* get_path_str(const URL& url) {
@@ -1226,11 +1225,34 @@ namespace Arc {
     return arg.success;
   }
 
+  DataStatus DataPointRLS::Stat(std::list<FileInfo>& files,
+                                const std::list<DataPoint*>& urls,
+                                DataPointInfoType verb) {
+    // Bulk operations not implemented yet
+    for (std::list<DataPoint*>::const_iterator i = urls.begin(); i != urls.end(); ++i) {
+      FileInfo f;
+      DataStatus res = (*i)->Stat(f, verb);
+      if (!res.Passed()) files.push_back(FileInfo());
+      else files.push_back(f);
+    }
+    return DataStatus::Success;
+
+  }
+
   DataStatus DataPointRLS::List(std::list<FileInfo>& /*files*/, DataPointInfoType /*verb*/) {
     // RLS has flat struture
     return DataStatus::ListError;
   }
 
+  DataStatus DataPointRLS::Resolve(bool source, const std::list<DataPoint*>& urls) {
+    // Bulk operations not implemented yet
+    for (std::list<DataPoint*>::const_iterator i = urls.begin(); i != urls.end(); ++i) {
+      DataStatus res = (*i)->Resolve(source);
+      if (!res.Passed()) return source ? DataStatus::ReadResolveError : DataStatus::WriteResolveError;
+    }
+    return DataStatus::Success;
+  }
+
 } // namespace Arc
 
 Arc::PluginDescriptor PLUGINS_TABLE_NAME[] = {
