@@ -147,6 +147,7 @@ namespace Arc {
     // wait for open to complete
     if (!client->IsOpen_wait()) {
       logger.msg(ERROR, "Failed to open file %s", url.str());
+      reading = false;
       return DataStatus::ReadStartError;
     }
 
@@ -155,6 +156,7 @@ namespace Arc {
       FileInfo file;
       DataPointInfoType info(INFO_TYPE_CONTENT);
       if (!Stat(file, info))
+        reading = false;
         return DataStatus::ReadStartError;
     }
 
@@ -164,6 +166,7 @@ namespace Arc {
     if(!CreateThreadFunction(&DataPointXrootd::read_file_start, this)) {
       client->Close();
       reading = false;
+      buffer = NULL;
       return DataStatus::ReadStartError;
     }
 
@@ -173,13 +176,17 @@ namespace Arc {
   DataStatus DataPointXrootd::StopReading() {
     if (!reading) return DataStatus::ReadStopError;
     reading = false;
+    if (!buffer) return DataStatus::ReadStopError;
     if (!buffer->eof_read()) {
       buffer->error_read(true);      /* trigger transfer error */
       client->Close();
     }
     transfer_cond.wait();         /* wait till reading thread exited */
-    if (buffer->error_read())
+    if (buffer->error_read()) {
+      buffer = NULL;
       return DataStatus::ReadError;
+    }
+    buffer = NULL;
     return DataStatus::Success;
   }
 
