@@ -49,14 +49,14 @@ namespace Arc {
     }
 
     if(!factory_->load(FinderLoader::GetLibrariesList(), "HED:BrokerPlugin", name)) {
-      logger.msg(ERROR, "Broker plugin \"%s\" not found.", name);
+      logger.msg(DEBUG, "Broker plugin \"%s\" not found.", name);
       return NULL;
     }
 
     BrokerPlugin *p = factory_->GetInstance<BrokerPlugin>("HED:BrokerPlugin", name, &arg, false);
 
     if (!p) {
-      logger.msg(ERROR, "Broker %s could not be created", name);
+      logger.msg(DEBUG, "Unable to load BrokerPlugin (%s)", name);
       return NULL;
     }
 
@@ -66,7 +66,7 @@ namespace Arc {
     if (keep_ownership) {
       plugins.push_back(p);
     }
-    logger.msg(INFO, "Loaded Broker %s", name);
+    logger.msg(INFO, "Broker %s loaded", name);
     return p;
   }
 
@@ -160,8 +160,8 @@ namespace Arc {
                              EtTimePair("MinCPUTime", (int)t.ComputingShare->MinCPUTime.GetPeriod())};
 
       typedef std::pair<std::string, const ScalableTime<int>*> JobTimePair;
-      JobTimePair jobTime[] = {JobTimePair("TotalWallTime", &j->Resources.TotalWallTime),
-                               JobTimePair("TotalCPUTime", &j->Resources.TotalCPUTime)};
+      JobTimePair jobTime[] = {JobTimePair("IndividualWallTime", &j->Resources.IndividualWallTime),
+                               JobTimePair("IndividualCPUTime", &j->Resources.IndividualCPUTime)};
 
       int i = 0;
       for (; i < 4; i++) {
@@ -224,6 +224,28 @@ namespace Arc {
       }
     }
 
+    {
+      const int totalcputime = (j->Resources.TotalCPUTime.range.min > 0 ? j->Resources.TotalCPUTime.range.min : j->Resources.TotalCPUTime.range.max);
+      if (totalcputime != -1) {
+        if (t.ComputingShare->MaxTotalCPUTime.GetPeriod() != -1) {
+          if (t.ComputingShare->MaxTotalCPUTime.GetPeriod() < j->Resources.TotalCPUTime.range.min) {
+            logger.msg(VERBOSE, "Matchmaking, MaxTotalCPUTime problem, ExecutionTarget: %d (MaxTotalCPUTime), JobDescription: %d (TotalCPUTime)", t.ComputingShare->MaxTotalCPUTime.GetPeriod(), totalcputime);
+            return false;
+          }
+        }
+        else if (t.ComputingShare->MaxCPUTime.GetPeriod() != -1) {
+          const int slots = (j->Resources.SlotRequirement.NumberOfSlots > 0 ? j->Resources.SlotRequirement.NumberOfSlots : 1);
+          if (t.ComputingShare->MaxCPUTime.GetPeriod() < totalcputime/slots) {
+            logger.msg(VERBOSE, "Matchmaking, MaxTotalCPUTime problem, ExecutionTarget: %d (MaxCPUTime), JobDescription: %d (TotalCPUTime/NumberOfSlots)", t.ComputingShare->MaxTotalCPUTime.GetPeriod(), totalcputime/slots);
+            return false;
+          }
+        }
+        else {
+          logger.msg(VERBOSE, "Matchmaking, ExecutionTarget:  %s, MaxTotalCPUTime or MaxCPUTime not defined, assuming no CPU time limit", t.ComputingEndpoint->URLString);
+        }
+      }
+    }
+
     if (j->Resources.IndividualPhysicalMemory != -1) {
       if (t.ExecutionEnvironment->MainMemorySize != -1) {     // Example: 678
         if (t.ExecutionEnvironment->MainMemorySize < j->Resources.IndividualPhysicalMemory) {
@@ -393,7 +415,7 @@ namespace Arc {
       }
       if (t.ComputingShare->MaxSlotsPerJob != -1) {     // Example: 5656
         if (t.ComputingShare->MaxSlotsPerJob < j->Resources.SlotRequirement.NumberOfSlots) {
-          logger.msg(VERBOSE, "Matchmaking, MaxSlotsPerJob problem, ExecutionTarget: %d (MaxSlotsPerJob) JobDescription: %d (NumberOfProcesses)", t.ComputingManager->TotalSlots, j->Resources.SlotRequirement.NumberOfSlots);
+          logger.msg(VERBOSE, "Matchmaking, MaxSlotsPerJob problem, ExecutionTarget: %d (MaxSlotsPerJob) JobDescription: %d (NumberOfProcesses)", t.ComputingShare->MaxSlotsPerJob, j->Resources.SlotRequirement.NumberOfSlots);
           return false;
         }
       }
