@@ -7,73 +7,60 @@
 #include <string>
 
 #include <arc/URL.h>
-#include <arc/client/JobController.h>
+#include <arc/client/JobControllerPlugin.h>
 
 namespace Arc {
 
   class Logger;
+  class Endpoint;
   class UserConfig;
 
   /// % JobSupervisor class
   /**
-   * The JobSupervisor class is tool for loading JobController plugins
+   * The JobSupervisor class is tool for loading JobControllerPlugin plugins
    * for managing Grid jobs.
    **/
 
   class JobSupervisor {
   public:
-    /// Create a JobSupervisor object
-    /**
-     * Default constructor to create a JobSupervisor. Automatically
-     * loads JobController plugins based upon the input jobids.
-     *
-     * @param usercfg Reference to UserConfig object with information
-     * about user credentials and joblistfile.
-     *
-     * @param jobs List of jobs(jobid or job name) to be managed.
-     *
-     **/
-    JobSupervisor(const UserConfig& usercfg, const std::list<std::string>& jobs);
-
     /// Create a JobSupervisor
     /**
      * The list of Job objects passed to the constructor will be managed by this
-     * JobSupervisor, through the JobController class. It is important that the
-     * Flavour member of each Job object is set and correspond to the
-     * JobController plugin which are capable of managing that specific job. The
-     * JobController plugin will be loaded using the JobControllerLoader class,
-     * loading a plugin of type "HED:JobController" and name specified by the
-     * Flavour member, and the a reference to the UserConfig object usercfg will
+     * JobSupervisor, through the JobControllerPlugin class. It is important that the
+     * InterfaceName member of each Job object is set and names a interface
+     * supported by one of the available JobControllerPlugin plugins. The
+     * JobControllerPlugin plugin will be loaded using the JobControllerPluginLoader class,
+     * loading a plugin of type "HED:JobControllerPlugin" which supports the particular
+     * interface, and the a reference to the UserConfig object usercfg will
      * be passed to the plugin. Additionally a reference to the UserConfig
      * object usercfg will be stored, thus usercfg must exist throughout the
-     * scope of the created object. If the Flavour member of a Job object is
+     * scope of the created object. If the InterfaceName member of a Job object is
      * unset, a VERBOSE log message will be reported and that Job object will
-     * be ignored. If the JobController plugin for a given Flavour cannot be
-     * loaded, a WARNING log message will be reported and any Job object with
-     * that Flavour will be ignored. If loading of a specific plugin failed,
+     * be ignored. If the JobControllerPlugin plugin for a given interface cannot be
+     * loaded, a WARNING log message will be reported and any Job object requesting
+     * that interface will be ignored. If loading of a specific plugin failed,
      * that plugin will not be tried loaded for subsequent Job objects
      * requiring that plugin.
-     * Job objects, for which the corresponding JobController plugin loaded
-     * successfully, will be added to that plugin using the
-     * JobController::FillJobStore(const Job&) method.
+     * Job objects will be added to the corresponding JobControllerPlugin plugin, if
+     * loaded successfully.
      *
-     * @param usercfg UserConfig object to pass to JobController plugins and to
+     * @param usercfg UserConfig object to pass to JobControllerPlugin plugins and to
      *  use in member methods.
      * @param jobs List of Job objects which will be managed by the created
      *  object.
      **/
     JobSupervisor(const UserConfig& usercfg, const std::list<Job>& jobs = std::list<Job>());
 
-    ~JobSupervisor();
+    ~JobSupervisor() {}
 
     /// Add job
     /**
      * Add Job object to this JobSupervisor for job management. The Job
-     * object will be passed to the corresponding specialized JobController.
+     * object will be passed to the corresponding specialized JobControllerPlugin.
      *
      * @param job Job object to add for job management
      * @return true is returned if the passed Job object was added to the
-     *  underlying JobController, otherwise false is returned and a log
+     *  underlying JobControllerPlugin, otherwise false is returned and a log
      *  message emitted with the reason.
      **/
     bool AddJob(const Job& job);
@@ -81,17 +68,21 @@ namespace Arc {
     /// Get list of managed jobs
     /**
      * The list of jobs managed by this JobSupervisor is returned when
-     * calling this method.
+     * calling this method. If the includeJobsWithoutStatus argument is set to
+     * false, only Job objects with a valid State attribute is returned.
      *
+     * @param includeJobWithoutStatus specifies whether jobs with invalid status
+     *  should be included in the returned list
      * @return list of Job objects managed by this JobSupervisor
+     * @see JobState::operator bool
      **/
-    std::list<Job> GetJobs() const;
+    std::list<Job> GetJobs(bool includeJobsWithoutStatus = true) const;
 
     /// Update job information
     /**
      * When invoking this method the job information for the jobs managed by
      * this JobSupervisor will be updated. Internally, for each loaded
-     * JobController the JobController::GetJobInformation method will be
+     * JobControllerPlugin the JobControllerPlugin::UpdateJobs method will be
      * called, which will be responsible for updating job information.
      **/
     void Update();
@@ -101,8 +92,8 @@ namespace Arc {
      * This method retrieves output files of jobs managed by this JobSupervisor.
      *
      * Before identifying jobs for which to retrieve output files, the
-     * JobController::GetJobInformation method is called for each loaded
-     * JobController in order to retrieve the most up to date job information.
+     * JobControllerPlugin::UpdateJobs method is called for each loaded
+     * JobControllerPlugin in order to retrieve the most up to date job information.
      * If an empty status-filter is specified, all jobs managed by this
      * JobSupervisor will be considered for retrieval, except jobs in the
      * undefined state (see JobState). If the status-filter is not empty, then
@@ -119,66 +110,29 @@ namespace Arc {
      * 'force' argument is set to 'true', and a download directory for a
      * given job already exist it will be overwritten, otherwise files for
      * that job will not be downloaded. This method calls the
-     * JobController::GetJob method in order to download jobs, and if a job
+     * JobControllerPlugin::GetJob method in order to download jobs, and if a job
      * is successfully retrieved the job ID will be appended to the
      * 'retrievedJobs' list. If all jobs are successfully retrieved this
      * method returns true, otherwise false.
      *
-     * @param statusfilter list of job status used for filtering jobs.
      * @param downloaddir specifies the path to in which job download
      *   directories will be located.
      * @param usejobname specifies whether to use the job name or job ID as
      *   directory name to store job output files in.
      * @param force indicates whether existing job directories should be
      *   overwritten or not.
-     * @param retrievedJobs job IDs of successfully retrieved jobs will be
-     *   appended to this list.
-     * @see JobController::GetJob.
+     * @see JobControllerPlugin::RetrieveJob.
      * @return true if all jobs are successfully retrieved, otherwise false.
      **/
-    bool Get(const std::list<std::string>& statusfilter, const std::string& downloaddir,
-             bool usejobname, bool force, std::list<URL>& retrievedJobs);
-
-    /// Kill jobs
-    /**
-     * This method kills jobs managed by this JobSupervisor.
-     *
-     * Before identifying jobs to kill, the JobController::GetJobInformation
-     * method is called for each loaded JobController in order to retrieve
-     * the most up to date job information.
-     *
-     * Since jobs in the JobState::DELETED, JobState::FINISHED,
-     * JobState::KILLED or JobState::FAILED states is already in a terminal
-     * state, a terminate action will not be send for those. Also no
-     * terminate action will be send for jobs in the JobState::UNDEFINED
-     * state, since job information is not available.
-     * If the status-filter is non-empty, a terminate action will only be
-     * send to jobs with a general or specific state (see JobState)
-     * identical to any of the entries in the status-filter, excluding the
-     * states mentioned above.
-     *
-     * For each job to be killed, the specialized JobController::CancelJob
-     * method is called and is responsible for terminating the given job. If
-     * the method fails to terminate a job, this method will return false,
-     * otherwise true is returned. The job ID of successfully terminated
-     * jobs will be appended to the passed killedJobs list.
-     *
-     * @param statusfilter list of job status used for filtering jobs.
-     * @param killedJobs list of URLs which to append job IDs of
-     *  successfully terminated jobs to.
-     * @see JobController::CancelJob.
-     * @return true if all jobs terminated successfully, otherwise false.
-     **/
-    bool Kill(const std::list<std::string>& statusfilter, std::list<URL>& killedJobs);
+    bool Retrieve(const std::string& downloaddirprefix, bool usejobname, bool force, std::list<std::string>& downloaddirectories);
 
     /// Renew job credentials
     /**
-     * This method renew credentials of the jobs managed by this
-     * JobSupervisor.
+     * This method will renew credentials of jobs managed by this JobSupervisor.
      *
      * Before identifying jobs for which to renew credentials, the
-     * JobController::GetJobInformation method is called for each loaded
-     * JobController in order to retrieve the most up to date job
+     * JobControllerPlugin::UpdateJobs method is called for each loaded
+     * JobControllerPlugin in order to retrieve the most up to date job
      * information.
      *
      * Since jobs in the JobState::DELETED, JobState::FINISHED or
@@ -193,29 +147,26 @@ namespace Arc {
      * excluding the already filtered states as mentioned above.
      *
      * For each job for which to renew credentials, the specialized
-     * JobController::RenewJob method is called and is responsible for
+     * JobControllerPlugin::RenewJob method is called and is responsible for
      * renewing the credentials for the given job. If the method fails to
-     * renew job credentials, this method will return false,
-     * otherwise true is returned. The job ID of successfully renewed jobs
-     * will be appended to the passed renewedJobs list.
+     * renew any job credentials, this method will return false (otherwise
+     * true), and the job ID (IDFromEndpoint) of such jobs is appended to the
+     * notrenewed list. The job ID of successfully renewed jobs will be appended
+     * to the passed renewed list.
      *
-     * @param statusfilter list of job status used for filtering jobs.
-     * @param renewedJobs list of URLs which to append job IDs to, of
-     *  jobs for which credentials was successfully renewed.
-     * @see JobController::RenewJob.
-     * @return true if credentials for all jobs were successfully renewed,
-     *  otherwise false.
+     * @return false if any call to JobControllerPlugin::RenewJob fails, true
+     *  otherwise.
+     * @see JobControllerPlugin::RenewJob.
      **/
-    bool Renew(const std::list<std::string>& statusfilter, std::list<URL>& renewedJobs);
+    bool Renew();
 
-    /// Resume job
+    /// Resume jobs by status
     /**
-     * This method resumes jobs managed by this
-     * JobSupervisor.
+     * This method resumes jobs managed by this JobSupervisor.
      *
      * Before identifying jobs to resume, the
-     * JobController::GetJobInformation method is called for each loaded
-     * JobController in order to retrieve the most up to date job
+     * JobControllerPlugin::UpdateJobs method is called for each loaded
+     * JobControllerPlugin in order to retrieve the most up to date job
      * information.
      *
      * Since jobs in the JobState::DELETED, JobState::FINISHED or
@@ -228,19 +179,17 @@ namespace Arc {
      * to any of the entries in the status-filter will be resumed, excluding
      * the already filtered states as mentioned above.
      *
-     * For each job to resume, the specialized JobController::ResumeJob
+     * For each job to resume, the specialized JobControllerPlugin::ResumeJob
      * method is called and is responsible for resuming the particular job.
      * If the method fails to resume a job, this method will return false,
      * otherwise true is returned. The job ID of successfully resumed jobs
      * will be appended to the passed resumedJobs list.
      *
-     * @param statusfilter list of job status used for filtering jobs.
-     * @param resumeJobs list of URLs which to append job IDs to, of jobs
-     *  which was successfully resumed.
-     * @see JobController::ResumeJob.
-     * @return true if all jobs were successfully resumed, otherwise false.
+     * @return false if any call to JobControllerPlugin::ResumeJob fails, true
+     *  otherwise.
+     * @see JobControllerPlugin::ResumeJob.
      **/
-    bool Resume(const std::list<std::string>& statusfilter, std::list<URL>& resumedJobs);
+    bool Resume();
 
     /// Resubmit jobs
     /**
@@ -249,8 +198,8 @@ namespace Arc {
      * if successful a new job will be submitted.
      *
      * Before identifying jobs to be resubmitted, the
-     * JobController::GetJobInformation method is called for each loaded
-     * JobController in order to retrieve the most up to date job information.
+     * JobControllerPlugin::UpdateJobs method is called for each loaded
+     * JobControllerPlugin in order to retrieve the most up to date job information.
      * If an empty status-filter is specified, all jobs managed by this
      * JobSupervisor will be considered for resubmission, except jobs in the
      * undefined state (see JobState). If the status-filter is not empty, then
@@ -292,17 +241,14 @@ namespace Arc {
      * resubmittedJobs list - it will not be added to this JobSupervisor. The
      * method returns false if ERRORs were reported otherwise true is returned.
      *
-     * @param statusfilter list of job status used for filtering jobs.
      * @param destination specifies how target destination should be determined
      *  (1 = same target, 2 = not same, any other = any target).
      * @param resubmittedJobs list of Job objects which resubmitted jobs will be
      *  appended to.
-     * @param notresubmitted list of URL objects which the IDFromEndpoint URL
-     *  will be appended to.
+     * @param TODO
      * @return false if any error is encountered, otherwise true.
      **/
-    bool Resubmit(const std::list<std::string>& statusfilter, int destination,
-                  std::list<Job>& resubmittedJobs, std::list<URL>& notresubmitted);
+    bool Resubmit(int destination, const std::list<Endpoint>&, std::list<Job>& resubmittedJobs, const std::list<std::string>& = std::list<std::string>());
 
     /// Migrate jobs
     /**
@@ -312,8 +258,8 @@ namespace Arc {
      * description.
      *
      * Before identifying jobs to be migrated, the
-     * JobController::GetJobInformation method is called for each loaded
-     * JobController in order to retrieve the most up to date job information.
+     * JobControllerPlugin::UpdateJobs method is called for each loaded
+     * JobControllerPlugin in order to retrieve the most up to date job information.
      * Only jobs for which the State member of the Job object has the value
      * JobState::QUEUEING, will be considered for migration. Furthermore the job
      * description must be obtained (either locally or remote) and successfully
@@ -333,10 +279,10 @@ namespace Arc {
      * will be appended to the notmigrated list and then false will be returned.
      *
      * When the above checks have been carried out successfully, the following
-     * is done for each job considered for migration. The ActivityOldId member
+     * is done for each job considered for migration. The ActivityOldID member
      * of the Identification member in the job description will be set to that
      * of the Job object, and the IDFromEndpoint URL will be appended to
-     * ActivityOldId member of the job description. After that the Broker object
+     * ActivityOldID member of the job description. After that the Broker object
      * will be used to find a suitable ExecutionTarget object, and if found a
      * migrate request will tried sent using the ExecutionTarget::Migrate
      * method, passing the UserConfig object of this class. The passed
@@ -353,84 +299,82 @@ namespace Arc {
      *  service fails to cancel the existing queuing job.
      * @param migratedJobs list of Job objects which migrated jobs will be
      *  appended to.
-     * @param notmigrated list of URL objects which the IDFromEndpoint URL
-     *  will be appended to.
+     * @param TODO
      * @return false if any error is encountered, otherwise true.
      **/
-    bool Migrate(bool forcemigration,
-                 std::list<Job>& migratedJobs, std::list<URL>& notmigrated);
+    bool Migrate(bool forcemigration, const std::list<Endpoint>&, std::list<Job>& migratedJobs, const std::list<std::string>& = std::list<std::string>());
 
     /// Cancel jobs
     /**
-     * This method will request cancellation of jobs, identified by their
-     * IDFromEndpoint member, for which that URL is equal to any in the jobids
-     * list. Only jobs corresponding to a Job object managed by this
-     * JobSupervisor will be considered for cancellation. Job objects not in a
-     * valid state (see JobState) will not be considered, and the IDFromEndpoint
-     * URLs of those objects will be appended to the notcancelled URL list. For
-     * jobs not in a finished state (see JobState::IsFinished), the
-     * JobController::Cancel method will be called, passing the corresponding
-     * Job object, in order to cancel the job. If the JobController::Cancel call
-     * succeeds or if the job is in a finished state the IDFromEndpoint URL will
-     * be appended to the list to be returned. If the JobController::Cancel call
-     * fails the IDFromEndpoint URL is appended to the notkilled URL list.
+     * This method cancels jobs managed by this JobSupervisor.
      *
-     * Note: If there is any URL in the jobids list for which there is no
-     * corresponding Job object, then the size of the returned list plus the
-     * size of the notcancelled list will not equal that of the jobids list.
+     * Before identifying jobs to cancel, the JobControllerPlugin::UpdateJobs
+     * method is called for each loaded JobControllerPlugin in order to retrieve
+     * the most up to date job information.
      *
-     * @param jobids List of Job::IDFromEndpoint URL objects for which a
-     *  corresponding job, managed by this JobSupervisor should be cancelled.
-     * @param notcancelled List of Job::IDFromEndpoint URL objects for which the
-     *  corresponding job were not cancelled.
-     * @return The list of Job::IDFromEndpoint URL objects of successfully
-     *  cancelled or finished jobs is returned.
+     * Since jobs in the JobState::DELETED, JobState::FINISHED,
+     * JobState::KILLED or JobState::FAILED states is already in a terminal
+     * state, a cancel request will not be send for those. Also no
+     * request will be send for jobs in the JobState::UNDEFINED state, since job
+     * information is not available. If the status-filter is non-empty, a
+     * cancel request will only be send to jobs with a general or specific state
+     * (see JobState) identical to any of the entries in the status-filter,
+     * excluding the states mentioned above.
+     *
+     * For each job to be cancelled, the specialized JobControllerPlugin::CancelJob
+     * method is called and is responsible for cancelling the given job. If the
+     * method fails to cancel a job, this method will return false (otherwise
+     * true), and the job ID (IDFromEndpoint) of such jobs is appended to the
+     * notcancelled list. The job ID of successfully cancelled jobs will be
+     * appended to the passed cancelled list.
+     *
+     * @return false if any call to JobControllerPlugin::CancelJob failed, true
+     *  otherwise.
+     * @see JobControllerPlugin::CancelJob.
      **/
-    std::list<URL> Cancel(const std::list<URL>& jobids, std::list<URL>& notcancelled);
+    bool Cancel();
 
     /// Clean jobs
     /**
-     * This method will request cleaning of jobs, identified by their
-     * IDFromEndpoint member, for which that URL is equal to any in the jobids
-     * list. Only jobs corresponding to a Job object managed by this
-     * JobSupervisor will be considered for cleaning. Job objects not in a valid
-     * state (see JobState) will not be considered, and the IDFromEndpoint URLs
-     * of those objects will be appended to the notcleaned URL list, otherwise
-     * the JobController::Clean method will be called, passing the corresponding
-     * Job object, in order to clean the job. If that method fails the
-     * IDFromEndpoint URL of the Job object will be appended to the notcleaned
-     * URL list, and if it succeeds the IDFromEndpoint URL will be appended
-     * to the list of URL objects to be returned.
+     * This method removes from services jobs managed by this JobSupervisor.
+     * Before cleaning jobs, the JobController::GetInformation method is called in
+     * order to update job information, and that jobs are selected by job status
+     * instead of by job IDs. The status list argument should contain states
+     * for which cleaning of job in any of those states should be carried out.
+     * The states are compared using both the JobState::operator() and
+     * JobState::GetGeneralState() methods. If the status list is empty, all
+     * jobs will be selected for cleaning.
      *
-     * Note: If there is any URL in the jobids list for which there is no
-     * corresponding Job object, then the size of the returned list plus the
-     * size of the notcleaned list will not equal that of the jobids list.
-     *
-     * @param jobids List of Job::IDFromEndpoint URL objects for which a
-     *  corresponding job, managed by this JobSupervisor should be cleaned.
-     * @param notcleaned List of Job::IDFromEndpoint URL objects for which the
-     *  corresponding job were not cleaned.
-     * @return The list of Job::IDFromEndpoint URL objects of successfully
-     *  cleaned jobs is returned.
+     * @return false if calls to JobControllerPlugin::CleanJob fails, true otherwise.
      **/
-    std::list<URL> Clean(const std::list<URL>& jobids, std::list<URL>& notcleaned);
+    bool Clean();
 
-    /// Get list of JobControllers
-    /**
-     * Method to get the list of JobControllers loaded by constructor.
-     *
-     **/
-    const std::list<JobController*>& GetJobControllers() {
-      return loader.GetJobControllers();
-    }
+    const std::list<Job>& GetAllJobs() const { return jobs; }
+    std::list<Job> GetSelectedJobs() const;
 
-    bool JobsFound() const;
+    void SelectValid();
+    void SelectByStatus(const std::list<std::string>& status);
+    void SelectByID(const std::list<URL>& ids);
+
+    void ClearSelection();
+    
+    const std::list<URL>& GetIDsProcessed() const { return processed; }
+    const std::list<URL>& GetIDsNotProcessed() const { return notprocessed; }
 
   private:
-    static Logger logger;
-    std::map<std::string, JobController*> loadedJCs;
-    JobControllerLoader loader;
     const UserConfig& usercfg;
+
+    std::list<Job> jobs;
+    // Selected and non-selected jobs.
+    typedef std::map<JobControllerPlugin*, std::pair< std::list<Job*>, std::list<Job*> > > JobSelectionMap;
+    JobSelectionMap jcJobMap;
+    std::map<std::string, JobControllerPlugin*> loadedJCs;
+
+    std::list<URL> processed, notprocessed;
+
+    JobControllerPluginLoader loader;
+
+    static Logger logger;
   };
 
 } //namespace ARC
