@@ -102,7 +102,6 @@ namespace Arc {
       LESSTHANOREQUAL = 5 /**< see #operator<= */
     };
 
-#ifndef SWIG
     /// Convert a #ComparisonOperatorEnum value to a comparison method pointer.
     /**
      * The passed #ComparisonOperatorEnum will be converted to a
@@ -116,7 +115,6 @@ namespace Arc {
      * @return A method pointer to a comparison method is returned.
      **/
     static ComparisonOperator convert(const ComparisonOperatorEnum& co);
-#endif
 
     /// Indicates whether the object is empty.
     /**
@@ -266,7 +264,10 @@ namespace Arc {
      **/
     const std::string& getVersion() const { return version; }
 
-#ifndef SWIG
+    const std::list<std::string>& getOptions() const { return option; }
+
+    void addOption(const std::string& opt) { option.push_back(opt); }
+
     /// Convert Software::ComparisonOperator to a string.
     /**
      * This method is not available in language bindings created by
@@ -277,7 +278,6 @@ namespace Arc {
      *         Software::ComparisonOperator is returned.
      **/
     static std::string toString(ComparisonOperator co);
-#endif
 
     /// Tokens used to split version string.
     /**
@@ -291,6 +291,7 @@ namespace Arc {
     std::string name;
     std::string version;
     std::list<std::string> tokenizedVersion;
+    std::list<std::string> option;
 
     static Logger logger;
   };
@@ -319,7 +320,6 @@ namespace Arc {
      * requirements.
      **/
     SoftwareRequirement() {}
-#ifndef SWIG
     /// Create a SoftwareRequirement object.
     /**
      * The created SoftwareRequirement object will contain one
@@ -335,9 +335,7 @@ namespace Arc {
      * @param swComOp is the Software::ComparisonOperator of the
      *        requirement to add.
      **/
-    SoftwareRequirement(const Software& sw,
-                        Software::ComparisonOperator swComOp = &Software::operator==);
-#endif
+    SoftwareRequirement(const Software& sw, Software::ComparisonOperator swComOp);
 
     /// Create a SoftwareRequirement object.
     /**
@@ -349,8 +347,7 @@ namespace Arc {
      * @param co is the Software::ComparisonOperatorEnum of the
      *        requirement to add.
      **/
-    SoftwareRequirement(const Software& sw,
-                        Software::ComparisonOperatorEnum co);
+    SoftwareRequirement(const Software& sw, Software::ComparisonOperatorEnum co = Software::EQUAL);
 
     /// Assignment operator.
     /**
@@ -371,7 +368,6 @@ namespace Arc {
      **/
     SoftwareRequirement(const SoftwareRequirement& sr) { *this = sr; }
 
-#ifndef SWIG
     /// Add a Software object a corresponding comparion operator to this object.
     /**
      * Adds software name and version to list of requirements and
@@ -386,8 +382,8 @@ namespace Arc {
      *        to add as part of a requirement, the default operator
      *        will be Software::operator==().
      **/
-    void add(const Software& sw, Software::ComparisonOperator swComOp = &Software::operator==);
-#endif
+    void add(const Software& sw, Software::ComparisonOperator swComOp);
+
     /// Add a Software object a corresponding comparion operator to this object.
     /**
      * Adds software name and version to list of requirements and
