@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <stdlib.h>
@@ -18,7 +22,7 @@ public:
   ~JobDescriptionParserTest() { delete jdpl; }
 
   void setUp() {}
-  void tearDown() {}
+  void tearDown() { Arc::ThreadInitializer().waitExit(); }
 
   void LoadTest();
 
@@ -28,8 +32,6 @@ private:
 };
 
 JobDescriptionParserTest::JobDescriptionParserTest() : jdp(NULL) {
-  Arc::SetEnv("ARC_PLUGIN_PATH", ".libs");
-
   jdpl = new Arc::JobDescriptionParserLoader();
 }
 
