@@ -1,9 +1,14 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <list>
 
 #include <arc/client/Software.h>
 #include <arc/client/ExecutionTarget.h>
+#include <arc/Thread.h>
 
 #define SV Arc::Software
 #define SR Arc::SoftwareRequirement
@@ -28,7 +33,7 @@ class SoftwareTest
 public:
   SoftwareTest() {}
   void setUp() {}
-  void tearDown() {}
+  void tearDown() { Arc::ThreadInitializer().waitExit(); }
   void EqualityTest();
   void ComparisonTest();
   void BasicRequirementsTest();
@@ -123,7 +128,7 @@ void SoftwareTest::BasicRequirementsTest() {
 }
 
 void SoftwareTest::RequirementsAndTest() {
-  SR sr; sr.add(SV("A-1.03")); sr.add(SV("B-2.12"));
+  SR sr; sr.add(SV("A-1.03"), SV::EQUAL); sr.add(SV("B-2.12"), SV::EQUAL);
 
   versions.push_back(SV("A-1.03"));
   versions.push_back(SV("B-2.12"));
@@ -144,7 +149,7 @@ void SoftwareTest::RequirementsAssignmentTest() {
   versions.push_back(SV("A-2.2"));
   versions.push_back(SV("A-2.3"));
 
-  sr.add(SV("A-1.3"));
+  sr.add(SV("A-1.3"), SV::EQUAL);
   CPPUNIT_ASSERT(sr.isSatisfied(versions));
   CPPUNIT_ASSERT(sr.selectSoftware(versions));
   CPPUNIT_ASSERT_EQUAL(1, (int) sr.getSoftwareList().size());
@@ -152,13 +157,13 @@ void SoftwareTest::RequirementsAssignmentTest() {
   CPPUNIT_ASSERT(sr.isResolved());
   sr.clear();
 
-  sr.add(SV("A-1.2"));
+  sr.add(SV("A-1.2"), SV::EQUAL);
   CPPUNIT_ASSERT(!sr.isSatisfied(versions));
   CPPUNIT_ASSERT(!sr.selectSoftware(versions));
   sr.clear();
   
-  sr.add(SV("A-1.3"));
-  sr.add(SV("A-2.4"));
+  sr.add(SV("A-1.3"), SV::EQUAL);
+  sr.add(SV("A-2.4"), SV::EQUAL);
   CPPUNIT_ASSERT(!sr.isSatisfied(versions));
   CPPUNIT_ASSERT(!sr.selectSoftware(versions));
   CPPUNIT_ASSERT_EQUAL(2, (int) sr.getSoftwareList().size());
