@@ -24,7 +24,7 @@ int main(int argc, char **argv) {
 
   std::string requested_format = "";
   options.AddOption('f', "format",
-                    istring("define the requested format (nordugrid:jsdl, egee:jdl, nordugrid:xrsl)"),
+                    istring("define the requested format (nordugrid:jsdl, egee:jdl, nordugrid:xrsl, emies:adl)"),
                     istring("format"),
                     requested_format);
 
@@ -69,7 +69,7 @@ int main(int argc, char **argv) {
     else
       original_description = (*it);
 
-    if (requested_format == "egee:jdl" || requested_format == "nordugrid:jsdl" || requested_format == "nordugrid:xrsl" || requested_format == "") {
+    if (requested_format == "egee:jdl" || requested_format == "nordugrid:jsdl" || requested_format == "nordugrid:xrsl" || requested_format == "emies:adl" || requested_format == "") {
       if (show_original_description) {
         std::cout << std::endl << Arc::IString(" [ Parsing the original text ] ") << std::endl << std::endl;
         std::cout << original_description << std::endl;
@@ -87,6 +87,8 @@ int main(int argc, char **argv) {
         
         jds.front().UnParse(jobdesc, "egee:jdl");
         std::cout << std::endl << Arc::IString(" [ egee:jdl ] ")       << std::endl << jobdesc << std::endl;
+        jds.front().UnParse(jobdesc, "emies:adl");
+        std::cout << std::endl << Arc::IString(" [ emies:adl ] ")       << std::endl << jobdesc << std::endl;
         jds.front().UnParse(jobdesc, "nordugrid:jsdl");
         std::cout << std::endl << Arc::IString(" [ nordugrid:jsdl ] ") << std::endl << jobdesc << std::endl;
         jds.front().UnParse(jobdesc, "nordugrid:xrsl");
