@@ -232,16 +232,6 @@ namespace Arc {
     : locale(locale),
       format(LongFormat) {}
 
-  LogDestination::LogDestination(const LogDestination&) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
-  void LogDestination::operator=(const LogDestination&) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
   void LogDestination::setFormat(const LogFormat& newformat) {
     format = newformat;
   }
@@ -267,18 +257,6 @@ namespace Arc {
     EnvLockUnwrap(true);
   }
 
-  LogStream::LogStream(const LogStream&)
-    : LogDestination(),
-      destination(std::cerr) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
-  void LogStream::operator=(const LogStream&) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
   LogFile::LogFile(const std::string& path)
     : LogDestination(),
       path(path),
@@ -332,23 +310,6 @@ namespace Arc {
     }
   }
 
-  LogFile::LogFile(void)
-    : LogDestination(), maxsize(-1), backups(-1), reopen(false) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
-  LogFile::LogFile(const LogFile&)
-    : LogDestination(), maxsize(-1), backups(-1), reopen(false) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
-  void LogFile::operator=(const LogFile&) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
   LogFile::operator bool(void) {
     Glib::Mutex::Lock lock(mutex);
     return (reopen)?(!path.empty()):destination.is_open();
@@ -515,10 +476,11 @@ namespace Arc {
 
   void Logger::deleteDestinations(void) {
     Glib::Mutex::Lock lock(mutex);
-    std::list<LogDestination*> destinations = getContext().destinations;
+    std::list<LogDestination*>& destinations = getContext().destinations;
     for(std::list<LogDestination*>::iterator dest = destinations.begin();
                             dest != destinations.end();) {
       delete *dest;
+      *dest = NULL;
       dest = destinations.erase(dest);
     }
   }
@@ -585,16 +547,6 @@ namespace Arc {
     // addDestination(cerr);
   }
 
-  Logger::Logger(const Logger& logger):context(logger.context) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
-  void Logger::operator=(const Logger&) {
-    // Executing this code should be impossible!
-    exit(EXIT_FAILURE);
-  }
-
   std::string Logger::getDomain() {
     return domain;
   }
