@@ -199,73 +199,35 @@ namespace Arc {
     }
   };
 
+  /// Thread-safe counter with capability to wait for zero value.
+  /// It is extendable through re-implementation of virtual methods.
   class SimpleCounter {
   private:
     Glib::Cond cond_;
     Glib::Mutex lock_;
     int count_;
   public:
-    SimpleCounter(void)
-      : count_(0) {}
-    ~SimpleCounter(void) {
-      /* race condition ? */
-      lock_.lock();
-      count_ = 0;
-      cond_.broadcast();
-      lock_.unlock();
-    }
-    int inc(void) {
-      lock_.lock();
-      ++count_;
-      int r = count_;
-      lock_.unlock();
-      return r;
-    }
-    int dec(void) {
-      lock_.lock();
-      if(count_ > 0) --count_;
-      if(count_ <= 0) cond_.signal();
-      int r = count_;
-      lock_.unlock();
-      return r;
-    }
-    int get(void) {
-      lock_.lock();
-      int r = count_;
-      lock_.unlock();
-      return r;
-    }
-    int set(int v) {
-      lock_.lock();
-      count_ = v;
-      if(count_ <= 0) cond_.signal();
-      int r = count_;
-      lock_.unlock();
-      return r;
-    }
-    void wait(void) {
-      lock_.lock();
-      while (count_ > 0) cond_.wait(lock_);
-      lock_.unlock();
-    }
-    /** Wait for condition no longer than t milliseconds */
-    bool wait(int t) {
-      lock_.lock();
-      Glib::TimeVal etime;
-      etime.assign_current_time();
-      etime.add_milliseconds(t);
-      bool res(true);
-      while (count_ > 0) {
-        res = cond_.timed_wait(lock_, etime);
-        if (!res)
-          break;
-      }
-      lock_.unlock();
-      return res;
-    }
-    // This method is meant to be used only after fork.
-    // It resets state of all internal locks and variables.
-    void forceReset(void) {
+    SimpleCounter(void) : count_(0) {}
+    virtual ~SimpleCounter(void);
+    /// Increment value of counter.
+    /** Returns new value. */
+    virtual int inc(void);
+    /// Decrement value of counter.
+    /** Returns new value. Does not go below 0 value. */
+    virtual int dec(void);
+    /// Returns current value of counter.
+    virtual int get(void) const;
+    /// Set value of counter.
+    /** Returns new value. */
+    virtual int set(int v);
+    /// Wait for zero condition.
+    virtual void wait(void) const;
+    /// Wait for zero condition no longer than t milliseconds.
+    /** If t is negative - wait forever. */
+    virtual bool wait(int t) const;
+    /// This method is meant to be used only after fork.
+    /** It resets state of all internal locks and variables. */
+    virtual void forceReset(void) {
       lock_.unlock();
     }
   };
@@ -357,6 +319,175 @@ namespace Arc {
     };
   };
 
+  /// Helper class for ThreadedPointer
+  class ThreadedPointerBase {
+  private:
+    Glib::Mutex lock_;
+    Glib::Cond cond_;
+    unsigned int cnt_;
+    void *ptr_;
+    bool released_;
+    ThreadedPointerBase(ThreadedPointerBase&) {};
+    ~ThreadedPointerBase(void);
+  public:
+    ThreadedPointerBase(void *p);
+    ThreadedPointerBase* add(void);
+    void* rem(void);
+    void* ptr(void) const { return ptr_; };
+    void rel(void) { released_ = true; };
+    unsigned int cnt(void) const { return cnt_; };
+    void lock(void) { lock_.lock(); };
+    void unlock(void) { lock_.unlock(); };
+    void wait(void) { cond_.wait(lock_); };
+    bool wait(Glib::TimeVal etime) {
+      return cond_.timed_wait(lock_,etime);
+    };
+  };
+
+  /// Wrapper for pointer with automatic destruction and mutiple references
+  /** See for CountedPointer for description. Differently from CountedPointer
+     this class provides thread safe destruction of refered object. But the
+     instance of ThreadedPointer itself is not thread safe. Hence it is
+     advisable to use different instances in different threads. */
+  template<typename T>
+  class ThreadedPointer {
+  private:
+    ThreadedPointerBase *object_;
+  public:
+    ThreadedPointer(T *p)
+      : object_(new ThreadedPointerBase(p)) {}
+    ThreadedPointer(const ThreadedPointer<T>& p)
+      : object_(p.object_->add()) {}
+    ThreadedPointer(void)
+      : object_(new ThreadedPointerBase(NULL)) {}
+    ~ThreadedPointer(void) {
+      delete((T*)(object_->rem()));
+    }
+    ThreadedPointer<T>& operator=(T *p) {
+      if (p != object_->ptr()) {
+        delete((T*)(object_->rem()));
+        object_ = new ThreadedPointerBase(p);
+      }
+      return *this;
+    }
+    ThreadedPointer<T>& operator=(const ThreadedPointer<T>& p) {
+      if (p.object_->ptr() != object_->ptr()) {
+        delete((T*)(object_->rem()));
+        object_ = p.object_->add();
+      }
+      return *this;
+    }
+    /// For refering wrapped object
+    T& operator*(void) const {
+      return *(T*)(object_->ptr());
+    }
+    /// For refering wrapped object
+    T* operator->(void) const {
+      return (T*)(object_->ptr());
+    }
+    /// Returns false if pointer is NULL and true otherwise.
+    operator bool(void) const {
+      return ((object_->ptr()) != NULL);
+    }
+    /// Returns true if pointer is NULL and false otherwise.
+    bool operator!(void) const {
+      return ((object_->ptr()) == NULL);
+    }
+    /// Returns true if pointers are equal
+    bool operator==(const ThreadedPointer& p) const {
+      return ((T*)(object_->ptr()) == (T*)(p.object_->ptr()));
+    }
+    /// Returns true if pointers are not equal
+    bool operator!=(const ThreadedPointer& p) const {
+      return ((T*)(object_->ptr()) != (T*)(p.object_->ptr()));
+    }
+    /// Comparison operator
+    bool operator<(const ThreadedPointer& p) const {
+      return ((T*)(object_->ptr()) < (T*)(p.object_->ptr()));
+    }
+    /// Cast to original pointer
+    T* Ptr(void) const {
+      return (T*)(object_->ptr());
+    }
+    /// Release refered object so that it can be passed to other container
+    /** After Release() is called refered object is will not be destroyed
+       automatically anymore. */
+    T* Release(void) {
+      T* tmp = (T*)(object_->ptr());
+      object_->rel();
+      return tmp;
+    }
+    /// Returns number of ThreadedPointer instances refering to underlying object
+    unsigned int Holders(void) {
+      return object_->cnt();
+    }
+    /// Waits till number of ThreadedPointer instances <= minThr or >= maxThr
+    /* Returns current number of instances. */
+    unsigned int WaitOutRange(unsigned int minThr, unsigned int maxThr) {
+      unsigned int r = 0;
+      object_->lock();
+      for(;;) {
+        r = object_->cnt();
+        if(r <= minThr) break;
+        if(r >= maxThr) break;
+        object_->wait();
+      };
+      object_->unlock();
+      return r;
+    }
+    /// Waits till number of ThreadedPointer instances <= minThr or >= maxThr
+    /** Waits no longer than timeout milliseconds. If timeout is negative -
+       wait forever. Returns current number of instances. */
+    unsigned int WaitOutRange(unsigned int minThr, unsigned int maxThr, int timeout) {
+      if(timeout < 0) return WaitOutRange(minThr, maxThr);
+      unsigned int r = 0;
+      object_->lock();
+      Glib::TimeVal etime;
+      etime.assign_current_time();
+      etime.add_milliseconds(timeout);
+      for(;;) {
+        r = object_->cnt();
+        if(r <= minThr) break;
+        if(r >= maxThr) break;
+        if(!object_->wait(etime)) break;
+      };
+      object_->unlock();
+      return r;
+    }
+    /// Waits till number of ThreadedPointer instances >= minThr and <= maxThr
+    /* Returns current number of instances. */
+    unsigned int WaitInRange(unsigned int minThr, unsigned int maxThr) {
+      unsigned int r = 0;
+      object_->lock();
+      for(;;) {
+        r = object_->cnt();
+        if((r >= minThr) && (r <= maxThr)) break;
+        object_->wait();
+      };
+      object_->unlock();
+      return r;
+    }
+    /// Waits till number of ThreadedPointer instances >= minThr and <= maxThr
+    /** Waits no longer than timeout milliseconds. If timeout is negative -
+       wait forever. Returns current number of instances. */
+    unsigned int WaitInRange(unsigned int minThr, unsigned int maxThr, int timeout) {
+      if(timeout < 0) return WaitInRange(minThr, maxThr);
+      unsigned int r = 0;
+      object_->lock();
+      Glib::TimeVal etime;
+      etime.assign_current_time();
+      etime.add_milliseconds(timeout);
+      for(;;) {
+        r = object_->cnt();
+        if((r >= minThr) && (r <= maxThr)) break;
+        if(!object_->wait(etime)) break;
+      };
+      object_->unlock();
+      return r;
+    }
+
+  };
+
   /// This class is a set of conditions, mutexes, etc. conveniently
   /// exposed to monitor running child threads and to wait till
   /// they exit. There are no protections against race conditions.
@@ -403,6 +534,10 @@ namespace Arc {
     // This method is meant to be used only after fork.
     // It resets state of all internal locks and variables.
     void forceReset(void);
+    // Wait for all known threads to exit.
+    // It can be used before exiting application to make 
+    // sure no concurent threads are running during cleanup.
+    void waitExit(void);
   };
 
   // This is done intentionally to make sure glibmm is
