@@ -749,7 +749,7 @@ namespace Arc {
     if (!commonlocoptions.empty())
       urlstr += ';' + OptionString(commonlocoptions, ';');
 
-    if (!username.empty() || !passwd.empty() || !locations.empty())
+    if (!username.empty() || !passwd.empty() || !locations.empty() || !commonlocoptions.empty())
       urlstr += '@';
 
     if (!host.empty()) {
@@ -1153,6 +1153,10 @@ namespace Arc {
       return true;
     }
 
+    if (protocol == "ldap" && str[0] == '/') { // For LDAP there is no starting slash (/)
+      str.erase(0, 1);
+    }
+
     return path == str;
   }
 
