@@ -155,6 +155,7 @@ namespace Arc {
                          initializeCredentialsType initializeCredentials,
                          bool loadSysConfig)
     : timeout(0), keySize(0), ok(false), initializeCredentials(initializeCredentials)  {
+    setDefaults();
     if (loadSysConfig) {
 #ifndef WIN32
       if (Glib::file_test(SYSCONFIG, Glib::FILE_TEST_IS_REGULAR)) {
@@ -202,8 +203,6 @@ namespace Arc {
     }
 
     ok = true;
-
-    setDefaults();
   }
 
   UserConfig::UserConfig(const std::string& conffile, const std::string& jfile,
@@ -211,6 +210,7 @@ namespace Arc {
     : timeout(0), keySize(0), ok(false), initializeCredentials(initializeCredentials)  {
     // If job list file have been specified, try to initialize it, and
     // if it fails then this object is non-valid (ok = false).
+    setDefaults();
     if (!jfile.empty() && !JobListFile(jfile))
       return;
 
@@ -266,8 +266,6 @@ namespace Arc {
     }
 
     ok = true;
-
-    setDefaults();
   }
 
   UserConfig::UserConfig(const long int& ptraddr) { *this = *((UserConfig*)ptraddr); }
@@ -527,8 +525,11 @@ namespace Arc {
                 "improper permissions/ownership and usercert.pem/userkey.pem not found\n"
                 "at default locations:\n"
                 "~/.arc/, ~/.globus/, %s/etc/arc, and ./.\n"
-                "Please manually specify the proxy or certificate/key locations, or use\n"
-                "arcproxy utility to create a proxy certificte", ArcLocation::Get()
+                "If the proxy or certificate/key does exist, please manually specify the locations via env\n"
+                "X509_USER_CERT/X509_USER_KEY or X509_USER_PROXY, or the certificatepath/keypath or proxypath\n"
+                "item in client.conf\n"
+                "If the certificate/key does exist, and proxy is needed to be generated, please\n"
+                "use arcproxy utility to create a proxy certificate.", ArcLocation::Get()
               );
               if(require) {
                 res = false;
@@ -578,7 +579,9 @@ namespace Arc {
                         "~/.arc/certificates, ~/.globus/certificates,\n"
                         "%s/etc/certificates, %s/etc/grid-security/certificates,\n"
                         "%s/share/certificates, /etc/grid-security/certificates.\n"
-                        "The certificate will not be verified.", 
+                        "The certificate will not be verified.\n"
+                        "If the CA certificates directory does exist, please manually specify the locations via env\n"
+                        "X509_CERT_DIR, or the cacertificatesdirectory item in client.conf\n", 
                         ArcLocation::Get(), ArcLocation::Get(), ArcLocation::Get());
                       res = false;
                     }
@@ -697,8 +700,8 @@ namespace Arc {
             }
           }
           if (common["brokername"]) {
-            broker = std::make_pair<std::string, std::string>(ini["common"]["brokername"],
-                                                              ini["common"]["brokerarguments"] ? ini["common"]["brokerarguments"] : "");
+            broker = std::make_pair<std::string, std::string>(common["brokername"],
+                                                              common["brokerarguments"] ? common["brokerarguments"] : "");
             common["brokername"].Destroy();
             if (common["brokername"]) {
               logger.msg(WARNING, "Multiple %s attributes in configuration file (%s)", "brokername", conffile);
@@ -813,8 +816,8 @@ namespace Arc {
                          overlayfile);
           while (common.Child()) {
             logger.msg(WARNING,
-                       "Unknown attribute %s in common section, ignoring it",
-                       common.Child().Name());
+                       "Unknown attribute %s in common section of configuration file (%s), ignoring it",
+                       common.Child().Name(), conffile);
             common.Child().Destroy();
           }
 
