@@ -57,6 +57,7 @@
 #define __ARC_DATAPOINT_H__
 
 #include <list>
+#include <set>
 #include <string>
 
 #include <arc/DateTime.h>
@@ -319,6 +320,30 @@ namespace Arc {
        be retrieved due to limitation of protocol or access control. */
     virtual DataStatus Stat(FileInfo& file, DataPointInfoType verb = INFO_TYPE_ALL) = 0;
 
+    /// Retrieve information about several DataPoints.
+    /** If a DataPoint represents a directory or something similar,
+       information about the object itself and not its contents will
+       be obtained. This method can use bulk operations if the protocol
+       supports it. The protocols and hosts of all the DataPoints in
+       urls must be the same and the same as this DataPoint's protocol
+       and host. This method can be called on any of the urls, for
+       example urls.front()->Stat(files, urls);
+       Calling this method with an empty list of urls returns success if
+       the protocol supports bulk Stat, and an error if it does not.
+       \param files will contain objects' names and requested attributes.
+       There may be more attributes than requested. There may be less
+       if objects can't provide particular information. The order of this
+       vector matches the order of urls. If a stat of any url fails then
+       the corresponding FileInfo in this list will evaluate to false.
+       \param urls list of DataPoints to stat. Protocols and hosts must
+       match and match this DataPoint's protocol and host.
+       \param verb defines attribute types which method must try to
+       retrieve. It is not a failure if some attributes could not
+       be retrieved due to limitation of protocol or access control. */
+    virtual DataStatus Stat(std::list<FileInfo>& files,
+                            const std::list<DataPoint*>& urls,
+                            DataPointInfoType verb = INFO_TYPE_ALL) = 0;
+
     /// List hierarchical content of this object.
     /** If the DataPoint represents a directory or something similar its
        contents will be listed.
@@ -330,6 +355,16 @@ namespace Arc {
        be retrieved due to limitation of protocol or access control. */
     virtual DataStatus List(std::list<FileInfo>& files, DataPointInfoType verb = INFO_TYPE_ALL) = 0;
 
+    /// Create a directory.
+    /** If the protocol supports it, this method creates the last directory
+     * in the path to the URL. It assumes the last component of the path is a
+     * file-like object and not a directory itself, unless the path ends in a
+     * directory separator. If with_parents is true then all missing parent
+     * directories in the path will also be created.
+     * \param with_parents If true then all missing directories in the path
+     * are created */
+    virtual DataStatus CreateDirectory(bool with_parents=false) = 0;
+
     /// Allow/disallow DataPoint to produce scattered data during
     /// *reading* operation.
     /** \param v true if allowed (default is false). */
@@ -374,6 +409,16 @@ namespace Arc {
        information. */
     virtual DataStatus Resolve(bool source) = 0;
 
+    /// Resolves several index service URLs.
+    /** Can use bulk calls if protocol allows. The protocols and hosts of all
+       the DataPoints in urls must be the same and the same as this DataPoint's
+       protocol and host. This method can be called on any of the urls, for
+       example urls.front()->Resolve(true, urls);
+       \param source true if DataPoint objects represent source of information
+       \param urls List of DataPoints to resolve. Protocols and hosts must
+       match and match this DataPoint's protocol and host. */
+    virtual DataStatus Resolve(bool source, const std::list<DataPoint*>& urls) = 0;
+
     /// Check if file is registered in Indexing Service.
     /** Proper value is obtainable only after Resolve. */
     virtual bool Registered() const = 0;
@@ -524,6 +569,9 @@ namespace Arc {
     /** Usage differs between different indexing services. */
     virtual const std::string& CurrentLocationMetadata() const = 0;
 
+    /// Returns a pointer to the DataPoint representing the current location.
+    virtual DataPoint* CurrentLocationHandle() const = 0;
+
     /// Compare metadata of DataPoint and current location
     /** Returns inconsistency error or error encountered during
      * operation, or success */
@@ -572,6 +620,10 @@ namespace Arc {
     virtual void SortLocations(const std::string& pattern,
                                const URLMap& url_map) = 0;
 
+    /// Add URL options to this DataPoint's URL object. Invalid options for the
+    /// DataPoint instance will not be added.
+    virtual void AddURLOptions(const std::map<std::string, std::string>& options);
+
   protected:
     URL url;
     const UserConfig usercfg;
@@ -587,7 +639,7 @@ namespace Arc {
     bool cache;
     bool stageable;
     /** Subclasses should add their own specific options to this list */
-    std::list<std::string> valid_url_options;
+    std::set<std::string> valid_url_options;
 
     static Logger logger;
 
@@ -599,7 +651,7 @@ namespace Arc {
      * \param url The URL representing the DataPoint
      * \param usercfg User configuration object
      */
-    DataPoint(const URL& url, const UserConfig& usercfg);
+    DataPoint(const URL& url, const UserConfig& usercfg, PluginArgument* parg);
   };
 
   /// Class used by DataHandle to load the required DMC.
