@@ -10,8 +10,8 @@
 
 namespace Arc {
 
-  DataPointDirect::DataPointDirect(const URL& url, const UserConfig& usercfg)
-    : DataPoint(url, usercfg),
+  DataPointDirect::DataPointDirect(const URL& url, const UserConfig& usercfg, PluginArgument* parg)
+    : DataPoint(url, usercfg, parg),
       buffer(NULL),
       bufsize(-1),
       bufnum(1),
@@ -108,6 +108,10 @@ namespace Arc {
     return DataStatus::NotSupportedForDirectDataPointsError;
   }
 
+  DataStatus DataPointDirect::Resolve(bool source, const std::list<DataPoint*>& urls) {
+    return DataStatus::NotSupportedForDirectDataPointsError;
+  }
+
   DataStatus DataPointDirect::PreRegister(bool, bool) {
     return DataStatus::NotSupportedForDirectDataPointsError;
   }
@@ -145,6 +149,10 @@ namespace Arc {
     return empty;
   }
   
+  DataPoint* DataPointDirect::CurrentLocationHandle() const {
+    return const_cast<DataPointDirect*> (this);
+  }
+
   DataStatus DataPointDirect::CompareLocationMetadata() const {
     return DataStatus::NotSupportedForDirectDataPointsError;
   }
@@ -201,4 +209,11 @@ namespace Arc {
     return NULL;
   }
 
+  DataStatus DataPointDirect::Stat(std::list<FileInfo>& files,
+                                   const std::list<DataPoint*>& urls,
+                                   DataPointInfoType verb) {
+    return DataStatus::UnimplementedError;
+  }
+
+
 } // namespace Arc
