@@ -21,7 +21,7 @@ namespace Arc {
 
     virtual const URL& CurrentLocation() const;
     virtual const std::string& CurrentLocationMetadata() const;
-    
+    virtual DataPoint* CurrentLocationHandle() const;
     virtual DataStatus CompareLocationMetadata() const;
     virtual bool NextLocation();
     virtual bool LocationValid() const;
@@ -90,7 +90,7 @@ namespace Arc {
   protected:
     bool resolved;
     bool registered;
-    DataPointIndex(const URL& url, const UserConfig& usercfg);
+    DataPointIndex(const URL& url, const UserConfig& usercfg, PluginArgument* parg);
 
   private:
     // Following members must be kept synchronised hence they are private
