@@ -1,4 +1,8 @@
 // -*- indent-tabs-mode: nil -*-
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -655,7 +659,7 @@ void FileCacheTest::testLinkFile() {
 
   // create bad soft-link
   if (_uid != 0 && stat("/lost+found/sessiondir", &fileStat) != 0 && errno == EACCES) {
-    CPPUNIT_ASSERT(!_fc1->Link("/lost_found/sessiondir/file1", _url, false, false, true, try_again));
+    CPPUNIT_ASSERT(!_fc1->Link("/lost_found/sessiondir/file1", _url, false, false, false, try_again));
     CPPUNIT_ASSERT(!try_again);
   }
 
@@ -748,7 +752,7 @@ void FileCacheTest::testCopyFile() {
 
   // create bad copy
   if (_uid != 0 && stat("/lost+found/sessiondir", &fileStat) != 0 && errno == EACCES)
-    CPPUNIT_ASSERT(!_fc1->Link("/lost+found/sessiondir/file1", _url, true, false, true, try_again));
+    CPPUNIT_ASSERT(!_fc1->Link("/lost+found/sessiondir/file1", _url, true, false, false, try_again));
 
   // Stop cache to release lock
   CPPUNIT_ASSERT(_fc1->Stop(_url));
@@ -961,7 +965,7 @@ void FileCacheTest::testTwoCaches() {
   // copy file
   CPPUNIT_ASSERT_EQUAL(0, remove(soft_link.c_str()));
   CPPUNIT_ASSERT(fc2->Start(_url, available, is_locked));
-  CPPUNIT_ASSERT(fc2->Link(soft_link, _url, true, false, true, try_again));
+  CPPUNIT_ASSERT(fc2->Link(soft_link, _url, true, false, false, try_again));
 
   // check job dir is created
   CPPUNIT_ASSERT(stat(hard_link_cache1.c_str(), &fileStat) == 0 || stat(hard_link_cache2.c_str(), &fileStat) == 0);
@@ -1098,7 +1102,7 @@ void FileCacheTest::testConstructor() {
   CPPUNIT_ASSERT(!(*_fc1 == *fc6));
 
   // create with two different caches and compare
-  caches.empty();
+  caches.clear();
   caches.push_back(_cache_dir);
   caches.push_back(cache_dir3);
   Arc::FileCache *fc7 = new Arc::FileCache(caches, _jobid, _uid, _gid);
@@ -1108,6 +1112,8 @@ void FileCacheTest::testConstructor() {
   delete fc7;
 
   // constructor with remote and draining caches
+  caches.clear();
+  caches.push_back(_cache_dir);
   std::vector<std::string> remote_caches;
   remote_caches.push_back(_testroot + "remote1");
   std::vector<std::string> draining_caches;
