@@ -819,6 +819,11 @@ void InfoRegistrar::sendRegistrationToEMIREG() {
                     tmp_message += ",";
                 }
                 tmp_message += "{";
+                // Mandatory attributes are here: https://twiki.cern.ch/twiki/bin/view/EMI/EMIRSERDesc
+                // Service_ID
+                tmp_message += "\"Service_ID\":\"";
+                tmp_message += (std::string)node["SrcAdv"]["EPR"]["Address"];
+                tmp_message += "\"";
                 // Service_Name
                 if ( ((std::string)node["SrcAdv"]["Type"]).find("org.nordugrid.execution") != std::string::npos){
                     tmp_message += "\"Service_Name\":\"ComputingService\",";
@@ -837,10 +842,30 @@ void InfoRegistrar::sendRegistrationToEMIREG() {
                 tmp_message += "\"Service_Type\":\"";
                 tmp_message += (std::string)node["SrcAdv"]["Type"];
                 tmp_message += "\",";
+                //Service_Endpoint_ID
+                tmp_message += "\"Service_Endpoint_ID\":\"";
+                tmp_message += (std::string)node["SrcAdv"]["EPR"]["Address"];
+                tmp_message += "\"";
                 //Service_Endpoint_URL
                 tmp_message += "\"Service_Endpoint_URL\":\"";
                 tmp_message += (std::string)node["SrcAdv"]["EPR"]["Address"];
                 tmp_message += "\"";
+                //Service_Endpoint_Capability
+                tmp_message += "\"Service_Endpoint_Capability\":[\"";
+                tmp_message += "N/A";	//TODO: set capability values
+                tmp_message += "]\"";
+                //Service_Endpoint_Technology
+                tmp_message += "\"Service_Endpoint_Technology\":\"";
+                tmp_message += "N/A";	//TODO: set technology values
+                tmp_message += "\"";
+                //Service_Endpoint_InterfaceName
+                tmp_message += "\"Service_Endpoint_InterfaceName\":\"";
+                tmp_message += "N/A";	//TODO: set InterfaceName values
+                tmp_message += "\"";
+                //Service_Endpoint_InterfaceVersion
+                tmp_message += "\"Service_Endpoint_InterfaceVersion\":\"";
+                tmp_message += "N/A";	//TODO: set InterfaceVersion values
+                tmp_message += "\"";
                 if (already_registered){
                     // Service_ExpireOn
                      Period expiration((std::string)node["MetaSrcAdv"]["Expiration"]);
@@ -899,11 +924,16 @@ void InfoRegistrar::sendRegistrationToEMIREG() {
                 } else {
                     if( http_info.code == 200 )  {
                         logger_.msg(VERBOSE, "Successful %s to EMIRegistry (%s)", method, id_);
+                        already_registered = true;
                         delete http_response;
                         break;
                     } else {
                         std::string method2 = already_registered ? "update" : "register";
                         logger_.msg(VERBOSE, "Failed to %s to EMIRegistry (%s) - %d", method2, id_, http_info.code );
+                        if ( retry_ == 1 ) {
+                            // Already registration need becasue the entry expired (and removed) on the EMIR.
+                            already_registered = false;
+                        }
                     }
                 }
                 retry_--;
@@ -912,7 +942,6 @@ void InfoRegistrar::sendRegistrationToEMIREG() {
                 sleep(1);
             }
         }
-        already_registered = true;
         // end of the connection with the EMIRegistry
 
         // Thread sleeping
