@@ -16,11 +16,11 @@ namespace Arc {
 class RegisteredService: public Service
 {
     private:
-        InfoRegister inforeg;
+        InfoRegisters inforeg;
 
     public:
         /** Example contructor - Server takes at least it's configuration subtree */
-        RegisteredService(Config*);
+        RegisteredService(Config*, PluginArgument*);
 
         virtual ~RegisteredService(void) { };
 };
