@@ -20,16 +20,6 @@ namespace Arc {
 
   class PluginsFactory;
 
-  /// Base class for loadable ARC components.
-  /** All classes representing loadable ARC components must be either
-     descendants of this class or be wrapped by its offspring. */
-  class Plugin {
-    protected:
-      Plugin(void);
-    public:
-      virtual ~Plugin(void);
-  };
-
   /// Base class for passing arguments to loadable ARC components.
   /** During its creation constructor function of ARC loadable component
      expects instance of class inherited from this one or wrapped in it.
@@ -59,6 +49,24 @@ namespace Arc {
       Glib::Module* get_module(void);
   };
 
+  /// Base class for loadable ARC components.
+  /** All classes representing loadable ARC components must be either
+     descendants of this class or be wrapped by its offspring. */
+  class Plugin {
+    private:
+      Plugin(void) {};
+      Plugin& operator=(const Plugin&) { return *this; };
+    protected:
+      PluginsFactory* factory_;
+      Glib::Module* module_;
+      /// Main constructor for creating new plugin object
+      Plugin(PluginArgument* arg);
+      /// Constructor to be used if plugin want to copy itself
+      Plugin(const Plugin& obj);
+    public:
+      virtual ~Plugin(void);
+  };
+
   /// Name of symbol refering to table of plugins.
   /** This C null terminated string specifies name of symbol which
      shared library should export to give an access to an array
@@ -115,6 +123,7 @@ namespace Arc {
      protection implementation is suboptimal and will be revised
      in future. */
   class PluginsFactory: public ModuleManager {
+    friend class PluginArgument;
     private:
       Glib::Mutex lock_;
       typedef std::map<std::string,PluginDescriptor*> descriptors_t_;
@@ -144,7 +153,7 @@ namespace Arc {
          for analyzing its content. If set to false only *.apd
          files are checked. Modules without corresponding *.apd
          will be ignored. Default is true; */
-      void TryLoad(bool v = true) { try_load_ = v; };
+      void TryLoad(bool v) { try_load_ = v; };
       bool TryLoad(void) { return try_load_; };
       Plugin* get_instance(const std::string& kind,PluginArgument* arg,bool search = true);
       Plugin* get_instance(const std::string& kind,int version,PluginArgument* arg,bool search = true);
