@@ -16,12 +16,12 @@
 
 class TestMCC: public Arc::MCC {
     public:
-        TestMCC(Arc::Config *cfg);
+        TestMCC(Arc::Config *cfg, Arc::PluginArgument *parg);
         virtual ~TestMCC(void);
         virtual Arc::MCC_Status process(Arc::Message&,Arc::Message&);
 };
 
-TestMCC::TestMCC(Arc::Config* cfg):Arc::MCC(cfg) {
+TestMCC::TestMCC(Arc::Config* cfg, Arc::PluginArgument *parg):Arc::MCC(cfg,parg) {
 }
 
 TestMCC::~TestMCC() {
@@ -35,7 +35,7 @@ static Arc::Plugin* get_mcc(Arc::PluginArgument* arg) {
     Arc::MCCPluginArgument* mccarg =
             arg?dynamic_cast<Arc::MCCPluginArgument*>(arg):NULL;
     if(!mccarg) return NULL;
-    return new TestMCC((Arc::Config*)(*mccarg));
+    return new TestMCC((Arc::Config*)(*mccarg),arg);
 }
 
 Arc::PluginDescriptor PLUGINS_TABLE_NAME[] = {
