@@ -10,13 +10,14 @@
 
 #include "DelegationCollector.h"
 
-namespace ArcSec {
+namespace ArcMCCTLSSec {
 
 using namespace Arc;
+using namespace ArcMCCTLS;
 
 static Arc::Logger logger(Arc::Logger::getRootLogger(),"DelegationCollector");
 
-DelegationCollector::DelegationCollector(Config *cfg):SecHandler(cfg) {
+DelegationCollector::DelegationCollector(Config *cfg,PluginArgument* parg):SecHandler(cfg,parg) {
 }
 
 DelegationCollector::~DelegationCollector(void) {
@@ -112,7 +113,7 @@ Arc::Plugin* DelegationCollector::get_sechandler(Arc::PluginArgument* arg) {
     ArcSec::SecHandlerPluginArgument* shcarg =
             arg?dynamic_cast<ArcSec::SecHandlerPluginArgument*>(arg):NULL;
     if(!shcarg) return NULL;
-    return new DelegationCollector((Arc::Config*)(*shcarg));
+    return new DelegationCollector((Arc::Config*)(*shcarg),shcarg);
 }
 
 }
