@@ -7,11 +7,13 @@
 #include <arc/ArcConfig.h>
 #include <arc/loader/Plugin.h>
 
-namespace ArcSec {
+namespace ArcMCCTLSSec {
+
+using namespace ArcSec;
 
 class DelegationCollector : public SecHandler {
  public:
-  DelegationCollector(Arc::Config *cfg);
+  DelegationCollector(Arc::Config *cfg,Arc::PluginArgument* parg);
   virtual ~DelegationCollector(void);
   virtual bool Handle(Arc::Message* msg) const;
   static Arc::Plugin* get_sechandler(Arc::PluginArgument* arg);
