@@ -37,7 +37,9 @@
 
 #include "MCCTLS.h"
 
-namespace Arc {
+namespace ArcMCCTLS {
+
+using namespace Arc;
 
 bool x509_to_string(X509* cert,std::string& str) {
   BIO *out = BIO_new(BIO_s_mem());
@@ -121,41 +123,9 @@ class TLSSecAttr: public SecAttr {
   bool processing_failed_;
   virtual bool equal(const SecAttr &b) const;
 };
-}
-
-//Glib::Mutex Arc::MCC_TLS::lock_;
-Arc::Logger Arc::MCC_TLS::logger(Arc::Logger::getRootLogger(), "MCC.TLS");
-
-Arc::MCC_TLS::MCC_TLS(Arc::Config& cfg,bool client) : Arc::MCC(&cfg), config_(cfg,logger,client) {
-}
-
-static Arc::Plugin* get_mcc_service(Arc::PluginArgument* arg) {
-    Arc::MCCPluginArgument* mccarg =
-            arg?dynamic_cast<Arc::MCCPluginArgument*>(arg):NULL;
-    if(!mccarg) return NULL;
-    return new Arc::MCC_TLS_Service(*(Arc::Config*)(*mccarg));
-}
-
-static Arc::Plugin* get_mcc_client(Arc::PluginArgument* arg) {
-    Arc::MCCPluginArgument* mccarg =
-            arg?dynamic_cast<Arc::MCCPluginArgument*>(arg):NULL;
-    if(!mccarg) return NULL;
-    return new Arc::MCC_TLS_Client(*(Arc::Config*)(*mccarg));
-}
-
-Arc::PluginDescriptor PLUGINS_TABLE_NAME[] = {
-    { "tls.service", "HED:MCC", NULL, 0, &get_mcc_service },
-    { "tls.client",  "HED:MCC", NULL, 0, &get_mcc_client  },
-    { "delegation.collector", "HED:SHC", NULL, 0, &ArcSec::DelegationCollector::get_sechandler},
-    { NULL, NULL, NULL, 0, NULL }
-};
-
-using namespace Arc;
-
 
 #define SELFSIGNED(cert) (X509_NAME_cmp(X509_get_issuer_name(cert),X509_get_subject_name(cert)) == 0)
 
-
 TLSSecAttr::TLSSecAttr(PayloadTLSStream& payload, ConfigTLSMCC& config, Logger& logger) {
    char buf[100];
    std::string subject;
@@ -189,7 +159,7 @@ TLSSecAttr::TLSSecAttr(PayloadTLSStream& payload, ConfigTLSMCC& config, Logger&
 #endif
          // Parse VOMS attributes from each certificate of the peer chain.
          Arc::VOMSTrustList trust_list(config.VOMSCertTrustDN());
-         bool res = parseVOMSAC(cert, config.CADir(), config.CAFile(), trust_list, voms_attributes_, true, true);
+         bool res = parseVOMSAC(cert, config.CADir(), config.CAFile(), config.VOMSDir(), trust_list, voms_attributes_, true, true);
          if(!res) {
             logger.msg(ERROR,"VOMS attribute parsing failed");
          };
@@ -218,7 +188,7 @@ TLSSecAttr::TLSSecAttr(PayloadTLSStream& payload, ConfigTLSMCC& config, Logger&
 #endif
       // Parse VOMS attributes from peer certificate
       Arc::VOMSTrustList trust_list(config.VOMSCertTrustDN());
-      bool res = parseVOMSAC(peercert, config.CADir(), config.CAFile(), trust_list, voms_attributes_, true, true);
+      bool res = parseVOMSAC(peercert, config.CADir(), config.CAFile(), config.VOMSDir(), trust_list, voms_attributes_, true, true);
       if(!res) {
         logger.msg(ERROR,"VOMS attribute parsing failed");
       };
@@ -382,7 +352,7 @@ class MCC_TLS_Context:public MessageContextElement {
 
 /* The main functionality of the constructor method is to
    initialize SSL layer. */
-MCC_TLS_Service::MCC_TLS_Service(Config& cfg):MCC_TLS(cfg,false) {
+MCC_TLS_Service::MCC_TLS_Service(Config& cfg,PluginArgument* parg):MCC_TLS(cfg,false,parg) {
    if(!OpenSSLInit()) return;
 }
 
@@ -423,6 +393,11 @@ MCC_Status MCC_TLS_Service::process(Message& inmsg,Message& outmsg) {
       // Creating new SSL object bound to stream of previous MCC
       // TODO: renew stream because it may be recreated by TCP MCC
       stream = new PayloadTLSMCC(inpayload,config_,logger);
+      // Check for established connection
+      if(!*stream) {
+        delete stream;
+        return MCC_Status();
+      }
       context=new MCC_TLS_Context(stream);
       inmsg.Context()->Add("tls.service",context);
    };
@@ -476,7 +451,7 @@ MCC_Status MCC_TLS_Service::process(Message& inmsg,Message& outmsg) {
    return MCC_Status(STATUS_OK);
 }
 
-MCC_TLS_Client::MCC_TLS_Client(Config& cfg):MCC_TLS(cfg,true){
+MCC_TLS_Client::MCC_TLS_Client(Config& cfg,PluginArgument* parg):MCC_TLS(cfg,true,parg){
    stream_=NULL;
    if(!OpenSSLInit()) return;
    /* Get DN from certificate, and put it into message's attribute */
@@ -547,3 +522,34 @@ void MCC_TLS_Client::Next(MCCInterface* next,const std::string& label) {
    };
    MCC::Next(next,label);
 }
+
+
+} // namespace ArcMCCTLS
+
+//Glib::Mutex Arc::MCC_TLS::lock_;
+Arc::Logger ArcMCCTLS::MCC_TLS::logger(Arc::Logger::getRootLogger(), "MCC.TLS");
+
+ArcMCCTLS::MCC_TLS::MCC_TLS(Arc::Config& cfg,bool client,PluginArgument* parg) : Arc::MCC(&cfg,parg), config_(cfg,logger,client) {
+}
+
+static Arc::Plugin* get_mcc_service(Arc::PluginArgument* arg) {
+    Arc::MCCPluginArgument* mccarg =
+            arg?dynamic_cast<Arc::MCCPluginArgument*>(arg):NULL;
+    if(!mccarg) return NULL;
+    return new ArcMCCTLS::MCC_TLS_Service(*(Arc::Config*)(*mccarg),mccarg);
+}
+
+static Arc::Plugin* get_mcc_client(Arc::PluginArgument* arg) {
+    Arc::MCCPluginArgument* mccarg =
+            arg?dynamic_cast<Arc::MCCPluginArgument*>(arg):NULL;
+    if(!mccarg) return NULL;
+    return new ArcMCCTLS::MCC_TLS_Client(*(Arc::Config*)(*mccarg),mccarg);
+}
+
+Arc::PluginDescriptor PLUGINS_TABLE_NAME[] = {
+    { "tls.service", "HED:MCC", NULL, 0, &get_mcc_service },
+    { "tls.client",  "HED:MCC", NULL, 0, &get_mcc_client  },
+    { "delegation.collector", "HED:SHC", NULL, 0, &ArcMCCTLSSec::DelegationCollector::get_sechandler},
+    { NULL, NULL, NULL, 0, NULL }
+};
+
