@@ -37,7 +37,7 @@ Plugin* ArcPDP::get_arc_pdp(PluginArgument* arg) {
     ArcSec::PDPPluginArgument* pdparg =
             arg?dynamic_cast<ArcSec::PDPPluginArgument*>(arg):NULL;
     if(!pdparg) return NULL;
-    return new ArcPDP((Arc::Config*)(*pdparg));
+    return new ArcPDP((Arc::Config*)(*pdparg),arg);
 }
 
 // This class is used to store Evaluator per connection
@@ -64,7 +64,7 @@ ArcPDPContext::ArcPDPContext(void):eval(NULL) {
   eval = eval_loader.getEvaluator(evaluator);
 }
 
-ArcPDP::ArcPDP(Config* cfg):PDP(cfg) /*, eval(NULL)*/ {
+ArcPDP::ArcPDP(Config* cfg,Arc::PluginArgument* parg):PDP(cfg,parg) /*, eval(NULL)*/ {
   XMLNode pdp_node(*cfg);
 
   XMLNode filter = (*cfg)["Filter"];
