@@ -29,7 +29,7 @@ class X509TokenSH : public SecHandler {
   bool valid_;
 
  public:
-  X509TokenSH(Arc::Config *cfg, Arc::ChainContext* ctx);
+  X509TokenSH(Arc::Config *cfg, Arc::ChainContext* ctx, Arc::PluginArgument* parg);
   virtual ~X509TokenSH(void);
   static Arc::Plugin* get_sechandler(Arc::PluginArgument* arg);
   virtual bool Handle(Arc::Message* msg) const;
