@@ -12,13 +12,16 @@ namespace DataStaging {
   public:
 
     /// Starts child process
-    DataDeliveryLocalComm(const DTR& dtr, const TransferParameters& params);
+    DataDeliveryLocalComm(DTR_ptr dtr, const TransferParameters& params);
     /// This stops the child process
-    ~DataDeliveryLocalComm();
+    virtual ~DataDeliveryLocalComm();
 
     /// Read from stdout of child to get status
     virtual void PullStatus();
 
+    /// Returns "/" since local Delivery can access everywhere
+    static bool CheckComm(DTR_ptr dtr, std::vector<std::string>& allowed_dirs);
+
     /// Returns true if child process exists
     virtual operator bool() const { return (child_ != NULL); };
     /// Returns true if child process does not exist
@@ -27,6 +30,8 @@ namespace DataStaging {
   private:
     /// Child process
     Arc::Run* child_;
+    /// Temporary credentails location
+    std::string tmp_proxy_;
     /// Time last communication was received from child
     Arc::Time last_comm;
   };
