@@ -10,6 +10,7 @@
 #include <arc/OptionParser.h>
 #include <arc/StringConv.h>
 #include <arc/UserConfig.h>
+#include <arc/Utils.h>
 #include <arc/data/DataHandle.h>
 #include <arc/data/DataBuffer.h>
 
@@ -227,6 +228,15 @@ int main(int argc,char* argv[]) {
   dest->SetSecure(false);
   dest->Passive(true);
 
+  // set X509* for 3rd party tools which need it (eg GFAL)
+  SetEnv("X509_USER_PROXY", source_cfg.ProxyPath());
+  if (!source_cfg.CACertificatesDirectory().empty()) SetEnv("X509_CERT_DIR", source_cfg.CACertificatesDirectory());
+  // those tools also use hostcert by default if the user is root...
+  if (getuid() == 0) {
+    SetEnv("X509_USER_CERT", source_cfg.ProxyPath());
+    SetEnv("X509_USER_KEY", source_cfg.ProxyPath());
+  }
+
   // set signal handlers
   signal(SIGTERM, sig_shutdown);
   signal(SIGINT, sig_shutdown);
@@ -273,7 +283,7 @@ int main(int argc,char* argv[]) {
                   DataStaging::DTRErrorStatus::LOCAL_FILE_ERROR,
                  DataStaging::DTRErrorStatus::ERROR_SOURCE,
                  std::string("Failed reading from source: ")+source->CurrentLocation().str()+
-                  " : "+source->GetFailureReason().GetDesc()+": "+source_st.GetDesc(),
+                  " : "+std::string(source_st),
                  0,0);
     _exit(-1);
     //return -1;
@@ -287,7 +297,7 @@ int main(int argc,char* argv[]) {
                   DataStaging::DTRErrorStatus::LOCAL_FILE_ERROR,
                  DataStaging::DTRErrorStatus::ERROR_DESTINATION,
                  std::string("Failed writing to destination: ")+dest->CurrentLocation().str()+
-                  " : "+dest->GetFailureReason().GetDesc()+": "+dest_st.GetDesc(),
+                  " : "+std::string(dest_st),
                  0,0);
     _exit(-1);
     //return -1;
@@ -333,29 +343,35 @@ int main(int argc,char* argv[]) {
 
   // Error at source or destination
   if(source_failed || !source_st) {
+    std::string err("Failed reading from source: "+source->CurrentLocation().str());
+    // If error reported in read callback, use that instead
+    if (source->GetFailureReason() != DataStatus::UnknownError) source_st = source->GetFailureReason();
+    if (!source_st) err += " : " + std::string(source_st);
     ReportStatus(DataStaging::DTRStatus::TRANSFERRED,
                  (source_url.Protocol() != "file") ?
-                  (!source_st && source_st.Retryable() ?
+                  (((!source_st && source_st.Retryable()) || buffer.speed.transferred_size() > 0) ?
                       DataStaging::DTRErrorStatus::TEMPORARY_REMOTE_ERROR :
                       DataStaging::DTRErrorStatus::PERMANENT_REMOTE_ERROR) :
                   DataStaging::DTRErrorStatus::LOCAL_FILE_ERROR,
                  DataStaging::DTRErrorStatus::ERROR_SOURCE,
-                 std::string("Failed reading from source: ")+source->CurrentLocation().str()+
-                  " : "+source->GetFailureReason().GetDesc()+": "+source_st.GetDesc(),
+                 err,
                  buffer.speed.transferred_size(),
                  GetFileSize(*source,*dest));
     reported = true;
   };
   if(dest_failed || !dest_st) {
+    std::string err("Failed writing to destination: "+dest->CurrentLocation().str());
+    // If error reported in write callback, use that instead
+    if (dest->GetFailureReason() != DataStatus::UnknownError) dest_st = dest->GetFailureReason();
+    if (!dest_st) err += " : " + std::string(dest_st);
     ReportStatus(DataStaging::DTRStatus::TRANSFERRED,
                  (dest_url.Protocol() != "file") ?
-                  (!dest_st && dest_st.Retryable() ?
+                  (((!dest_st && dest_st.Retryable()) || buffer.speed.transferred_size() > 0) ?
                          DataStaging::DTRErrorStatus::TEMPORARY_REMOTE_ERROR :
                          DataStaging::DTRErrorStatus::PERMANENT_REMOTE_ERROR) :
                   DataStaging::DTRErrorStatus::LOCAL_FILE_ERROR,
                  DataStaging::DTRErrorStatus::ERROR_DESTINATION,
-                 std::string("Failed writing to destination: ")+dest->CurrentLocation().str()+
-                  " : "+dest->GetFailureReason().GetDesc()+": "+dest_st.GetDesc(),
+                 err,
                  buffer.speed.transferred_size(),
                  GetFileSize(*source,*dest));
     reported = true;
@@ -389,7 +405,7 @@ int main(int argc,char* argv[]) {
     crc_dest.print(buf,100);
     calc_csum = buf;
   }
-  if (!calc_csum.empty() && crc.Type() != CheckSumAny::none) {
+  if (!reported && !calc_csum.empty() && crc.Type() != CheckSumAny::none) {
 
     // compare calculated to any checksum given as an option
     if (source->CheckCheckSum()) {
@@ -404,6 +420,10 @@ int main(int argc,char* argv[]) {
                      0,0);
         reported = true;
         eof_reached = false; // TODO general error flag is better than this
+        // Delete destination
+        if (!dest->Remove().Passed()) {
+          logger.msg(WARNING, "Failed cleaning up destination %s", dest->GetURL().str());
+        }
       }
       else
         logger.msg(INFO, "Calculated transfer checksum %s matches source checksum", calc_csum);
