@@ -10,6 +10,8 @@
 
 #include "FileChunks.h"
 #include "grid-manager/grid_manager.h"
+//#include "delegation/DelegationStore.h"
+#include "delegation/DelegationStores.h"
 
 class JobLog;
 class JobsListConfig;
@@ -20,6 +22,7 @@ namespace ARex {
 class ARexGMConfig;
 class ARexConfigContext;
 class CountedResourceLock;
+class DelegationStores;
 
 class CountedResource {
  friend class CountedResourceLock;
@@ -58,13 +61,15 @@ class ARexService: public Arc::RegisteredService {
   Arc::ThreadRegistry thread_count_;
   Arc::NS ns_;
   Arc::Logger logger_;
-  Arc::DelegationContainerSOAP delegations_;
+  DelegationStores delegation_stores_;
   OptimizedInformationContainer infodoc_;
-  Arc::InfoRegisters inforeg_;
+  //Arc::InfoRegisters inforeg_;
   CountedResource infolimit_;
   CountedResource beslimit_;
   CountedResource datalimit_;
   std::string endpoint_;
+  bool enablearc_;
+  bool enableemies_;
   bool publishstaticinfo_;
   std::string uname_;
   std::string gmconfig_;
@@ -81,8 +86,9 @@ class ARexService: public Arc::RegisteredService {
   JobLog* job_log_;
   JobsListConfig* jobs_cfg_;
   GMEnvironment* gm_env_;
+  JobUsers* users_;
+  JobUser* my_user_;
   GridManager* gm_;
-  bool valid_;
   ARexConfigContext* get_configuration(Arc::Message& inmsg);
 
   // A-REX operations
@@ -163,17 +169,21 @@ class ARexService: public Arc::RegisteredService {
   void ESUnknownActivityIDFault(Arc::SOAPFault& fault,const std::string& message = "",const std::string& desc = "");
   void ESInvalidActivityStateFault(Arc::XMLNode fault,const std::string& message = "",const std::string& desc = "");
   void ESInvalidActivityStateFault(Arc::SOAPFault& fault,const std::string& message = "",const std::string& desc = "");
+  void ESInvalidParameterFault(Arc::XMLNode fault,const std::string& message = "",const std::string& desc = "");
+  void ESInvalidParameterFault(Arc::SOAPFault& fault,const std::string& message = "",const std::string& desc = "");
+  void ESOperationNotPossibleFault(Arc::XMLNode fault,const std::string& message,const std::string& desc = "");
+  void ESOperationNotPossibleFault(Arc::SOAPFault& fault,const std::string& message,const std::string& desc = "");
+  void ESActivityNotInTerminalStateFault(Arc::XMLNode fault,const std::string& message,const std::string& desc = "");
+  void ESActivityNotInTerminalStateFault(Arc::SOAPFault& fault,const std::string& message,const std::string& desc = "");
 
  public:
-  ARexService(Arc::Config *cfg);
+  ARexService(Arc::Config *cfg,Arc::PluginArgument *parg);
   virtual ~ARexService(void);
   virtual Arc::MCC_Status process(Arc::Message& inmsg,Arc::Message& outmsg);
   void InformationCollector(void);
   virtual bool RegistrationCollector(Arc::XMLNode &doc);
   virtual std::string getID();
   void StopChildThreads(void);
-  operator bool(void) { return valid_; };
-  bool operator!(void) { return !valid_; };
 };
 
 } // namespace ARex
