@@ -15,10 +15,13 @@ class FileRecord {
   Db    db_lock_;
   Db    db_locked_;
   Db    db_link_;
+  int error_num_;
+  std::string error_str_;
   bool valid_;
   static int locked_callback(Db *, const Dbt *, const Dbt *, Dbt * result);
   static int lock_callback(Db *, const Dbt *, const Dbt *, Dbt * result);
   std::string uid_to_path(const std::string& uid);
+  bool dberr(const char* s, int err);
  public:
   class Iterator {
    private:
@@ -41,10 +44,18 @@ class FileRecord {
     const std::list<std::string>& meta(void) const { return meta_; };
     const std::string path(void) const { return frec_.uid_to_path(uid_); };
   };
+  enum recovery {
+    no_recovery = 0,
+    ordinary_recovery = 1,
+    catastrophic_recovery = 2,
+    full_recovery = 3
+  };
   friend class FileRecord::Iterator;
-  FileRecord(const std::string& base);
+  FileRecord(const std::string& base, recovery recover = no_recovery);
+  ~FileRecord(void);
   operator bool(void) { return valid_; };
   bool operator!(void) { return !valid_; };
+  std::string Error(void) { return error_str_; };
   std::string Add(std::string& id, const std::string& owner, const std::list<std::string>& meta);
   std::string Find(const std::string& id, const std::string& owner, std::list<std::string>& meta);
   bool Modify(const std::string& id, const std::string& owner, const std::list<std::string>& meta);
