@@ -6,6 +6,7 @@
 #include <fstream>
 #include <iostream>
 #include <pwd.h>
+#include <unistd.h>
 
 #include <arc/StringConv.h>
 #include <arc/Logger.h>
@@ -30,12 +31,16 @@ bool configure_user_dirs(const std::string &my_username,
                 std::string& allow_submit,bool& strict_session,
                 std::string& gridftp_endpoint,
                 std::string& arex_endpoint,
+                bool& enable_arc_interface,
+                bool& enable_emies_interface,
                 const GMEnvironment& env) {
   std::ifstream cfile;
   int gm_port = 0;
   std::string gm_mount_point;
   std::string gm_hostname;
   std::string arex_mount_point;
+  bool enable_arc = true;
+  bool enable_emies = false;
   //read_env_vars(true);
   bool configured = false;
   std::string central_control_dir("");
@@ -239,6 +244,12 @@ bool configure_user_dirs(const std::string &my_username,
         else if(command == "arex_mount_point") {
           arex_mount_point = config_next_arg(rest);
         }
+        else if(command == "enable_arc_interface") {
+          enable_arc = (Arc::lower(config_next_arg(rest)) == "yes");
+        }
+        else if(command == "enable_emies_interface") {
+          enable_emies = (Arc::lower(config_next_arg(rest)) == "yes");
+        }
         else if(command == "hostname") {
           gm_hostname = config_next_arg(rest);
         }
@@ -359,139 +370,8 @@ bool configure_user_dirs(const std::string &my_username,
   if(gm_mount_point[0] != '/') gm_mount_point = "/"+gm_mount_point;;
   gridftp_endpoint = "gsiftp://"+gm_hostname+":"+Arc::tostring(gm_port)+gm_mount_point;
   arex_endpoint = arex_mount_point;
-  return true;
-}
-
-bool configure_users_dirs(Arc::XMLNode cfg,JobUsers& users) {
-  Arc::XMLNode tmp_node;
-  tmp_node = cfg["control"];
-  for(;tmp_node;++tmp_node) {
-    Arc::XMLNode unode = tmp_node["username"];
-    std::list<std::string> usernames;
-    for(;unode;++unode) {
-      std::string username;
-      username = (std::string)unode;
-      if(username.empty()) continue;
-      if(username == "*") {  /* add all gridmap users */
-        logger.msg(Arc::ERROR,"Gridmap user list feature is not supported anymore. Plase use @filename to specify user list.");
-        return false;
-      };
-      if(username[0] == '@') {  /* add users from file */
-        std::list<std::string> userlist;
-        std::string filename = username.substr(1);
-        if(!file_user_list(filename,userlist)) {
-          logger.msg(Arc::ERROR,"Can't read users in specified file %s",filename);
-          return false;
-        };
-        for(std::list<std::string>::iterator u = userlist.begin();
-                                 u != userlist.end();++u) {
-          usernames.push_back(*u);
-        };
-        continue;
-      };
-      if(username == ".") {
-        usernames.push_back("");
-        continue;
-      };
-      usernames.push_back(username);
-    };
-    for(std::list<std::string>::iterator u = usernames.begin();
-                             u != usernames.end();++u) {
-      std::string control_dir = tmp_node["controlDir"];
-      std::string session_root = tmp_node["sessionRootDir"];
-      JobUsers::iterator user=users.AddUser(*u);
-      if(user == users.end()) return false;
-      user->substitute(control_dir);
-      user->substitute(session_root);
-      user->SetControlDir(control_dir);
-      user->SetSessionRoot(session_root);
-    };
-  }; // for(control)
-  return true;
-}
-
-bool configure_users_dirs(JobUsers& users,GMEnvironment& env) {
-  std::ifstream cfile;
-  //read_env_vars(true);
-  std::string central_control_dir("");
-  ConfigSections* cf = NULL;
-  std::string session_root;
-
-  if(!config_open(cfile,env)) {
-    logger.msg(Arc::ERROR,"Can't open configuration file"); return false;
-  };
-  switch(config_detect(cfile)) {
-    case config_file_XML: {
-      Arc::XMLNode cfg;
-      if(!cfg.ReadFromStream(cfile)) {
-        logger.msg(Arc::ERROR,"Can't interpret configuration file as XML");
-        config_close(cfile);
-        return false;
-      };
-      if(!configure_users_dirs(cfg,users)) {
-        config_close(cfile);
-        return false;
-      };
-    }; break;
-    case config_file_INI: {
-      cf=new ConfigSections(cfile);
-      cf->AddSection("common");
-      cf->AddSection("grid-manager");
-      cf->AddSection("queue");
-      for(;;) {
-        std::string rest;
-        std::string command;
-        cf->ReadNext(command,rest);
-        if(command.length() == 0) {
-          if(central_control_dir.length() != 0) {
-            command="control"; rest=central_control_dir+" .";
-            central_control_dir="";
-          } else {
-            break;
-          };
-        };
-        if(cf->SectionNum() == 2) { // queue
-        }
-        else if(command == "sessiondir") {
-          session_root = config_next_arg(rest);
-          if(session_root.length() == 0) { config_close(cfile); delete cf; return false; };
-          if(session_root == "*") session_root="";
-        }
-        else if(command == "controldir") {
-          central_control_dir=rest;
-        }
-        else if(command == "control") {
-          std::string control_dir = config_next_arg(rest);
-          if(control_dir.length() == 0) { config_close(cfile); delete cf; return false; };
-          if(control_dir == "*") control_dir="";
-          for(;;) {
-            std::string username = config_next_arg(rest);
-            if(username.length() == 0) break;
-            if(username == "*") {  /* add all gridmap users */
-              config_close(cfile); delete cf; return false;
-            };
-            if(username[0] == '@') {  /* add users from file */
-              std::string filename = username.substr(1);
-              if(!file_user_list(filename,rest)) { config_close(cfile); delete cf; return false; };
-              continue;
-            };
-            if(username == ".") username = "";
-            JobUsers::iterator user=users.AddUser(username);
-            if(user == users.end()) { config_close(cfile); delete cf; return false; };
-            user->substitute(control_dir);
-            user->substitute(session_root);
-            user->SetControlDir(control_dir);
-            user->SetSessionRoot(session_root);
-          };
-        };
-      };
-    }; break;
-
-    default: {
-    }; break;
-  };
-  config_close(cfile);
-  if(cf) delete cf;
+  enable_arc_interface = enable_arc;
+  enable_emies_interface = enable_emies;
   return true;
 }
 
