@@ -32,16 +32,8 @@ bool configure_user_dirs(const std::string &my_username,
                 std::string& allow_submit,bool& strict_session,
                 std::string& gridftp_endpoint,
                 std::string& arex_endpoint,
+                bool& enable_arc_interface,
+                bool& enable_emies_interface,
                 const GMEnvironment& env);
 
-/*
-  Reads configuration file to find all defined control directories.
-  Returns
-    true - success
-    false - failure
-    On success 'control_dirs' contains list of all control directories.
-*/
-bool configure_users_dirs(JobUsers& users,GMEnvironment& env);
-bool configure_users_dirs(Arc::XMLNode cfg,JobUsers& users);
-
 #endif // __GM_CONFIG_PRE_H__
