@@ -7,11 +7,16 @@
 
 class JobLog;
 class JobsListConfig;
+namespace ARex {
+  class DelegationStores;
+}
 
 class GMEnvironment {
   bool valid_;
   JobLog& job_log_;
   JobsListConfig& jobs_cfg_;
+  // TODO: this should go away after proper locking in DelegationStore is implemented
+  ARex::DelegationStores* delegations_;
  public:
   GMEnvironment(JobLog& job_log,JobsListConfig& jcfg,bool guess = false);
   operator bool(void) const { return valid_; };
@@ -37,6 +42,10 @@ class GMEnvironment {
   std::string cert_dir_loc() const;
   void cert_dir_loc(const std::string&) const;
 
+  // VOMS lsc root directory location
+  std::string voms_dir_loc() const;
+  void voms_dir_loc(const std::string&) const;
+
   // RTE setup scripts
   std::string runtime_config_dir(void) const;
   void runtime_config_dir(const std::string&);
@@ -49,6 +58,8 @@ class GMEnvironment {
   JobLog& job_log() const;
   JobsListConfig& jobs_cfg() const;
 
+  ARex::DelegationStores* delegations(void) const;
+  void delegations(ARex::DelegationStores*);
 };
 
 ///  Read environment, check files and set variables
