@@ -33,25 +33,6 @@
 #include "info_types.h"
 #include "info_files.h"
 
-#if defined __GNUC__ && __GNUC__ >= 3
-
-#define istream_readline(__f,__s,__n) {      \
-   __f.get(__s,__n,__f.widen('\n'));         \
-   if(__f.fail()) __f.clear();               \
-   __f.ignore(std::numeric_limits<std::streamsize>::max(), __f.widen('\n')); \
-}
-
-#else
-
-#define istream_readline(__f,__s,__n) {      \
-   __f.get(__s,__n,'\n');         \
-   if(__f.fail()) __f.clear();               \
-   __f.ignore(INT_MAX,'\n'); \
-}
-
-#endif
-
-
 const char * const sfx_failed      = ".failed";
 const char * const sfx_cancel      = ".cancel";
 const char * const sfx_restart     = ".restart";
@@ -320,6 +301,8 @@ bool job_controldiag_mark_put(const JobDescription &desc,const JobUser &user,cha
   if(!fix_file_owner(fname,desc,user)) return false;
   if(!fix_file_permissions(fname)) return false;
   if(args == NULL) return true;
+  struct stat st;
+  if(args[0] && stat(args[0], &st) != 0) return true;
   int h = open(fname.c_str(),O_WRONLY);
   if(h == -1) return false;
   int r;
