@@ -5,6 +5,7 @@
 #include <cstdio>
 #include <fstream>
 #include <pwd.h>
+#include <unistd.h>
 
 #include <arc/XMLNode.h>
 #include <arc/ArcConfig.h>
@@ -16,10 +17,11 @@
 
 #include "jobs/users.h"
 #include "conf/conf_file.h"
+#include "conf/conf_staging.h"
 #include "jobs/plugins.h"
 #include "files/info_files.h"
 #include "jobs/commfifo.h"
-#include "jobs/states.h"
+#include "jobs/job_config.h"
 #include "log/job_log.h"
 
 void get_arex_xml(Arc::XMLNode& arex,GMEnvironment& env) {
@@ -51,22 +53,32 @@ void get_arex_xml(Arc::XMLNode& arex,GMEnvironment& env) {
 
 /** Fill maps with shares taken from data staging states log */
 void get_new_data_staging_shares(const std::string& control_dir,
+                                 const GMEnvironment& env,
                                  std::map<std::string, int>& share_preparing,
                                  std::map<std::string, int>& share_preparing_pending,
                                  std::map<std::string, int>& share_finishing,
                                  std::map<std::string, int>& share_finishing_pending) {
-  // read dtrstate.log
-  std::list<std::string> data;
-  if (!Arc::FileRead(control_dir+"/dtrstate.log", data)) {
-    std::cout<<"Can't read transfer states from "<<control_dir<<"/dtrstate.log";
+  // get DTR configuration
+  StagingConfig staging_conf(env);
+  if (!staging_conf) {
+    std::cout<<"Could not read data staging configuration from "<<env.nordugrid_config_loc()<<std::endl;
     return;
   }
-  // format DTR_ID state priority share
+  std::string dtr_log = staging_conf.get_dtr_log();
+  if (dtr_log.empty()) dtr_log = control_dir+"/dtrstate.log";
+
+  // read DTR state info
+  std::list<std::string> data;
+  if (!Arc::FileRead(dtr_log, data)) {
+    std::cout<<"Can't read transfer states from "<<dtr_log<<". Perhaps A-REX is not running?"<<std::endl;
+    return;
+  }
+  // format DTR_ID state priority share [destinatinon]
   // any state but TRANSFERRING is a pending state
   for (std::list<std::string>::iterator line = data.begin(); line != data.end(); ++line) {
     std::vector<std::string> entries;
     Arc::tokenize(*line, entries, " ");
-    if (entries.size() != 4) continue;
+    if (entries.size() < 4 || entries.size() > 6) continue;
 
     std::string state = entries[1];
     std::string share = entries[3];
@@ -197,15 +209,17 @@ int main(int argc, char* argv[]) {
       std::cout<<"Can't read configuration file"<<std::endl;
       return 1;
     }
+    bool enable_arc = false;
+    bool enable_emies = false;
     if (config_detect(cfile) == config_file_XML) {
       // take out the element that can be passed to configure_serviced_users
       Arc::XMLNode arex;
       get_arex_xml(arex,env);
-      if (!arex || !configure_serviced_users(arex, users, my_uid, my_username, my_user)) {
+      if (!arex || !configure_serviced_users(arex, users/*, my_uid, my_username*/, my_user, enable_arc, enable_emies)) {
         std::cout<<"Error processing configuration."<<std::endl;
         return 1;
       }
-    } else if(!configure_serviced_users(users,my_uid,my_username,my_user)) {
+    } else if(!configure_serviced_users(users/*, my_uid, my_username*/, my_user, enable_arc, enable_emies)) {
       std::cout<<"Error processing configuration."<<std::endl;
       return 1;
     }
@@ -245,7 +259,7 @@ int main(int argc, char* argv[]) {
   for (JobUsers::iterator user = users.begin(); user != users.end(); ++user) {
     if((!notshow_jobs) || (!notshow_states) || (show_share)) {
       if (show_share && jobs_cfg.GetNewDataStaging()) {
-        get_new_data_staging_shares(user->ControlDir(),
+        get_new_data_staging_shares(user->ControlDir(), env,
                                     share_preparing, share_preparing_pending,
                                     share_finishing, share_finishing_pending);
       }
