@@ -23,6 +23,7 @@
 #include <arc/DateTime.h>
 #include <arc/Logger.h>
 #include <arc/Utils.h>
+#include <arc/GUID.h>
 #include <arc/credential/Credential.h>
 
 #include "../conf/conf.h"
@@ -37,11 +38,11 @@
 #include "../misc/escaped.h"
 #include "../misc/proxy.h"
 #include "../run/run_parallel.h"
-#include "../log/job_log.h"
 #include "../../../gridftpd/userspec.h"
 #include "../../../gridftpd/names.h"
 #include "../../../gridftpd/misc.h"
 #include "../../../gridftpd/fileplugin/fileplugin.h"
+#include "../../delegation/DelegationStore.h"
 
 #ifdef HAVE_GACL
 #include "../../../gridftpd/auth/gacl_auth.h"
@@ -121,7 +122,7 @@ static void job_subst(std::string& str,void* arg) {
 }
 
 
-JobPlugin::JobPlugin(std::istream &cfile,userspec_t &user_s):user_a(user_s.user),job_map(user_s.user) {
+JobPlugin::JobPlugin(std::istream &cfile,userspec_t &user_s):env(job_log,jobs_cfg,true),user_a(user_s.user),job_map(user_s.user) {
   initialized=true;
   rsl_opened=false;
   job_rsl_max_size = DEFAULT_JOB_RSL_MAX_SIZE;
@@ -182,9 +183,6 @@ JobPlugin::JobPlugin(std::istream &cfile,userspec_t &user_s):user_a(user_s.user)
       logger.msg(Arc::WARNING, "Unsupported configuration command: %s", command);
     };
   };
-  JobLog job_log;
-  JobsListConfig jobs_cfg;
-  GMEnvironment env(job_log,jobs_cfg,true);
   if(!env) {
     logger.msg(Arc::ERROR, "Environment could not be set up");
     initialized = false;
@@ -214,11 +212,13 @@ JobPlugin::JobPlugin(std::istream &cfile,userspec_t &user_s):user_a(user_s.user)
         std::string allowsubmit;
         bool strict_session;
         std::string endpoint2;
+        bool enable_arc;
+        bool enable_emies;
         if(!configure_user_dirs(uname,
           control_dir,session_roots,
           session_dirs_non_draining,
           default_lrms,default_queue,avail_queues,*cont_plugins,*cred_plugin,
-          allowsubmit,strict_session,endpoint,endpoint2,env)) {
+          allowsubmit,strict_session,endpoint,endpoint2,enable_arc,enable_emies,env)) {
           logger.msg(Arc::ERROR, "Failed processing grid-manager configuration");
           initialized=false;
         } else if (gm_dirs_info.size() > 0 && session_roots.size() > 1) {
@@ -690,7 +690,7 @@ int JobPlugin::close(bool eof) {
       logger.msg(Arc::ERROR, "%s", error_description);
       return 1;
     };
-    if(job_desc.failedstate.length() == 0) {
+    if(job_desc.failedstate.empty()) {
       error_description="Job can't be restarted.";
       logger.msg(Arc::ERROR, "%s", error_description);
       return 1;
@@ -825,6 +825,8 @@ int JobPlugin::close(bool eof) {
     globalid+=job_id;
     job_desc.globalid=globalid;
   };
+  job_desc.headnode=endpoint;
+  job_desc.interface="org.nordugrid.gridftpjob";
   /* ***********************************************
    * Try to create proxy                           *
    *********************************************** */
@@ -855,9 +857,6 @@ int JobPlugin::close(bool eof) {
     ::close(h);
     ::close(hh);
     try {
-      JobLog job_log;
-      JobsListConfig jobs_cfg;
-      GMEnvironment env(job_log,jobs_cfg);
       Arc::Credential ci(proxy_fname, proxy_fname, env.cert_dir_loc(), "");
       job_desc.expiretime = ci.GetEndTime();
     } catch (std::exception) {
@@ -873,6 +872,9 @@ int JobPlugin::close(bool eof) {
     error_description="Failed to create job description.";
     return 1;
   };
+  /* ******************************************
+   * Write access policy                      *
+   ****************************************** */
   if(acl.length() != 0) {
     if(!job_acl_write_file(job_id,*user,acl)) {
       logger.msg(Arc::ERROR, "Failed writing ACL");
@@ -881,6 +883,18 @@ int JobPlugin::close(bool eof) {
       return 1;
     };
   };
+  /* ***********************************************
+   * Collect delegation identifiers                *
+   *********************************************** */
+  std::list<std::string> deleg_ids;
+  for(std::list<FileData>::iterator f = job_desc.inputdata.begin();
+                                      f != job_desc.inputdata.end();++f) {
+    if(!f->cred.empty()) deleg_ids.push_back(f->cred);
+  };
+  for(std::list<FileData>::iterator f = job_desc.outputdata.begin();
+                                      f != job_desc.outputdata.end();++f) {
+    if(!f->cred.empty()) deleg_ids.push_back(f->cred);
+  };
   /* ***********************************************
    * Call authentication/authorization plugin/exec *
    *********************************************** */
@@ -965,6 +979,15 @@ int JobPlugin::close(bool eof) {
     error_description="Failed registering job in grid-manager.";
     return 1;
   };
+
+  // Put lock on delegated credentials
+  // In current implementation it may be risky to use multiple DelegationStore
+  // objects for accessing delegations. Either database is stays undamaged
+  // still needs investigation. But in current situation it should not happen
+  // because job description sent over gridftp does not contain per-file
+  // delegations.
+  ARex::DelegationStore(user->DelegationDir()).LockCred(job_id,deleg_ids,subject);
+
   SignalFIFO(*user);
   job_id.resize(0);
   chosenFilePlugin = NULL;
@@ -1189,9 +1212,6 @@ int JobPlugin::checkdir(std::string &dirname) {
     std::string old_proxy_fname=user->ControlDir()+"/job."+id+".proxy";
     Arc::Time new_proxy_expires;
     Arc::Time old_proxy_expires;
-    JobLog job_log;
-    JobsListConfig jobs_cfg;
-    GMEnvironment env(job_log,jobs_cfg);
     try {
       Arc::Credential new_ci(proxy_fname, proxy_fname, env.cert_dir_loc(), "");
       new_proxy_expires = new_ci.GetEndTime();
@@ -1357,9 +1377,11 @@ bool JobPlugin::make_job_id(void) {
   bool found = false;
   delete_job_id();
   for(int i=0;i<100;i++) {
-    std::string id=Arc::tostring((unsigned int)getpid())+
-                   Arc::tostring((unsigned int)time(NULL))+
-                   Arc::tostring(rand(),1);
+    //std::string id=Arc::tostring((unsigned int)getpid())+
+    //               Arc::tostring((unsigned int)time(NULL))+
+    //               Arc::tostring(rand(),1);
+    std::string id;
+    Arc::GUID(id);
     // create job.id.description file then loop through all control dirs to find if it already exists
     std::vector<gm_dirs_>::iterator it = gm_dirs_info.begin();
     std::string fname=it->control_dir+"/job."+id+".description";
