@@ -273,13 +273,15 @@ bool JobsList::ActJobs(void) {
   bool once_more = false;
   bool postpone_preparing = false;
   bool postpone_finishing = false;
-  if((jcfg.max_jobs_processing != -1) && 
-     (!jcfg.use_local_transfer) && 
-     ((JOB_NUM_PROCESSING*3) > (jcfg.max_jobs_processing*2))) {
-    if(JOB_NUM_PREPARING > JOB_NUM_FINISHING) { 
-      postpone_preparing=true; 
-    } else if(JOB_NUM_PREPARING < JOB_NUM_FINISHING) {
-      postpone_finishing=true;
+  if (!(jcfg.use_new_data_staging && dtr_generator)) {
+    if((jcfg.max_jobs_processing != -1) && 
+       (!jcfg.use_local_transfer) && 
+       ((JOB_NUM_PROCESSING*3) > (jcfg.max_jobs_processing*2))) {
+      if(JOB_NUM_PREPARING > JOB_NUM_FINISHING) { 
+        postpone_preparing=true; 
+      } else if(JOB_NUM_PREPARING < JOB_NUM_FINISHING) {
+        postpone_finishing=true;
+      };
     };
   };
   // first pass - optionally skipping some states
@@ -379,6 +381,13 @@ bool JobsList::FailedJob(const JobsList::iterator &i,bool cancel) {
   } else {
     r=false;
   };
+  // If the job failed during FINISHING then uploader or DTR deals with .output
+  // The exception is cancelling uploader since process is simply killed and
+  // does not get the chance to change .output.
+  if (i->get_state() == JOB_STATE_FINISHING && (!cancel || dtr_generator)) {
+    if (i->local) job_local_write_file(*i,*user,*(i->local));
+    return r;
+  }
   // adjust output files to failure state
   // Not good looking code
   std::string filename = user->ControlDir() + "/job." + i->get_id() + ".description";
@@ -396,7 +405,7 @@ bool JobsList::FailedJob(const JobsList::iterator &i,bool cancel) {
       } else {
         std::string path;
         ARex::DelegationStores* delegs = user->Env().delegations();
-        if(delegs) path = (*delegs)[user->DelegationDir()].FindCred(f->cred,i->local->DN);
+        if(delegs && i->local) path = (*delegs)[user->DelegationDir()].FindCred(f->cred,i->local->DN);
         f->cred = path;
       };
       if(i->local) ++(i->local->uploads);
@@ -406,7 +415,7 @@ bool JobsList::FailedJob(const JobsList::iterator &i,bool cancel) {
     r=false;
     logger.msg(Arc::ERROR,"%s: Failed writing list of output files: %s",i->job_id,Arc::StrError(errno));
   };
-  job_local_write_file(*i,*user,*(i->local));
+  if(i->local) job_local_write_file(*i,*user,*(i->local));
   /*
   std::list<FileData> fl;
   if(job_output_read_file(i->job_id,*user,fl)) {
@@ -444,8 +453,9 @@ bool JobsList::GetLocalDescription(const JobsList::iterator &i) {
 bool JobsList::state_submitting(const JobsList::iterator &i,bool &state_changed,bool cancel) {
   JobsListConfig& jcfg = user->Env().jobs_cfg();
   if(i->child == NULL) {
-    /* no child was running yet, or recovering from fault */
-    /* write grami file for globus-script-X-submit */
+    // no child was running yet, or recovering from fault 
+    // write grami file for globus-script-X-submit 
+    // TODO: read existing grami file to check if job is already submited
     JobLocalDescription* job_desc;
     if(i->local) { job_desc=i->local; }
     else {
@@ -480,7 +490,7 @@ bool JobsList::state_submitting(const JobsList::iterator &i,bool &state_changed,
     if(cancel) { cmd=user->Env().nordugrid_data_loc()+"/cancel-"+job_desc->lrms+"-job"; }
     else { cmd=user->Env().nordugrid_data_loc()+"/submit-"+job_desc->lrms+"-job"; };
     if(!cancel) {
-      logger.msg(Arc::INFO,"%s: state SUBMITTING: starting child: %s",i->job_id,cmd);
+      logger.msg(Arc::INFO,"%s: state SUBMIT: starting child: %s",i->job_id,cmd);
     } else {
       if(!job_lrms_mark_check(i->job_id,*user)) {
         logger.msg(Arc::INFO,"%s: state CANCELING: starting child: %s",i->job_id,cmd);
@@ -506,30 +516,74 @@ bool JobsList::state_submitting(const JobsList::iterator &i,bool &state_changed,
     return true;
   }
   else {
-    /* child was run - check exit code */
+    // child was run - check if exited and then exit code
+    bool simulate_success = false;
     if(i->child->Running()) {
-      /* child is running - come later */
-      return true;
-    };
-    if(!cancel) {
-      logger.msg(Arc::INFO,"%s: state SUBMITTING: child exited with code %i",i->job_id,i->child->Result());
-    } else {
-      if((i->child->ExitTime() != Arc::Time::UNDEFINED) &&
-         ((Arc::Time() - i->child->ExitTime()) < (user->Env().jobs_cfg().WakeupPeriod()*2))) {
-        // not ideal solution
-        logger.msg(Arc::INFO,"%s: state CANCELING: child exited with code %i",i->job_id,i->child->Result());
+      // child is running - come later
+      // Due to unknown reason sometimes child exit event is lost. 
+      // As workaround check if child is running for too long. If
+      // it does then check in grami file for generated local id
+      // or in case of cancel just assume child exited.
+      if((Arc::Time() - i->child->RunTime()) > Arc::Period(CHILD_RUN_TIME_SUSPICIOUS)) {
+        if(!cancel) {
+          // Check if local id is already obtained
+          std::string local_id=read_grami(i->job_id,*user);
+          if(local_id.length() > 0) {
+            simulate_success = true;
+            logger.msg(Arc::ERROR,"%s: Job submission to LRMS takes too long. But ID is already obtained. Pretending submission is done.",i->job_id);
+          };
+        } else {
+          // Check if diagnosticvs collection is done
+          if(job_lrms_mark_check(i->job_id,*user)) {
+            simulate_success = true;
+            logger.msg(Arc::ERROR,"%s: Job cancel takes too long. But diagnostic collection seems to be done. Pretending cancel succeeded.",i->job_id);
+          };
+        };
       };
+      if((!simulate_success) && (Arc::Time() - i->child->RunTime()) > Arc::Period(CHILD_RUN_TIME_TOO_LONG)) {
+        // In any case it is way too long. Job must fail. Otherwise it will hang forewer.
+        delete i->child; i->child=NULL;
+        if(!cancel) {
+          logger.msg(Arc::ERROR,"%s: Job submission to LRMS takes too long. Failing.",i->job_id);
+          JobFailStateRemember(i,JOB_STATE_SUBMITTING);
+          i->AddFailure("Job submission to LRMS failed");
+          // It would be nice to cancel if job finally submits. But we do not know id.
+          return false;
+        } else {
+          logger.msg(Arc::ERROR,"%s: Job cancel takes too long. Failing.",i->job_id);
+          delete i->child; i->child=NULL;
+          return false;
+        };
+      };
+      if(!simulate_success) return true;
     };
-    if(i->child->Result() != 0) { 
+    if(!simulate_success) {
+      // real processing
       if(!cancel) {
-        logger.msg(Arc::ERROR,"%s: Job submission to LRMS failed",i->job_id);
-        JobFailStateRemember(i,JOB_STATE_SUBMITTING);
+        logger.msg(Arc::INFO,"%s: state SUBMIT: child exited with code %i",i->job_id,i->child->Result());
       } else {
-        logger.msg(Arc::ERROR,"%s: Failed to cancel running job",i->job_id);
+        if((i->child->ExitTime() != Arc::Time::UNDEFINED) &&
+           ((Arc::Time() - i->child->ExitTime()) < (user->Env().jobs_cfg().WakeupPeriod()*2))) {
+          // not ideal solution
+          logger.msg(Arc::INFO,"%s: state CANCELING: child exited with code %i",i->job_id,i->child->Result());
+        };
       };
-      delete i->child; i->child=NULL;
-      if(!cancel) i->AddFailure("Job submission to LRMS failed");
-      return false;
+      // Another workaround in Run class may also detect lost child.
+      // It then sets exit code to -1. This value is also set in
+      // case child was killed. So it is worth to check grami anyway.
+      if((i->child->Result() != 0) && (i->child->Result() != -1)) {
+        if(!cancel) {
+          logger.msg(Arc::ERROR,"%s: Job submission to LRMS failed",i->job_id);
+          JobFailStateRemember(i,JOB_STATE_SUBMITTING);
+        } else {
+          logger.msg(Arc::ERROR,"%s: Failed to cancel running job",i->job_id);
+        };
+        delete i->child; i->child=NULL;
+        if(!cancel) i->AddFailure("Job submission to LRMS failed");
+        return false;
+      };
+    } else {
+      // Just pretend everything is alright
     };
     if(!cancel) {
       delete i->child; i->child=NULL;
@@ -546,19 +600,6 @@ bool JobsList::state_submitting(const JobsList::iterator &i,bool &state_changed,
         i->AddFailure("Internal error");
         return false;
       };   
-      /*
-      JobLocalDescription *job_desc;
-      if(i->local) { job_desc=i->local; }
-      else { job_desc=new JobLocalDescription; };
-      if(i->local == NULL) {
-        if(!job_local_read_file(i->job_id,*user,*job_desc)) {
-          logger.msg(Arc::ERROR,"%s: Failed reading local information",i->job_id);
-          i->AddFailure("Internal error");
-          delete job_desc; return false;
-        };
-        i->local=job_desc;
-      };
-      */
       i->local->localid=local_id;
       if(!job_local_write_file(*i,*user,*(i->local))) {
         i->AddFailure("Internal error");
@@ -572,7 +613,7 @@ bool JobsList::state_submitting(const JobsList::iterator &i,bool &state_changed,
         if((i->child->ExitTime() != Arc::Time::UNDEFINED) &&
            ((Arc::Time() - i->child->ExitTime()) > Arc::Period(Arc::Time::HOUR))) {
           // it takes too long
-          logger.msg(Arc::INFO,"%s: state CANCELING: timeout waiting for cancelation",i->job_id);
+          logger.msg(Arc::ERROR,"%s: state CANCELING: timeout waiting for cancelation",i->job_id);
           delete i->child; i->child=NULL;
           return false;
         };
@@ -1019,14 +1060,14 @@ void JobsList::ActJobUndefined(JobsList::iterator &i,
           i->job_state = new_state; /* this can be any state, if we are
                                          recovering after failure */
           if(new_state == JOB_STATE_ACCEPTED) {
-            state_changed = true; // at least that makes email notification
+            state_changed = true; // to trigger email notification, etc.
             // parse request (do it here because any other processing can 
             // read 'local' and then we never know if it was new job)
             JobLocalDescription *job_desc;
             job_desc = new JobLocalDescription;
             //job_desc->headnode = user->HeadNode(); done during job creation
             job_desc->sessiondir=i->session_dir;
-            /* first phase of job - just  accepted - parse request */
+            // first phase of job - just  accepted - parse request
             logger.msg(Arc::INFO,"%s: State: ACCEPTED: parsing job description",i->job_id);
             if(!process_job_req(*user,*i,*job_desc)) {
               logger.msg(Arc::ERROR,"%s: Processing job description failed",i->job_id);
@@ -1058,7 +1099,9 @@ void JobsList::ActJobUndefined(JobsList::iterator &i,
             job_state_write_file(*i,*user,i->job_state);
 
             // prepare information for logger
-            user->Env().job_log().make_file(*i,*user);
+            // This call is not needed here because at higher level make_file()
+            // is called for every state change
+            //user->Env().job_log().make_file(*i,*user);
           } else if(new_state == JOB_STATE_FINISHED) {
             once_more=true;
             job_state_write_file(*i,*user,i->job_state);
@@ -1255,7 +1298,7 @@ void JobsList::ActJobSubmitting(JobsList::iterator &i,
                                 bool& job_error,bool& state_changed) {
         /* state submitting - everything is ready for submission - 
            so run submission */
-        logger.msg(Arc::VERBOSE,"%s: State: SUBMITTING",i->job_id);
+        logger.msg(Arc::VERBOSE,"%s: State: SUBMIT",i->job_id);
         if(state_submitting(i,state_changed)) {
           if(state_changed) {
             i->job_state = JOB_STATE_INLRMS;
