@@ -16,7 +16,7 @@
 
 #include <arc/XMLNode.h>
 #include <arc/client/Job.h>
-#include <arc/client/JobController.h>
+#include <arc/client/JobControllerPlugin.h>
 #include <arc/UserConfig.h>
 #include <arc/CheckSum.h>
 #include <arc/data/FileCache.h>
@@ -30,6 +30,7 @@
 #include <arc/FileUtils.h>
 
 #include "../jobs/job.h"
+#include "../jobs/job_config.h"
 #include "../jobs/users.h"
 #include "../files/info_types.h"
 #include "../files/info_files.h"
@@ -79,9 +80,9 @@ class FileDataEx : public FileData {
    */
   std::string starttime; /* time of transfer started */
   std::string endtime; /* time of transfer finished */
-  /* if the file was retrieved from cache: 
+  /* if the file was retrieved from cache:
    *  - "yes";
-   *  - "no"; 
+   *  - "no";
    */
   std::string fromcache;
   time_t mtime;
@@ -120,7 +121,7 @@ static int clean_files(std::list<FileData> &job_files,char* session_dir) {
   std::string session(session_dir);
   /* delete only downloadable files, let user manage his/hers files */
   std::list<FileData> tmp;
-  if(delete_all_files(session,job_files,false,true,false) != 2) return 0;
+  if(delete_all_files(session,job_files,false,0,0) != 2) return 0;
   return 1;
 }
 
@@ -252,7 +253,7 @@ class PointPair {
       logger.msg(Arc::INFO, "Downloaded file %s", it->lfn);
       delete it->pair; it->pair=NULL;
       it->endtime=Arc::Time().str(Arc::UTCTime);
-      if (res == Arc::DataStatus::SuccessCached) 
+      if (res == Arc::DataStatus::SuccessCached)
         it->fromcache="yes";
       else
         it->fromcache="no";
@@ -292,7 +293,7 @@ int main(int argc,char** argv) {
   std::string preferred_pattern("");
   std::string failure_reason("");
   std::string x509_proxy, x509_cert, x509_key, x509_cadir;
-  srand(time(NULL) + getpid()); 
+  srand(time(NULL) + getpid());
   JobLog job_log;
   JobsListConfig jobs_cfg;
   GMEnvironment env(job_log,jobs_cfg);
@@ -307,7 +308,7 @@ int main(int argc,char** argv) {
         std::cerr<<"Usage: downloader [-hclpf] [-C conf_file] [-n files] [-t threads] [-U uid]"<<std::endl;
         std::cerr<<"                  [-u username] [-s min_speed] [-S min_speed_time]"<<std::endl;
         std::cerr<<"                  [-a min_average_speed] [-i min_activity_time]"<<std::endl;
-        std::cerr<<"                  [-d debug_level] [-r preferred_pattern job_id"<<std::endl;
+        std::cerr<<"                  [-d debug_level] [-r preferred_pattern] job_id"<<std::endl;
         std::cerr<<"                  control_directory session_directory [cache options]"<<std::endl;
         exit(1);
       }; break;
@@ -463,9 +464,7 @@ int main(int argc,char** argv) {
       cache = new Arc::FileCache(user.CacheParams().getCacheDirs(),
                                  user.CacheParams().getRemoteCacheDirs(),
                                  user.CacheParams().getDrainingCacheDirs(),
-                                 std::string(id), uid, gid,
-                                 user.CacheParams().getCacheMax(),
-                                 user.CacheParams().getCacheMin());
+                                 std::string(id), uid, gid);
       if (!(user.CacheParams().getCacheDirs().size() == 0) && !(*cache)) {
         logger.msg(Arc::ERROR, "Error creating cache");
         delete cache;
@@ -493,7 +492,7 @@ int main(int argc,char** argv) {
     // if no cache defined, use null cache
     cache = new Arc::FileCache();
   }
-  
+
   if(min_speed != 0)
     logger.msg(Arc::VERBOSE, "Minimal speed: %llu B/s during %i s", min_speed, min_speed_time);
   if(min_average_speed != 0)
@@ -519,9 +518,6 @@ int main(int argc,char** argv) {
   Arc::UserConfig usercfg(cred_type);
   usercfg.UtilsDirPath(control_dir);
   usercfg.SetUser(Arc::User(uid));
-  usercfg.ProxyPath(x509_proxy);
-  usercfg.CertificatePath(x509_cert);
-  usercfg.KeyPath(x509_key);
   usercfg.CACertificatesDirectory(x509_cadir);
 
   Arc::DataMover mover;
@@ -555,11 +551,11 @@ int main(int argc,char** argv) {
       }
     }
   }
-  // check if any input files are also output files downloadable by user (bug 1387)
+  // check if any input files are also output files (bug 1387 and 2793)
   if(job_output_read_file(desc.get_id(),user,output_files)) {
     for (std::list<FileData>::iterator j = output_files.begin(); j != output_files.end(); j++) {
       for (std::list<FileData>::iterator i = job_files_.begin(); i != job_files_.end(); i++) {
-        if (i->pfn == j->pfn && j->lfn.empty() && i->lfn.find(':') != std::string::npos) {
+        if (i->pfn == j->pfn && i->lfn.find(':') != std::string::npos) {
           Arc::URL u(i->lfn);
           std::string opt = u.Option("cache");
           // don't add copy option if exists or current option is "no" or "renew"
@@ -630,6 +626,15 @@ int main(int argc,char** argv) {
             failure_reason+=std::string("User requested local input file ")+source.c_str()+"\n";
             logger.msg(Arc::ERROR, "Local source for download: %s", source); res=1; goto exit;
           };
+          if(i->cred.empty()) {
+            usercfg.ProxyPath(x509_proxy);
+            usercfg.CertificatePath(x509_cert);
+            usercfg.KeyPath(x509_key);
+          } else {
+            usercfg.ProxyPath(i->cred);
+            usercfg.CertificatePath("");
+            usercfg.KeyPath("");
+          };
           PointPair* pair = new PointPair(source,destination,usercfg);
           if(!(pair->source)) {
             failure_reason+=std::string("Can't accept URL ")+source.c_str()+"\n";
@@ -662,7 +667,7 @@ int main(int argc,char** argv) {
     // Processing initiated - now wait for event
     pair_condition.wait_nonblock();
   };
-  
+
   {
     std::list<std::string> transfer_stats;
     transfer_stats.clear(); // paranoid initialization
@@ -677,13 +682,13 @@ int main(int argc,char** argv) {
       transfer_parameters += "size=" + Arc::tostring(st.st_size) + ',';
       transfer_parameters += "starttime=" + i->starttime + ',';
       transfer_parameters += "endtime=" + i->endtime + ',';
-      transfer_parameters += "fromcache=" + i->fromcache; 
+      transfer_parameters += "fromcache=" + i->fromcache;
       transfer_stats.push_back(transfer_parameters);
       if(Arc::URL(i->lfn).Option("exec") == "yes") {
         fix_file_permissions(session_dir+i->pfn,true);
       };
     };
-  
+
     std::string fname = user.ControlDir() + "/job." + desc.get_id() + ".statistics";
     std::ofstream f(fname.c_str(),std::ios::out | std::ios::app);
     if(f.is_open() ) {
@@ -691,7 +696,7 @@ int main(int argc,char** argv) {
   	    f << *it << std::endl;
       f.close();
     }
-  }   
+  }
   for(FileDataEx::iterator i=failed_files.begin();i!=failed_files.end();++i) {
     if (i->res.Retryable() || i->res == Arc::DataStatus::TransferError) {
       logger.msg(Arc::ERROR, "Failed to download (but may be retried) %s",i->lfn);
@@ -808,31 +813,27 @@ int main(int argc,char** argv) {
 
       if (found != std::string::npos) {
         Arc::Job job;
-        job.Flavour = "ARC1";
         job.JobID = Arc::URL(desc.get_local()->migrateactivityid);
         job.Cluster = Arc::URL(desc.get_local()->migrateactivityid.substr(0, found));
+        std::list<Arc::Job*> jobs(1, &job);
 
         Arc::UserConfig usercfg(job.Cluster.Protocol() == "https" ?
                                 Arc::initializeCredentialsType() :
                                 Arc::initializeCredentialsType(Arc::initializeCredentialsType::SkipCredentials));
         if (job.Cluster.Protocol() != "https" ||
             (job.Cluster.Protocol() == "https" && usercfg.CredentialsFound())) {
-          Arc::JobControllerLoader loader;
-          Arc::JobController *jobctrl = loader.load("ARC1", usercfg);
+          Arc::JobControllerPluginLoader loader;
+          Arc::JobControllerPlugin *jobctrl = loader.load("ARC1", usercfg);
           if (jobctrl) {
-            jobctrl->FillJobStore(job);
-
-            std::list<std::string> status;
-            status.push_back("Queuing");
-
-            if (!jobctrl->Kill(status, true) && !desc.get_local()->forcemigration) {
+            jobctrl->UpdateJobs(jobs);
+            if ((job.State != Arc::JobState::QUEUING || !jobctrl->CancelJobs(jobs)) && !desc.get_local()->forcemigration) {
               res = 1;
               failure_reason = "FATAL ERROR: Migration failed attempting to kill old job \"" + desc.get_local()->migrateactivityid + "\".";
             }
           }
           else {
             res = 1;
-            failure_reason = "FATAL ERROR: Migration failed, could not locate ARC1 JobController plugin. Maybe it is not installed?";
+            failure_reason = "FATAL ERROR: Migration failed, could not locate ARC1 JobControllerPlugin plugin. Maybe it is not installed?";
           }
         }
         else {
