@@ -26,6 +26,7 @@
 #include <arc/FileUtils.h>
 
 #include "../jobs/job.h"
+#include "../jobs/job_config.h"
 #include "../jobs/users.h"
 #include "../files/info_types.h"
 #include "../files/info_files.h"
@@ -106,7 +107,7 @@ class SimpleConditionLock {
 
 int clean_files(std::list<FileData> &job_files,char* session_dir) {
   std::string session(session_dir);
-  if(delete_all_files(session,job_files,true) != 2) return 0;
+  if(delete_all_files(session,job_files,true,0,0) != 2) return 0;
   return 1;
 }
 
@@ -373,9 +374,7 @@ int main(int argc,char** argv) {
       cache = new Arc::FileCache(user.CacheParams().getCacheDirs(),
                                  user.CacheParams().getRemoteCacheDirs(),
                                  user.CacheParams().getDrainingCacheDirs(),
-                                 std::string(id), uid, gid,
-                                 user.CacheParams().getCacheMax(),
-                                 user.CacheParams().getCacheMin());
+                                 std::string(id), uid, gid);
       if (!(user.CacheParams().getCacheDirs().size() == 0) && !(*cache)) {
         logger.msg(Arc::ERROR, "Error creating cache");
         delete cache;
@@ -427,9 +426,6 @@ int main(int argc,char** argv) {
   Arc::UserConfig usercfg(cred_type);
   usercfg.UtilsDirPath(control_dir);
   usercfg.SetUser(Arc::User(uid));
-  usercfg.ProxyPath(x509_proxy);
-  usercfg.CertificatePath(x509_cert);
-  usercfg.KeyPath(x509_key);
   usercfg.CACertificatesDirectory(x509_cadir);
 
   Arc::DataMover mover;
@@ -558,6 +554,15 @@ int main(int argc,char** argv) {
             i->res = Arc::DataStatus::WriteAcquireError; failed_files.push_back(*i); i = job_files.erase(i);
             continue;
           };
+          if(i->cred.empty()) {
+            usercfg.ProxyPath(x509_proxy);
+            usercfg.CertificatePath(x509_cert);
+            usercfg.KeyPath(x509_key);
+          } else {
+            usercfg.ProxyPath(i->cred);
+            usercfg.CertificatePath("");
+            usercfg.KeyPath("");
+          };
           PointPair* pair = new PointPair(source,destination,usercfg);
           if(!(pair->source)) {
             failure_reason+=std::string("Can't accept URL ")+source.c_str()+"\n";
@@ -602,6 +607,7 @@ int main(int argc,char** argv) {
     std::list<std::string> transfer_stats;
     transfer_stats.clear(); // paranoid initialization
     std::string transfer_parameters;
+    std::list<FileData> job_files_uploaded;
     
     for(FileDataEx::iterator i=processed_files.begin();i!=processed_files.end();++i) {
       logger.msg(Arc::INFO, "Uploaded %s", i->lfn);
@@ -613,17 +619,23 @@ int main(int argc,char** argv) {
       transfer_parameters += "starttime=" + i->starttime + ',';
       transfer_parameters += "endtime=" + i->endtime;
       transfer_stats.push_back(transfer_parameters);
+      job_files_uploaded.push_back(*i);
     };
     
     std::string fname = user.ControlDir() + "/job." + desc.get_id() + ".statistics";
     std::ofstream f(fname.c_str(),std::ios::out | std::ios::app);
     if(f.is_open() ) {
-  	  for (std::list<std::string>::iterator it=transfer_stats.begin(); it != transfer_stats.end(); ++it)
-  	    f << *it << std::endl;
+      for (std::list<std::string>::iterator it=transfer_stats.begin();
+                                          it != transfer_stats.end(); ++it) {
+        f << *it << std::endl;
+      };
       f.close();
       fix_file_owner(fname,desc,user);
-    }
+    };
    
+    if(!job_output_status_write_file(desc,user,job_files_uploaded)) {
+      logger.msg(Arc::WARNING, "Failed writing output status file");
+    };
   }
   
   for(FileDataEx::iterator i=failed_files.begin();i!=failed_files.end();++i) {
