@@ -331,8 +331,11 @@ sub collect($) {
             $q->{defaultwalltime} = int $qinfo->{defaultwallt}/60 if defined $qinfo->{defaultwallt};
             $q->{running} = $qinfo->{running} if defined $qinfo->{running};
             $q->{gridrunning} = $gridrunning{$share} || 0;   
-            $q->{gridqueued} = $gridqueued{$share} || 0;    
-            $q->{localqueued} = ($qinfo->{queued} - ( $gridqueued{$share} || 0 ));   
+            $q->{gridqueued} = $gridqueued{$share} || 0;
+            $q->{localqueued} = ($qinfo->{queued} - ( $gridqueued{$share} || 0 ));
+            if ( $q->{localqueued} < 0 ) {
+                $q->{localqueued} = 0;
+            }  
             $q->{prelrmsqueued} = $prelrmsqueued{$share} || 0;
             if ( $sconfig->{totalcpus} ) {
                 $q->{totalcpus} = $sconfig->{totalcpus}; # orphan
@@ -375,6 +378,11 @@ sub collect($) {
                 $j->{rerunable} = $gmjob->{failedstate} ? $gmjob->{failedstate} : 'none'
                     if $gmjob->{status} eq "FAILED";
                 $j->{comment} = [ $gmjob->{comment} ] if $gmjob->{comment};
+                # added to record which was the submission interface
+                if ( $gmjob->{interface} ) {
+                        my $submittedstring = 'SubmittedVia='.$gmjob->{interface};
+                        push(@{$j->{comment}}, $submittedstring);
+                };
                 $j->{reqcputime} = int $gmjob->{reqcputime}/60 if $gmjob->{reqcputime};
                 $j->{reqwalltime} = int $gmjob->{reqwalltime}/60 if $gmjob->{reqwalltime};
 
