@@ -38,6 +38,8 @@ my $lrms_options = {
     ll_bin_path => '*',
     slurm_bin_path => '*',
     slurm_wakeupperiod => '*',
+    dgbridge_stage_dir => '*',
+    dgbridge_stage_prepend => '*',
 };
 my $lrms_share_options = {
     fork_job_limit => '*',
@@ -78,6 +80,7 @@ my $share_options = {
     SchedulingPolicy => '*',
     Preemption => '*',
     totalcpus => '*',
+    defaultmemory => '*',
 };
 my $gmuser_options = {
     controldir => '',
@@ -106,14 +109,18 @@ my $gmcommon_options = {
     shared_scratch => '*',
     scratchdir => '*',
     use_janitor => '*',
+    enable_emies_interface => '*',
 };
 my $ldap_infosys_options = {
+    SlapdPort => '*',
     bdii_var_dir => '*',
     bdii_tmp_dir => '*',
+    bdii_run_dir => '*',
     infosys_compat => '*',
     infosys_nordugrid => '*',
     infosys_glue12 => '*',
-    infosys_glue2_ldap => '*'
+    infosys_glue2_ldap => '*',
+    bdii_update_pid_file => '*'
 };
 my $gridftpd_options = {
     GridftpdEnabled => '*',
@@ -121,6 +128,16 @@ my $gridftpd_options = {
     GridftpdMountPoint => '*',
     GridftpdAllowNew => '*',
     remotegmdirs => [ '*' ],
+    GridftpdPidFile => '*',
+};
+
+my $admindomain_options = {
+    Name => '*',
+    OtherInfo => [ '*' ],
+    Description => '*',
+    WWW => '*',
+    Distributed => '*',
+    Owner => '*'
 };
 
 # # # # # # # # # # # # # #
@@ -132,6 +149,7 @@ my $config_schema = {
     PublishNordugrid => '*',
     AdminDomain => '*',
     ttl => '*',
+    admindomain => { %$admindomain_options },
     %$gmcommon_options,
     %$gridftpd_options,
     %$ldap_infosys_options,
@@ -208,7 +226,7 @@ my $allbools = [ qw(
                  PublishNordugrid Homogeneous VirtualMachine
                  ConnectivityIn ConnectivityOut Preemption
                  infosys_compat infosys_nordugrid infosys_glue12 infosys_glue2_ldap
-                 GridftpdEnabled GridftpdAllowNew use_janitor) ];
+                 GridftpdEnabled GridftpdAllowNew use_janitor Distributed ) ];
 
 ############################ Generic functions ###########################
 
@@ -636,10 +654,11 @@ sub build_config_from_inifile {
     $config->{control} ||= {};
     $config->{location} ||= {};
     $config->{contacts} ||= [];
-    $config->{accesspolicies} ||= [];
+    $config->{accesspolicies} ||= [];   
     $config->{mappingpolicies} ||= [];
     $config->{xenvs} ||= {};
     $config->{shares} ||= {};
+    $config->{admindomain} ||= {};
 
 
     my $common = { $iniparser->get_section("common") };
@@ -656,7 +675,8 @@ sub build_config_from_inifile {
 
     my $infosys = { $iniparser->get_section("infosys") };
     rename_keys $infosys, $config, {providerlog => 'ProviderLog',
-                                    provider_loglevel => 'debugLevel'};
+                                    provider_loglevel => 'debugLevel',
+                                    port => 'SlapdPort'};
     move_keys $infosys, $config, [keys %$ldap_infosys_options];
 
     my @cnames = $iniparser->list_subsections('grid-manager');
@@ -675,10 +695,27 @@ sub build_config_from_inifile {
         $config->{GridftpdMountPoint} = $gjconf{path} if $gjconf{path};
         $config->{GridftpdAllowNew} = $gjconf{allownew} if defined $gjconf{allownew};
         $config->{remotegmdirs} = $gjconf{remotegmdirs} if defined $gjconf{remotegmdirs};
+        $config->{GridftpdPidFile} = $gconf{pidfile} if defined $gconf{pidfile};
     } else {
         $config->{GridftpdEnabled} = 'no';
     }
 
+    # global AdminDomain configuration
+    if ($iniparser->has_section('infosys/admindomain')) {
+        my $admindomain_options = { $iniparser->get_section('infosys/admindomain') };
+        rename_keys $admindomain_options, $config->{'admindomain'}, {name => 'Name',
+                                                    otherinfo => 'OtherInfo',
+                                                    description => 'Description',
+                                                    www => 'WWW',
+                                                    distributed => 'Distributed',
+                                                    owner => 'Owner'
+                                                    };
+        move_keys $admindomain_options, $config->{'admindomain'}, [keys %$admindomain_options];
+
+    } else {
+        $log->info('[infosys/admindomain] section missing. No site information will be published.');
+    }
+
     ############################ legacy ini config file structure #############################
 
     move_keys $common, $config, ['AdminDomain'];
@@ -906,6 +943,7 @@ sub printLRMSConfigScript {
 
     my $cluster = {};
     rename_keys $config->{service}, $cluster, {MaxVirtualMemory => 'nodememory'};
+    move_keys $config->{service}, $cluster, ['defaultmemory'];
 
     _print_shell_section('cluster', $cluster) if %$cluster;
 
