@@ -26,6 +26,10 @@ my $currentqueue = undef;
 # cache info about nodes
 my $pbsnodes;
 
+# PBS type and flavour
+my $lrms_type = undef;
+my $lrms_version = undef;
+
 # Resets queue-specific global variables if
 # the queue has changed since the last call
 sub init_globals($) {
@@ -38,6 +42,29 @@ sub init_globals($) {
     }
 }
 
+# get PBS type and version
+sub get_pbs_version ($) {
+    return unless not defined $lrms_type;
+
+    # path to LRMS commands
+    my ($config) = shift;
+    my ($path) = $$config{pbs_bin_path};
+
+    # determine the flavour and version of PBS
+    my $qmgr_string=`$path/qmgr -c "list server"`;
+    if ( $? != 0 ) {    
+        warning("Can't run qmgr");
+    }
+    if ($qmgr_string =~ /pbs_version = \b(\D+)_(\d\S+)\b/) {
+        $lrms_type = $1;
+        $lrms_version = $2;
+    } else {
+        $qmgr_string =~ /pbs_version = \b(\d\S+)\b/;
+        $lrms_type = "torque";
+        $lrms_version = $1;
+    }
+}
+
 ##########################################
 # Private subs
 ##########################################
@@ -87,16 +114,16 @@ sub split_hostlist {
     my @nodes;
     my $err;
     for my $nodespec (split '\+', $exec_host_string) {
-	if ($nodespec =~ m{^([^/:]+)/\d+(?:\*(\d+))?$}) {  # cases (1) and (2)
-	    my ($nodename, $multiplier) = ($1, $2 || 1);
-	    push @nodes, $nodename for 1..$multiplier;
-	} elsif ($nodespec =~ m{^([^/:]+)(?::(.+))?$}) {  # cases (3) and (4)
-	    my ($nodename, $resc) = ($1, $2 || '');
-	    my $multiplier = get_ncpus($resc);
-	    push @nodes, $nodename for 1..$multiplier;
-	} else {
-	    $err = $nodespec;
-	}
+        if ($nodespec =~ m{^([^/:]+)/\d+(?:\*(\d+))?$}) {  # cases (1) and (2)
+            my ($nodename, $multiplier) = ($1, $2 || 1);
+            push @nodes, $nodename for 1..$multiplier;
+        } elsif ($nodespec =~ m{^([^/:]+)(?::(.+))?$}) {  # cases (3) and (4)
+            my ($nodename, $resc) = ($1, $2 || '');
+            my $multiplier = get_ncpus($resc);
+            push @nodes, $nodename for 1..$multiplier;
+        } else {
+            $err = $nodespec;
+        }
     }
     warning("failed counting nodes in expression: $exec_host_string") if $err;
     return @nodes;
@@ -117,6 +144,26 @@ sub set_cpucount {
     delete $job->{"Resource_List.ncpus"};
 }
 
+# Convert time from [DD:[HH:[MM:]]]SS to minutes
+sub count_time {
+    my $pbs_time = shift;
+    # split and reverse PBS time to start from seconds, then drop seconds
+    my @t = reverse split /:/, $pbs_time;
+    my $minutes = 0;
+
+    if ( ! defined $t[1] ) {
+        # PBS seconds only case
+        $minutes = int( $t[0] / 60 );
+    } else {
+        # drop seconds
+        shift @t;
+        $minutes = $t[0];
+        $minutes += $t[1]*60 if defined $t[1];
+        $minutes += $t[2]*60*24 if defined $t[2];
+    }
+    return $minutes;
+}
+
 sub count_usedcpus {
     my ($select, $nodes, $ncpus) = @_;
     return sum_over_chunks(\&cpus_in_select_chunk, $select) if defined $select;
@@ -256,7 +303,7 @@ sub process_dqueues($$%){
 	@dqnames=split(",",$qstat{'route_destinations'});
 	@dqueues{@dqnames}=undef;
 	foreach my $dqname ( keys %dqueues ) {
-	    debug($dqname);
+	    debug("Processing queues behind routing queue. Current queue is $dqname");
 	    my (%dqstat);
 	    unless (open QSTATOUTPUT,   "$path/qstat -Q -f $dqname 2>/dev/null |") {
 		error("Error in executing qstat: $path/qstat -Q -f $dqname");
@@ -282,7 +329,7 @@ sub process_dqueues($$%){
     # this happens only if the RQ has no data defined on PBS
     # this should solve bug #859
     $singledqueue=shift(@dqnames);
-    debug('Just one queue: '.$singledqueue);
+    debug('Just one queue behind routing queue is currently supported: '.$singledqueue);
     my @attributes=(
 	'max_running',
 	'max_user_run',
@@ -296,7 +343,9 @@ sub process_dqueues($$%){
 	'state_count'
 	);
     foreach my $rkey (@attributes) {
-	debug('with key '.$rkey.' qstat returns '.$qstat{$rkey}.' and the dest. queue has '.$dqueues{$singledqueue}{$rkey} );
+        # line to check queues under routing queue values. Undefined values generate crap in logs,
+        # so is commented out.
+	# debug('with key '.$rkey.' qstat returns '.$qstat{$rkey}.' and the dest. queue has '.$dqueues{$singledqueue}{$rkey} );
 	if (!defined $qstat{$rkey}) {${$_[0]}{$rkey}=$dqueues{$singledqueue}{$rkey};};
     }
     return %dqueues;
@@ -320,26 +369,16 @@ sub cluster_info ($) {
 
     my (%lrms_cluster);
 
-    #determine the flavour and version of PBS"
-    my $qmgr_string=`$path/qmgr -c "list server"`;
-    if ( $? != 0 ) {    
-	warning("Can't run qmgr");
-    }
-    if ($qmgr_string =~ /pbs_version = \b(\D+)_(\d\S+)\b/) {
-      $lrms_cluster{lrms_type} = $1;
-      $lrms_cluster{lrms_glue_type}=lc($1);
-      $lrms_cluster{lrms_version} = $2;
-    }
-    else {
-	$qmgr_string =~ /pbs_version = \b(\d\S+)\b/;
-	$lrms_cluster{lrms_type}="torque";
-	if (exists $$config{scheduling_policy} and
-	    lc($$config{scheduling_policy}) eq "maui") {
-	    $lrms_cluster{lrms_glue_type}="torquemaui"
-	} else {
-	    $lrms_cluster{lrms_glue_type}="torque";
-	}
-	$lrms_cluster{lrms_version}=$1;
+    # flavour and version of PBS
+    get_pbs_version($config);
+    $lrms_cluster{lrms_type} = $lrms_type;
+    $lrms_cluster{lrms_glue_type}=lc($lrms_type);
+    $lrms_cluster{lrms_version} = $lrms_version;
+
+    if ( $lrms_type eq "torque" and
+    exists $$config{scheduling_policy} and
+    lc($$config{scheduling_policy}) eq "maui") {
+        $lrms_cluster{lrms_glue_type}="torquemaui";
     }
 
     # PBS treats cputime limit for parallel/multi-cpu jobs as job-total
@@ -356,55 +395,56 @@ sub cluster_info ($) {
     my ($number_of_running_jobs) = 0;
     $lrms_cluster{cpudistribution} = "";
     my (@cpudist) = 0;
+    my %available_nodes = ();
 
-    foreach my $node (keys %hoh_pbsnodes){
+    # loop over all available nodes 
+    foreach my $node (keys %hoh_pbsnodes) {
+        # skip nodes that does not conform dedicated_node_string filter
+        if ( exists $$config{dedicated_node_string} &&  $$config{dedicated_node_string} ne "") {
+            next unless ( $hoh_pbsnodes{$node}{"properties"} =~ 
+                m/^([^,]+,)*$$config{dedicated_node_string}(,[^,]+)*$/);
+        }
 
-	if ( exists $$config{dedicated_node_string} &&  $$config{dedicated_node_string} ne "") {
-	    unless ( $hoh_pbsnodes{$node}{"properties"} =~
-		     m/^([^,]+,)*$$config{dedicated_node_string}(,[^,]+)*$/) {
-		next;
-	    }
-	}
+        # add node to available_nodes hash
+        $available_nodes{$node} = 1;
 
-	my ($nodestate) = $hoh_pbsnodes{$node}{"state"};      
+        # get node state and number of CPUs
+        my ($nodestate) = $hoh_pbsnodes{$node}{"state"};
 
-	my $nodecpus;
+        my $nodecpus;
         if ($hoh_pbsnodes{$node}{'np'}) {
-	    $nodecpus = $hoh_pbsnodes{$node}{'np'};
+            $nodecpus = $hoh_pbsnodes{$node}{'np'};
         } elsif ($hoh_pbsnodes{$node}{'resources_available.ncpus'}) {
-	    $nodecpus = $hoh_pbsnodes{$node}{'resources_available.ncpus'};
+            $nodecpus = $hoh_pbsnodes{$node}{'resources_available.ncpus'};
         }
 
-	if ($nodestate=~/down/ or $nodestate=~/offline/) {
-	    next;
-	}
+        next if ($nodestate=~/down/ or $nodestate=~/offline/);
+
         if ($nodestate=~/(?:,|^)busy/) {
-           $lrms_cluster{totalcpus} += $nodecpus;
-	   $cpudist[$nodecpus] +=1;
-	   $number_of_running_jobs += $nodecpus;
-	   next;
+            $lrms_cluster{totalcpus} += $nodecpus;
+            $cpudist[$nodecpus] +=1;
+            $number_of_running_jobs += $nodecpus;
+            next;
         }
-	
 
-	$lrms_cluster{totalcpus} += $nodecpus;
+        $lrms_cluster{totalcpus} += $nodecpus;
+        $cpudist[$nodecpus] += 1;
 
-	$cpudist[$nodecpus] += 1;
-
-	if ($hoh_pbsnodes{$node}{"jobs"}){
-	    $number_of_running_jobs++;
-	    my ( @comma ) = ($hoh_pbsnodes{$node}{"jobs"}=~ /,/g);
-	    $number_of_running_jobs += @comma;
-	} 
+        if ($hoh_pbsnodes{$node}{"jobs"}){
+            $number_of_running_jobs++;
+            my ( @comma ) = ($hoh_pbsnodes{$node}{"jobs"}=~ /,/g);
+            $number_of_running_jobs += @comma;
+        }
     }      
 
+    # form LRMS cpudistribution string
     for (my $i=0; $i<=$#cpudist; $i++) {
-	next unless ($cpudist[$i]);  
-	$lrms_cluster{cpudistribution} .= " ".$i."cpu:".$cpudist[$i];
+        next unless ($cpudist[$i]);  
+        $lrms_cluster{cpudistribution} .= " ".$i."cpu:".$cpudist[$i];
     }
 
     # read the qstat -n information about all jobs
     # queued cpus, total number of cpus in all jobs
-
     $lrms_cluster{usedcpus} = 0;
     $lrms_cluster{queuedcpus} = 0;
     $lrms_cluster{queuedjobs} = 0;
@@ -412,19 +452,24 @@ sub cluster_info ($) {
 
     my %qstat_jobs = read_qstat_f($path);
 
-    for my $key (keys %qstat_jobs){
-	if ( $qstat_jobs{$key}{job_state} =~ /R/){
-	    my $count;
-	    $lrms_cluster{runningjobs}++;
-	    ++$count while ( $qstat_jobs{$key}{exec_host} =~ /\//g);
-	    $lrms_cluster{usedcpus}+=$count;
-	}
-	if ( $qstat_jobs{$key}{job_state} =~ /(W|T|Q)/){
-        $lrms_cluster{queuedjobs}++;
-        $lrms_cluster{queuedcpus}+=count_usedcpus($qstat_jobs{$key}{"Resource_List.select"},
-						  $qstat_jobs{$key}{"Resource_List.nodes"},
-						  $qstat_jobs{$key}{"Resource_List.ncpus"});
-	}
+    for my $key (keys %qstat_jobs) {
+        # usercpus (running jobs)
+        if ( $qstat_jobs{$key}{job_state} =~ /R/) {
+            $lrms_cluster{runningjobs}++;
+            my @nodes = split_hostlist($qstat_jobs{$key}{exec_host});
+            # filter using dedicated_node_string
+            foreach my $node ( @nodes ) {
+                next unless defined $available_nodes{$node};
+                $lrms_cluster{usedcpus}++;
+            }
+        }
+        # 
+        if ( $qstat_jobs{$key}{job_state} =~ /(W|T|Q)/) {
+            $lrms_cluster{queuedjobs}++;
+            $lrms_cluster{queuedcpus}+=count_usedcpus($qstat_jobs{$key}{"Resource_List.select"},
+                    $qstat_jobs{$key}{"Resource_List.nodes"},
+                    $qstat_jobs{$key}{"Resource_List.ncpus"});
+        }
     }
 
     # Names of all LRMS queues
@@ -499,9 +544,26 @@ sub queue_info ($$) {
         undef $singledqueue;
     }
 
-    my (%keywords) = ( 'max_running' => 'maxrunning',
-		       'max_user_run' => 'maxuserrun',
-		       'max_queuable' => 'maxqueuable' );
+    # publish queue limits parameters
+    # general limits (publish as is)
+    my (%keywords);
+    my (%keywords_all) = ( 'max_running' => 'maxrunning',
+		           'max_user_run' => 'maxuserrun',
+		           'max_queuable' => 'maxqueuable' );
+
+    # TODO: MinSlots, etc.
+    my (%keywords_torque) = ( 'resources_max.procct' => 'MaxSlotsPerJob' );
+
+    my (%keywords_pbspro) = ( 'resources_max.ncpus' => 'MaxSlotsPerJob' );
+
+    get_pbs_version($config);
+    if ( $lrms_type eq "torque" ) {
+        %keywords = (%keywords_all, %keywords_torque);
+    } elsif ( $lrms_type eq "pbspro" ) {
+        %keywords = (%keywords_all, %keywords_pbspro);
+    } else {
+        %keywords = %keywords_all;
+    }
 
     foreach my $k (keys %keywords) {
 	if (defined $qstat{$k} ) {
@@ -511,6 +573,7 @@ sub queue_info ($$) {
 	}
     }
 
+    # queue time limits (convert to minutes)
     %keywords = ( 'resources_max.cput' => 'maxcputime',
 		  'resources_min.cput' => 'mincputime',
 		  'resources_default.cput' => 'defaultcput',
@@ -520,8 +583,7 @@ sub queue_info ($$) {
 
     foreach my $k (keys %keywords) {
 	if ( defined $qstat{$k} ) {
-	    my @time=split(":",$qstat{$k});
-	    $lrms_queue{$keywords{$k}} = ($time[0]*60+$time[1]+($k eq 'resources_min.cput'?1:0));
+	    $lrms_queue{$keywords{$k}} = (&count_time($qstat{$k})+($k eq 'resources_min.cput'?1:0));
 	} else {
 	    $lrms_queue{$keywords{$k}} = "";
 	}
@@ -560,7 +622,7 @@ sub queue_info ($$) {
 	# refresh routing queue records, in case something changed on the
 	# destination queues
 	if ($qstat{queue_type} =~ /Route/) {
-	    debug("For the 2nd time, queue type is $qstat{queue_type}");
+	    debug("CPUs calculation pass. Queues are scanned a second time. Current queue is: $qstat{queue_type}");
 	    %dqueues = process_dqueues($qname,$path,\%qstat);
 	    # this variable contains the single destination queue
 	    $singledqueue = ( keys %dqueues )[0];
@@ -578,11 +640,24 @@ sub queue_info ($$) {
 	    # $singledqueue check has been added for routing queue support,
 	    # also the destination queue is checked to calculate totalcpus
             # also adds correct behaviour for queue_node_string
-	    if ( ! defined $hoh_pbsnodes{$node}{'properties'} || 
-		 ($hoh_pbsnodes{$node}{'properties'} =~ m/^([^,]+,)*$qname(,[^,]+)*$/ ||
-		  $hoh_pbsnodes{$node}{"properties"} =~ m/^([^,]+,)*$$config{dedicated_node_string}(,[^,]+)*$/ ||
-		  $hoh_pbsnodes{$node}{"properties"} =~ m/^([^,]+,)*$$config{queue_node_string}(,[^,]+)*$/ ||
-		  ( defined $singledqueue && $hoh_pbsnodes{$node}{"properties"} =~ m/^([^,]+,)*$singledqueue(,[^,]+)*$/) ) ){
+	    if (
+	      ( ! defined $hoh_pbsnodes{$node}{'properties'}
+	      ) || (
+	        (   
+		    defined $qname &&
+		    $hoh_pbsnodes{$node}{'properties'} =~ m/^([^,]+,)*$qname(,[^,]+)*$/
+	        ) || (
+		    defined $$config{dedicated_node_string} &&
+		    $hoh_pbsnodes{$node}{'properties'} =~ m/^([^,]+,)*$$config{dedicated_node_string}(,[^,]+)*$/
+	        ) || (
+		    defined $$config{queue_node_string} &&
+		    $hoh_pbsnodes{$node}{'properties'} =~ m/^([^,]+,)*$$config{queue_node_string}(,[^,]+)*$/
+	        ) || (
+		    defined $singledqueue &&
+		    $hoh_pbsnodes{$node}{'properties'} =~ m/^([^,]+,)*$singledqueue(,[^,]+)*$/
+	        )
+	      )
+	    ) {
 		my $cpus;
 
 		next if $hoh_pbsnodes{$node}{'state'} =~ m/offline/;
@@ -601,7 +676,7 @@ sub queue_info ($$) {
 	}
 	$lrms_queue{totalcpus} = $torque_totalcpus;
 
-	debug($lrms_queue{totalcpus});
+	debug("Totalcpus for all queues are: $lrms_queue{totalcpus}");
 
 	if(defined $$config{totalcpus}){
 	    if ($lrms_queue{totalcpus} eq "" or $$config{totalcpus} < $lrms_queue{totalcpus}) {
@@ -636,6 +711,9 @@ sub queue_info ($$) {
 	    $lrms_queue{queued}=0;
 	}
 
+        # fallback for defult values that are required for normal operation
+        $lrms_queue{MaxSlotsPerJob} = $lrms_queue{totalcpus} if $lrms_queue{MaxSlotsPerJob} eq "";
+
  	# calculate queued in case of a routing queue
         # queued jobs is the sum of jobs queued in the routing queue
         # plus jobs in the destination queue
@@ -732,8 +810,7 @@ sub jobs_info ($$@) {
 		}
 	    }
 	} elsif ( defined $tkeywords{$k} ) {
-	    my ( @t ) = split ':',$v;
-	    $lrms_jobs{$jid}{$tkeywords{$k}} = $t[0]*60+$t[1];
+	    $lrms_jobs{$jid}{$tkeywords{$k}} = &count_time($v);
 	} elsif ( defined $nkeywords{$k} ) {
 	    $lrms_jobs{$jid}{$k} = $v;
 	} elsif ( $k eq 'exec_host' ) {
@@ -896,15 +973,12 @@ sub users_info($$@) {
 	}
         # added to support routing queues
         if (!$acl_user_enable){
-	    if ($line =~ /\s*route_destinations\s=\s(.*)$/) {
-		@dqueues=split (',',$1);
-		$singledqueue=shift(@dqueues);
-		debug('local user acl taken from destination queue: '.$singledqueue);
-		$isrouting = 1;
-	    } else {
-		undef @dqueues;
-		undef $singledqueue;
-	    }
+	      if ($line =~ /\s*route_destinations\s=\s(.*)$/) {
+		    @dqueues=split (',',$1);
+		    $singledqueue=shift(@dqueues);
+		    warning('Routing queue did not have acl information. Local user acl taken from destination queue: '.$singledqueue);
+		    $isrouting = 1;
+	      }
         }
     }
     close QSTATOUTPUT;
@@ -914,7 +988,7 @@ sub users_info($$@) {
     # we proceed same way as before but on the first
     # destination queue to propagate the info to the routing one
     if ($isrouting){
-        debug('Getting acl from destination queue');
+        debug("Getting acl from destination queue $singledqueue");
         # Check that users have access to the queue
         unless (open QSTATOUTPUT,   "$path/qstat -f -Q $singledqueue 2>/dev/null |") {
 	    error("Error in executing qstat on destination queue: $path/qstat -f -Q $singledqueue");
@@ -1001,9 +1075,7 @@ sub users_info($$@) {
 		    last;
 		}
 		if ($line =~ /(\d+).+available for\s+([\w:]+)/) {
-		    my @tmp= reverse split /:/, $2;
-		    my $minutes=$tmp[1] + 60*$tmp[2] + 24*60*$tmp[3];
-		    $maui_freecpus .= " ".$1.":".$minutes;
+		    $maui_freecpus .= " ".$1.":".&count_time($2);
 		}
 		if ($line =~ /(\d+).+available with no timelimit/) {  	    
 		    $maui_freecpus.= " ".$1;
