@@ -1,5 +1,11 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <cstring>
 
+#include <arc/ws-addressing/WSA.h>
+
 #include "tools.h"
 
 namespace ARex {
@@ -64,10 +70,13 @@ namespace ARex {
     return state;
   }
 
-  void convertActivityStatusES(const std::string& gm_state,std::string& primary_state,std::list<std::string>& state_attributes,bool failed,bool pending) {
+  void convertActivityStatusES(const std::string& gm_state,std::string& primary_state,std::list<std::string>& state_attributes,bool failed,bool pending,const std::string& failedstate,const std::string& failedcause) {
+    bool failed_set = false;
+    bool canceled = (failedcause == "client");
     primary_state = "";
     if(gm_state == "ACCEPTED") {
       primary_state="ACCEPTED";
+      state_attributes.push_back("CLIENT-STAGEIN-POSSIBLE");
     } else if(gm_state == "PREPARING") {
       primary_state="PREPROCESSING";
       state_attributes.push_back("CLIENT-STAGEIN-POSSIBLE");
@@ -88,20 +97,34 @@ namespace ARex {
       state_attributes.push_back("CLIENT-STAGEOUT-POSSIBLE");
     } else if(gm_state == "DELETED") {
       primary_state="TERMINAL";
-      state_attributes.push_back("CLIENT-STAGEOUT-POSSIBLE");
+      state_attributes.push_back("EXPIRED");
     } else if(gm_state == "CANCELING") {
       primary_state="PROCESSING";
     };
+    if(failedstate == "ACCEPTED") {
+      state_attributes.push_back("VALIDATION-FAILURE");
+      failed_set = true;
+    } else if(failedstate == "PREPARING") {
+      state_attributes.push_back(canceled?"PREPROCESSING-CANCEL":"PREPROCESSING-FAILURE");
+      failed_set = true;
+    } else if(failedstate == "SUBMIT") {
+      state_attributes.push_back(canceled?"PROCESSING-CANCEL":"PROCESSING-FAILURE");
+      failed_set = true;
+    } else if(failedstate == "INLRMS") {
+      state_attributes.push_back(canceled?"PROCESSING-CANCEL":"PROCESSING-FAILURE");
+      // Or maybe APP-FAILURE
+      failed_set = true;
+    } else if(failedstate == "FINISHING") {
+      state_attributes.push_back(canceled?"POSTPROCESSING-CANCEL":"POSTPROCESSING-FAILURE");
+      failed_set = true;
+    } else if(failedstate == "FINISHED") {
+    } else if(failedstate == "DELETED") {
+    } else if(failedstate == "CANCELING") {
+    };
     if(primary_state == "TERMINAL") {
-      if(failed) {
-        //state_attributes.push_back("PREPROCESSING-CANCEL"); TODO
-        //state_attributes.push_back("PROCESSING-CANCEL"); TODO
-        //state_attributes.push_back("POSTPROCESSING-CANCEL"); TODO
-        //state_attributes.push_back("VALIDATION-FAILURE"); TODO
-        //state_attributes.push_back("PREPROCESSING-FAILURE"); TODO
-        //state_attributes.push_back("PROCESSING-FAILURE"); TODO
-        //state_attributes.push_back("POSTPROCESSING-FAILURE"); TODO
-        state_attributes.push_back("APP-FAILURE"); // TODO
+      if(failed && !failed_set) {
+        // Must put something to mark job failed
+        state_attributes.push_back("APP-FAILURE");
       };
     };
     if(!primary_state.empty()) {
@@ -109,11 +132,11 @@ namespace ARex {
     };
   }
 
-  Arc::XMLNode addActivityStatusES(Arc::XMLNode pnode,const std::string& gm_state,Arc::XMLNode glue_xml,bool failed,bool pending) {
+  Arc::XMLNode addActivityStatusES(Arc::XMLNode pnode,const std::string& gm_state,Arc::XMLNode glue_xml,bool failed,bool pending,const std::string& failedstate,const std::string& failedcause) {
     std::string primary_state;
     std::list<std::string> state_attributes;
     std::string glue_state("");
-    convertActivityStatusES(gm_state,primary_state,state_attributes,failed,pending);
+    convertActivityStatusES(gm_state,primary_state,state_attributes,failed,pending,failedstate,failedcause);
     Arc::XMLNode state = pnode.NewChild("estypes:ActivityStatus");
     state.NewChild("estypes:Status") = primary_state;
     for(std::list<std::string>::iterator st = state_attributes.begin();
@@ -123,5 +146,84 @@ namespace ARex {
     return state;
   }
 
+  JobIDGeneratorARC::JobIDGeneratorARC(const std::string& endpoint):endpoint_(endpoint) {
+  }
+
+  void JobIDGeneratorARC::SetLocalID(const std::string& id) {
+    id_ = id;
+  }
+
+  Arc::XMLNode JobIDGeneratorARC::GetGlobalID(Arc::XMLNode& pnode) {
+    Arc::XMLNode node;
+    if(!pnode) {
+      Arc::NS ns;
+      ns["bes-factory"]="http://schemas.ggf.org/bes/2006/08/bes-factory";
+      ns["a-rex"]="http://www.nordugrid.org/schemas/a-rex";
+      Arc::XMLNode(ns,"bes-factory:ActivityIdentifier").Exchange(pnode);
+      node = pnode;
+    } else {
+      node = pnode.NewChild("bes-factory:ActivityIdentifier");
+    };
+    Arc::WSAEndpointReference identifier(node);
+    // Make job's ID
+    identifier.Address(endpoint_); // address of service
+    identifier.ReferenceParameters().NewChild("a-rex:JobID")=id_;
+    identifier.ReferenceParameters().NewChild("a-rex:JobSessionDir")=endpoint_+"/"+id_;
+    return node;
+  }
+
+  std::string JobIDGeneratorARC::GetGlobalID(void) {
+    Arc::XMLNode node;
+    GetGlobalID(node);
+    std::string jobid;
+    node.GetDoc(jobid);
+    std::string::size_type p = 0;
+    // squeeze into 1 line
+    while((p=jobid.find_first_of("\r\n",p)) != std::string::npos) jobid.replace(p,1," ");
+    return jobid;
+  }
+
+  std::string JobIDGeneratorARC::GetManager(void) {
+    return endpoint_;
+  }
+
+  std::string JobIDGeneratorARC::GetInterface(void) {
+    return "org.nordugrid.xbes";
+  }
+
+  JobIDGeneratorES::JobIDGeneratorES(const std::string& endpoint):endpoint_(endpoint) {
+  }
+
+  void JobIDGeneratorES::SetLocalID(const std::string& id) {
+    id_ = id;
+  }
+
+  Arc::XMLNode JobIDGeneratorES::GetGlobalID(Arc::XMLNode& pnode) {
+    Arc::XMLNode node;
+    if(!pnode) {
+      Arc::NS ns;
+      ns["estypes"]="http://www.eu-emi.eu/es/2010/12/types";
+      Arc::XMLNode(ns,"estypes:ActivityID").Exchange(pnode);
+      node = pnode;
+    } else {
+      node = pnode.NewChild("estypes:ActivityID");
+    };
+    node = id_;
+    return node;
+  }
+
+  std::string JobIDGeneratorES::GetGlobalID(void) {
+    return id_;
+  }
+
+  std::string JobIDGeneratorES::GetManager(void) {
+    return endpoint_;
+  }
+
+  std::string JobIDGeneratorES::GetInterface(void) {
+    return "org.ogf.emies";
+  }
+
+
 }
 
