@@ -1,5 +1,6 @@
 #include <sys/stat.h>
 #include <errno.h>
+#include <unistd.h>
 
 #include <arc/credential/Credential.h>
 #include <arc/data/FileCache.h>
@@ -19,7 +20,7 @@
 // A-REX includes for configuration and running downloader
 #include "../a-rex/grid-manager/conf/conf_file.h"
 #include "../a-rex/grid-manager/log/job_log.h"
-#include "../a-rex/grid-manager/jobs/states.h"
+#include "../a-rex/grid-manager/jobs/job_config.h"
 #include "../a-rex/grid-manager/files/info_types.h"
 #include "../a-rex/grid-manager/files/info_files.h"
 #include "../a-rex/grid-manager/run/run_parallel.h"
@@ -33,7 +34,7 @@ static Arc::Plugin *get_service(Arc::PluginArgument* arg)
     Arc::ServicePluginArgument* srvarg =
             arg?dynamic_cast<Arc::ServicePluginArgument*>(arg):NULL;
     if(!srvarg) return NULL;
-    CacheService* s = new CacheService((Arc::Config*)(*srvarg));
+    CacheService* s = new CacheService((Arc::Config*)(*srvarg),arg);
     if (*s)
       return s;
     delete s;
@@ -42,13 +43,14 @@ static Arc::Plugin *get_service(Arc::PluginArgument* arg)
 
 Arc::Logger CacheService::logger(Arc::Logger::rootLogger, "CacheService");
 
-CacheService::CacheService(Arc::Config *cfg) : RegisteredService(cfg),
+CacheService::CacheService(Arc::Config *cfg, Arc::PluginArgument* parg) :
+                                               RegisteredService(cfg,parg),
                                                max_downloads(10),
                                                current_downloads(0),
                                                users(NULL),
                                                gm_env(NULL),
-                                               jcfg(NULL),
-                                               valid(false) {
+                                               jcfg(NULL) {
+  valid = false;
   // read configuration information
   /*
   cacheservice config specifies A-REX conf file
@@ -84,8 +86,10 @@ CacheService::CacheService(Arc::Config *cfg) : RegisteredService(cfg),
   // read A-REX config
   // user running this service
   Arc::User u;
-  JobUser my_user(*gm_env);
-  if (!configure_serviced_users(*users, u.get_uid(), u.Name(), my_user)) {
+  JobUser my_user(*gm_env, u.Name());
+  bool enable_arc = false;
+  bool enable_emies = false;
+  if (!configure_serviced_users(*users, my_user, enable_arc, enable_emies)) {
     logger.msg(Arc::ERROR, "Failed to process A-REX configuration in %s", gm_env->nordugrid_config_loc());
     return;
   }
@@ -420,7 +424,7 @@ Arc::MCC_Status CacheService::CacheLink(Arc::XMLNode in, Arc::XMLNode out,
   Arc::UserConfig usercfg;
   usercfg.UtilsDirPath(user.ControlDir());
   usercfg.ProxyPath(proxy_path);
-  usercfg.InitializeCredentials();
+  usercfg.InitializeCredentials(Arc::initializeCredentialsType::NotTryCredentials);
   std::string dn;
   Arc::Time exp_time;
   try {
