@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <sys/stat.h>
 
 #include <arc/message/MessageAttributes.h>
@@ -18,7 +22,7 @@ namespace DataStaging {
     Arc::ServicePluginArgument* srvarg =
             arg?dynamic_cast<Arc::ServicePluginArgument*>(arg):NULL;
     if(!srvarg) return NULL;
-    DataDeliveryService* s = new DataDeliveryService((Arc::Config*)(*srvarg));
+    DataDeliveryService* s = new DataDeliveryService((Arc::Config*)(*srvarg),arg);
     if (*s)
       return s;
     delete s;
@@ -43,67 +47,64 @@ namespace DataStaging {
       Arc::Time timelimit(Arc::Time()-Arc::Period(3600));
 
       active_dtrs_lock.lock();
-      for (std::map<DTR*, std::stringstream*>::iterator i = active_dtrs.begin();
-           i != active_dtrs.end(); ++i) {
+      for (std::map<DTR_ptr, sstream_ptr>::iterator i = active_dtrs.begin();
+           i != active_dtrs.end();) {
 
-        DTR* dtr = i->first;
+        DTR_ptr dtr = i->first;
 
         if (dtr->get_modification_time() < timelimit && dtr->get_status() != DTRStatus::TRANSFERRING) {
           archived_dtrs_lock.lock();
           if (dtr->error()) {
             logger.msg(Arc::VERBOSE, "Archiving DTR %s, state ERROR", dtr->get_id());
-            archived_dtrs[dtr->get_id()] = std::pair<std::string, std::string>("ERROR", dtr->get_error_status().GetDesc());
+            archived_dtrs[dtr->get_id()] = std::pair<std::string, std::string>("TRANSFER_ERROR", dtr->get_error_status().GetDesc());
           }
           else {
             logger.msg(Arc::VERBOSE, "Archiving DTR %s, state %s", dtr->get_id(), dtr->get_status().str());
-            archived_dtrs[dtr->get_id()] = std::pair<std::string, std::string>(dtr->get_status().str(), "");
+            archived_dtrs[dtr->get_id()] = std::pair<std::string, std::string>("TRANSFERRED", "");
           }
           archived_dtrs_lock.unlock();
-          // clean up DTR memory - delete DTR Logger and LogDestinations
-          cleanDTR(i->first);
-          delete i->second;
-          active_dtrs.erase(i);
+          // clean up DTR memory - delete DTR LogDestinations
+          if (dtr->get_logger()) dtr->get_logger()->deleteDestinations();
+          active_dtrs.erase(i++);
         }
+        else ++i;
       }
       active_dtrs_lock.unlock();
     }
 
   }
 
-  void DataDeliveryService::cleanDTR(DTR* dtr) {
-    if (!dtr) return;
-
-    if (dtr->get_logger()) {
-      dtr->get_logger()->deleteDestinations();
-      delete dtr->get_logger();
-    }
-    delete dtr;
-    dtr = NULL;
-  }
-
-  bool DataDeliveryService::CheckInput(const std::string& url, const Arc::UserConfig& usercfg) {
+  bool DataDeliveryService::CheckInput(const std::string& url, const Arc::UserConfig& usercfg, Arc::XMLNode& resultelement) {
 
     Arc::DataHandle h(url, usercfg);
     if (!h || !(*h)) {
-      logger.msg(Arc::ERROR, "Can't handle url %s", url);
+      resultelement.NewChild("ErrorDescription") = "Can't handle URL " + url;
       return false;
     }
     if (h->Local()) {
-      // TODO only access to session and cache should be allowed
-      if (h->GetURL().Path().find("../") != std::string::npos) {
-        logger.msg(Arc::ERROR, "'../' is not allowed in filename");
+      std::string path(h->GetURL().Path());
+      if (path.find("../") != std::string::npos) {
+        resultelement.NewChild("ErrorDescription") = "'../' is not allowed in filename";
+        return false;
+      }
+      bool allowed = false;
+      for (std::list<std::string>::iterator i = allowed_dirs.begin(); i != allowed_dirs.end(); ++i) {
+        if (path.find(*i) == 0) allowed = true;
+      }
+      if (!allowed) {
+        resultelement.NewChild("ErrorDescription") = "Access denied to path " + path;
         return false;
       }
     }
     return true;
   }
 
-  void DataDeliveryService::receiveDTR(DTR& dtr) {
+  void DataDeliveryService::receiveDTR(DTR_ptr dtr) {
     // note: logger doesn't work here - to fix
-    logger.msg(Arc::INFO, "Received DTR %s in state %s", dtr.get_id(), dtr.get_status().str());
+    logger.msg(Arc::INFO, "Received DTR %s in state %s", dtr->get_id(), dtr->get_status().str());
 
     // delete temp proxy file
-    std::string proxy_file(tmp_proxy_dir+"/DTR."+dtr.get_id()+".proxy");
+    std::string proxy_file(tmp_proxy_dir+"/DTR."+dtr->get_id()+".proxy");
     logger.msg(Arc::DEBUG, "Removing temp proxy %s", proxy_file);
     if (unlink(proxy_file.c_str()) && errno != ENOENT) {
       logger.msg(Arc::WARNING, "Failed to remove temporary proxy %s: %s", proxy_file, Arc::StrError(errno));
@@ -184,28 +185,30 @@ namespace DataStaging {
       Arc::XMLNode resultelement = results.NewChild("Result");
       resultelement.NewChild("ID") = dtrid;
 
-      if (!CheckInput(src, usercfg)) {
+      if (!CheckInput(src, usercfg, resultelement)) {
         resultelement.NewChild("ResultCode") = "SERVICE_ERROR";
-        resultelement.NewChild("ErrorDescription") = "Bad input for source";
+        resultelement["ErrorDescription"] = (std::string)resultelement["ErrorDescription"] + ": Cannot use source";
+        logger.msg(Arc::ERROR, (std::string)resultelement["ErrorDescription"]);
         continue;
       }
 
-      if (!CheckInput(dest, usercfg)) {
+      if (!CheckInput(dest, usercfg, resultelement)) {
         resultelement.NewChild("ResultCode") = "SERVICE_ERROR";
-        resultelement.NewChild("ErrorDescription") = "Bad input for destination";
-        continue;
+        resultelement["ErrorDescription"] = (std::string)resultelement["ErrorDescription"] + ": Cannot use destination";
+        logger.msg(Arc::ERROR, (std::string)resultelement["ErrorDescription"]);
+       continue;
       }
 
       if (current_processes >= max_processes) {
         logger.msg(Arc::WARNING, "All %u process slots used", max_processes);
         resultelement.NewChild("ResultCode") = "SERVICE_ERROR";
         resultelement.NewChild("ErrorDescription") = "No free process slot available";
-        continue;
+       continue;
       }
 
       // check if dtrid is in the active list - if so it is probably a retry
       active_dtrs_lock.lock();
-      std::map<DTR*, std::stringstream*>::iterator i = active_dtrs.begin();
+      std::map<DTR_ptr, sstream_ptr>::iterator i = active_dtrs.begin();
 
       for (; i != active_dtrs.end(); ++i) {
         if (i->first->get_id() == dtrid) break;
@@ -220,8 +223,7 @@ namespace DataStaging {
         }
         // Erase this DTR from active list
         logger.msg(Arc::VERBOSE, "Replacing DTR %s in state %s with new request", dtrid, i->first->get_status().str());
-        cleanDTR(i->first);
-        delete i->second;
+        if (i->first->get_logger()) i->first->get_logger()->deleteDestinations();
         active_dtrs.erase(i);
       }
       active_dtrs_lock.unlock();
@@ -232,7 +234,12 @@ namespace DataStaging {
       std::string proxy_file(tmp_proxy_dir+"/DTR."+dtrid+".proxy");
       logger.msg(Arc::VERBOSE, "Storing temp proxy at %s", proxy_file);
 
-      if (!Arc::FileCreate(proxy_file, credential)) {
+      bool proxy_result = Arc::FileCreate(proxy_file, credential);
+      if (!proxy_result && errno == ENOENT) {
+        Arc::DirCreate(tmp_proxy_dir, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH, true);
+        proxy_result = Arc::FileCreate(proxy_file, credential);
+      }
+      if (!proxy_result) {
         logger.msg(Arc::ERROR, "Failed to create temp proxy at %s: %s", proxy_file, Arc::StrError(errno));
         resultelement.NewChild("ResultCode") = "SERVICE_ERROR";
         resultelement.NewChild("ErrorDescription") = "Failed to store temporary proxy";
@@ -252,19 +259,23 @@ namespace DataStaging {
       // back to the client. LogStream keeps a reference to the stream so we
       // cannot delete it until deleting LogStream. These pointers are
       // deleted when the DTR is archived.
-      std::stringstream * stream = new std::stringstream();
+      sstream_ptr stream(new std::stringstream());
       Arc::LogDestination * output = new Arc::LogStream(*stream);
-      Arc::Logger * log = new Arc::Logger(Arc::Logger::getRootLogger(), "DataStaging");
+      DTRLogger log(new Arc::Logger(Arc::Logger::getRootLogger(), "DataStaging"));
       log->removeDestinations();
       log->addDestination(*output);
 
       std::string groupid(Arc::UUID());
 
-      DTR * dtr = new DTR(src, dest, usercfg, groupid, uid, log);
+      DTR_ptr dtr(new DTR(src, dest, usercfg, groupid, uid, log));
       if (!(*dtr)) {
         logger.msg(Arc::ERROR, "Invalid DTR");
         resultelement.NewChild("ResultCode") = "SERVICE_ERROR";
         resultelement.NewChild("ErrorDescription") = "Could not create DTR";
+        log->deleteDestinations();
+        if (unlink(proxy_file.c_str()) && errno != ENOENT) {
+          logger.msg(Arc::WARNING, "Failed to remove temporary proxy %s: %s", proxy_file, Arc::StrError(errno));
+        }
         continue;
       }
       ++current_processes;
@@ -287,7 +298,7 @@ namespace DataStaging {
       dtr->set_id(dtrid);
       dtr->set_status(DTRStatus::TRANSFER);
 
-      dtr->push(DELIVERY);
+      DTR::push(dtr, DELIVERY);
 
       // Add to active list
       active_dtrs_lock.lock();
@@ -342,7 +353,7 @@ namespace DataStaging {
       resultelement.NewChild("ID") = dtrid;
 
       active_dtrs_lock.lock();
-      std::map<DTR*, std::stringstream*>::iterator dtr_it = active_dtrs.begin();
+      std::map<DTR_ptr, sstream_ptr>::iterator dtr_it = active_dtrs.begin();
       for (; dtr_it != active_dtrs.end(); ++dtr_it) {
         if (dtr_it->first->get_id() == dtrid) break;
       }
@@ -368,18 +379,18 @@ namespace DataStaging {
         continue;
       }
 
-      DTR * dtr = dtr_it->first;
+      DTR_ptr dtr = dtr_it->first;
       resultelement.NewChild("Log") = dtr_it->second->str();
       resultelement.NewChild("BytesTransferred") = Arc::tostring(dtr->get_bytes_transferred());
 
       if (dtr->error()) {
-        logger.msg(Arc::INFO, "DTR %s failed", dtrid);
+        logger.msg(Arc::INFO, "DTR %s failed: %s", dtrid, dtr->get_error_status().GetDesc());
         resultelement.NewChild("ResultCode") = "TRANSFER_ERROR";
         resultelement.NewChild("ErrorDescription") = dtr->get_error_status().GetDesc();
         resultelement.NewChild("ErrorStatus") = Arc::tostring(dtr->get_error_status().GetErrorStatus());
         resultelement.NewChild("ErrorLocation") = Arc::tostring(dtr->get_error_status().GetErrorLocation());
         archived_dtrs_lock.lock();
-        archived_dtrs[dtrid] = std::pair<std::string, std::string>("ERROR", dtr->get_error_status().GetDesc());
+        archived_dtrs[dtrid] = std::pair<std::string, std::string>("TRANSFER_ERROR", dtr->get_error_status().GetDesc());
         archived_dtrs_lock.unlock();
       }
       else if (dtr->get_status() == DTRStatus::TRANSFERRED) {
@@ -392,15 +403,15 @@ namespace DataStaging {
         archived_dtrs_lock.unlock();
       }
       else {
-        logger.msg(Arc::INFO, "DTR %s still in progress (%lluB transferred)",
+        logger.msg(Arc::VERBOSE, "DTR %s still in progress (%lluB transferred)",
                    dtrid, dtr->get_bytes_transferred());
         resultelement.NewChild("ResultCode") = "TRANSFERRING";
         active_dtrs_lock.unlock();
         return Arc::MCC_Status(Arc::STATUS_OK);
       }
-      // Terminal state -  clean up DTR memory and delete DTR Logger and LogDestinations
-      cleanDTR(dtr);
-      delete dtr_it->second;
+      // Terminal state -  clean up DTR LogDestinations
+      if (dtr->get_logger()) dtr->get_logger()->deleteDestinations();
+      //delete dtr_it->second;
       active_dtrs.erase(dtr_it);
       active_dtrs_lock.unlock();
     }
@@ -446,7 +457,7 @@ namespace DataStaging {
 
       // Check if DTR is still in active list
       active_dtrs_lock.lock();
-      std::map<DTR*, std::stringstream*>::iterator dtr_it = active_dtrs.begin();
+      std::map<DTR_ptr, sstream_ptr>::iterator dtr_it = active_dtrs.begin();
       for (; dtr_it != active_dtrs.end(); ++dtr_it) {
         if (dtr_it->first->get_id() == dtrid) break;
       }
@@ -460,7 +471,7 @@ namespace DataStaging {
       }
       // DTR could be already finished, but report successful cancel anyway
 
-      DTR * dtr = dtr_it->first;
+      DTR_ptr dtr = dtr_it->first;
       if (dtr->get_status() == DTRStatus::TRANSFERRING_CANCEL) {
         active_dtrs_lock.unlock();
         logger.msg(Arc::ERROR, "DTR %s was already cancelled", dtrid);
@@ -486,11 +497,57 @@ namespace DataStaging {
     return Arc::MCC_Status(Arc::STATUS_OK);
   }
 
+  /*
+   Accepts:
+   <DataDeliveryPing/>
 
-  DataDeliveryService::DataDeliveryService(Arc::Config *cfg)
-    : RegisteredService(cfg),
+   Returns:
+   <DataDeliveryPingResponse>
+     <DataDeliveryPingResult>
+       <Result>
+         <ReturnCode>ERROR</ReturnCode>
+         <ErrorDescription>...</ErrorDescription>
+         <AllowedDir>/var/arc/cache</AllowedDir>
+         ...
+       </Result>
+       ...
+     </DataDeliveryPingResult>
+   </DataDeliveryPingResponse>
+   */
+  Arc::MCC_Status DataDeliveryService::Ping(Arc::XMLNode in, Arc::XMLNode out) {
+
+    Arc::XMLNode resultelement = out.NewChild("DataDeliveryPingResponse").NewChild("DataDeliveryPingResult").NewChild("Result");
+    resultelement.NewChild("ResultCode") = "OK";
+
+    for (std::list<std::string>::iterator dir = allowed_dirs.begin(); dir != allowed_dirs.end(); ++dir) {
+      resultelement.NewChild("AllowedDir") = *dir;
+    }
+
+    return Arc::MCC_Status(Arc::STATUS_OK);
+  }
+
+
+  DataDeliveryService::DataDeliveryService(Arc::Config *cfg, Arc::PluginArgument* parg)
+    : RegisteredService(cfg,parg),
       max_processes(100),
       current_processes(0) {
+
+    valid = false;
+    // Check configuration - at least one allowed IP address and dir must be specified
+    if (!(*cfg)["SecHandler"]["PDP"]["Policy"]["Rule"]["Subjects"]["Subject"]) {
+      logger.msg(Arc::ERROR, "Invalid configuration - no allowed IP address specified");
+      return;
+    }
+    if (!(*cfg)["AllowedDir"]) {
+      logger.msg(Arc::ERROR, "Invalid configuration - no allowed dirs specified");
+      return;
+    }
+    for (int n = 0;;++n) {
+      Arc::XMLNode allowed_dir = (*cfg)["AllowedDir"][n];
+      if (!allowed_dir) break;
+      allowed_dirs.push_back((std::string)allowed_dir);
+    }
+
     // Start archival thread
     if (!Arc::CreateThreadFunction(ArchivalThread, this)) {
       logger.msg(Arc::ERROR, "Failed to start archival thread");
@@ -524,6 +581,8 @@ namespace DataStaging {
 
   Arc::MCC_Status DataDeliveryService::process(Arc::Message &inmsg, Arc::Message &outmsg) {
 
+    if (!valid) return make_soap_fault(outmsg, "Service is not valid");
+
     // Check authorization
     if(!ProcessSecHandlers(inmsg, "incoming")) {
       logger.msg(Arc::ERROR, "Unauthorized");
@@ -576,6 +635,10 @@ namespace DataStaging {
       else if (MatchXMLName(op,"DataDeliveryCancel")) {
         result = Cancel(*inpayload, *outpayload);
       }
+      // ping service
+      else if (MatchXMLName(op,"DataDeliveryPing")) {
+        result = Ping(*inpayload, *outpayload);
+      }
       // Delegate credentials. Should be called before making a new request
       else if (delegation.MatchNamespace(*inpayload)) {
         if (!delegation.Process(*inpayload, *outpayload)) {
