@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define GRIDFTP_PLUGIN
 
 #include <sys/vfs.h>
@@ -8,7 +12,6 @@
 #include "../userspec.h"
 #include "../names.h"
 #include "../misc.h"
-#include "../misc/canonical_dir.h"
 #include "../misc/escaped.h"
 
 #include "gaclplugin.h"
