@@ -100,7 +100,7 @@ static void message_send_thread(void *arg) {
        thread_logger.msg(Arc::ERROR, "Empty URL list add to the thread.");
        return;
     }
-    if ( !bool(((ISIS::Thread_data *)data)->node) ) {
+    if ( !bool(data->node) ) {
        thread_logger.msg(Arc::ERROR, "Empty message add to the thread.");
        return;
     }
@@ -111,11 +111,11 @@ static void message_send_thread(void *arg) {
         //Send SOAP message to the neighbor.
         Arc::PayloadSOAP *response = NULL;
         Arc::MCCConfig mcc_cfg;
-        mcc_cfg.AddPrivateKey(((ISIS::Thread_data *)data)->isis_list[i].key);
-        mcc_cfg.AddCertificate(((ISIS::Thread_data *)data)->isis_list[i].cert);
-        mcc_cfg.AddProxy(((ISIS::Thread_data *)data)->isis_list[i].proxy);
-        mcc_cfg.AddCADir(((ISIS::Thread_data *)data)->isis_list[i].cadir);
-        mcc_cfg.AddCAFile(((ISIS::Thread_data *)data)->isis_list[i].cafile);
+        mcc_cfg.AddPrivateKey(data->isis_list[i].key);
+        mcc_cfg.AddCertificate(data->isis_list[i].cert);
+        mcc_cfg.AddProxy(data->isis_list[i].proxy);
+        mcc_cfg.AddCADir(data->isis_list[i].cadir);
+        mcc_cfg.AddCAFile(data->isis_list[i].cafile);
 
         Arc::ClientSOAP client_entry(mcc_cfg, url, 60);
 
@@ -127,7 +127,7 @@ static void message_send_thread(void *arg) {
         message_ns["isis"] = ISIS_NAMESPACE;
         Arc::PayloadSOAP req(message_ns);
 
-        req.NewChild(((ISIS::Thread_data *)data)->node);
+        req.NewChild(data->node);
         Arc::MCC_Status status;
         thread_logger.msg(Arc::VERBOSE, "Sending \"Register/RemoveRegistrations\" message to %s and waiting for the response.", url );
         status= client_entry.process(&req,&response);
@@ -332,7 +332,7 @@ static void soft_state_thread(void *data) {
     }
 }
 
-    ISIService::ISIService(Arc::Config *cfg):RegisteredService(cfg),logger_(Arc::Logger::rootLogger, "ISIS"),valid("PT12H"),remove("PT1D"),db_(NULL),neighbors_update_needed(false),available_provider(false),neighbors_count(0) {
+    ISIService::ISIService(Arc::Config *cfg, Arc::PluginArgument* parg):RegisteredService(cfg,parg),logger_(Arc::Logger::rootLogger, "ISIS"),validity("PT12H"),remove("PT1D"),db_(NULL),neighbors_update_needed(false),available_provider(false),neighbors_count(0) {
 
         logger_.msg(Arc::VERBOSE, "Parsing configuration parameters");
 
@@ -431,12 +431,12 @@ static void soft_state_thread(void *data) {
                 if(validp.GetPeriod() <= 0) {
                     logger_.msg(Arc::ERROR, "Configuration error. ETValid: \"%s\" is not a valid value. Default value will be used.",(std::string)(*cfg)["ETValid"]);
                 } else {
-                    valid.SetPeriod( validp.GetPeriod() );
+                    validity.SetPeriod( validp.GetPeriod() );
                 }
             } else logger_.msg(Arc::ERROR, "Configuration error. ETValid is empty. Default value will be used.");
         } else logger_.msg(Arc::VERBOSE, "ETValid: Default value will be used.");
 
-        logger_.msg(Arc::VERBOSE, "ETValid: %d seconds", valid.GetPeriod());
+        logger_.msg(Arc::VERBOSE, "ETValid: %d seconds", validity.GetPeriod());
 
         // Set up ETRemove if there is any in the configuration
         if ((bool)(*cfg)["ETRemove"]) {
@@ -516,7 +516,7 @@ static void soft_state_thread(void *data) {
         // or not, and if yes, then destroy itself and free the relevant pointer.
         valid_data = new Soft_State();
         valid_data->function = "ETValid";
-        valid_data->sleep = ((int)valid.GetPeriod());
+        valid_data->sleep = ((int)validity.GetPeriod());
         valid_data->query = "//RegEntry/MetaSrcAdv[count(Expiration)=1]/ServiceID";
         valid_data->database = db_;
         valid_data->kill_thread = &KillThread;
@@ -1000,7 +1000,7 @@ static void soft_state_thread(void *data) {
     static Arc::Plugin *get_service(Arc::PluginArgument* arg) {
         Arc::ServicePluginArgument* srvarg = arg?dynamic_cast<Arc::ServicePluginArgument*>(arg):NULL;
         if(!srvarg) return NULL;
-        return new ISIService((Arc::Config*)(*srvarg));
+        return new ISIService((Arc::Config*)(*srvarg),arg);
     }
 
     void ISIService::Neighbors_Update() {
