@@ -31,7 +31,7 @@ namespace ISIS {
             // Configuration parameters
             Arc::Logger logger_;
             std::string endpoint_;
-            Arc::Period valid;
+            Arc::Period validity;
             Arc::Period remove;
             int retry;
             int sparsity;
@@ -90,7 +90,7 @@ namespace ISIS {
 
             
         public:
-            ISIService(Arc::Config *cfg);
+            ISIService(Arc::Config *cfg, Arc::PluginArgument* parg);
             virtual ~ISIService(void);
             virtual Arc::MCC_Status process(Arc::Message &in, Arc::Message &out);
             virtual bool RegistrationCollector(Arc::XMLNode &doc);
