@@ -39,9 +39,12 @@ require_once('cache.inc');
 $order   = @$_GET["order"];
 $display = @$_GET["display"];
 $debug   = @$_GET["debug"];
+$lang    = @$_GET["lang"];
 if ( !$order )   $order   = "country";
 if ( !$display ) $display = "all";
 if ( !$debug )   $debug   = 0; 
+if ( !$lang )    $lang    = "default"; // browser language
+define("FORCE_LANG",$lang);
 
 // Setting up the page itself
 
@@ -60,13 +63,13 @@ $toppage->tabletop("<font face=\"Verdana,Geneva,Arial,Helvetica,sans-serif\">".E
 //********************** Legend - only needed for this module *********************
 echo "<table width=\"100%\" border=\"0\"><tr><td>\n";
 echo "<font size=\"-1\" face=\"Verdana,Geneva,Arial,Helvetica,Sans-serif,lucida\">".$errors["401"].":\n";
-echo "<img src=\"./mon-icons/icon_led.php?c1=204&c2=0&c3=0\" vspace=\"1\" hspace=\"3\" border=\"0\" title=\"".$errors["305"]."\" alt=\"".$errors["305"]."\" width=\"14\" height=\"6\">".$errors["402"]."&nbsp;<img src=\"./mon-icons/icon_led.php?c1=176&c2=176&c3=176\" vspace=\"1\" hspace=\"3\" border=\"0\" title=\"".$errors["306"]."\" alt=\"".$errors["306"]."\">".$errors["403"]."</font>\n";
+echo "<img src=\"./mon-icons/icon_led.php?c1=97&c2=144&c3=0\" vspace=\"1\" hspace=\"3\" border=\"0\" title=\"".$errors["305"]."\" alt=\"".$errors["305"]."\" width=\"14\" height=\"6\">".$errors["402"]."&nbsp;<img src=\"./mon-icons/icon_led.php?c1=176&c2=176&c3=176\" vspace=\"1\" hspace=\"3\" border=\"0\" title=\"".$errors["306"]."\" alt=\"".$errors["306"]."\">".$errors["403"]."</font>\n";
 echo "</td><td>";
-$sewin    = popup("sestat.php",650,200,8);
-$discwin  = popup("discover.php",700,400,9);
-$vostring = popup("volist.php",440,330,11);
-$usstring = popup("allusers.php",650,700,12);
-$acstring = popup("allusers.php?limit=1",500,600,12);
+$sewin    = popup("sestat.php",650,200,8,$lang,$debug);
+$discwin  = popup("discover.php",700,400,9,$lang,$debug);
+$vostring = popup("volist.php",440,330,11,$lang,$debug);
+$usstring = popup("allusers.php",650,700,12,$lang,$debug);
+$acstring = popup("allusers.php?limit=1",500,600,12,$lang,$debug);
 echo "<div align=\"right\"><nobr>\n";
 //******** Authorised users
 echo "<a href=\"$usstring\"><img src=\"./mon-icons/icon-folks.png\" width=\"24\" height=\"24\" border=\"0\" title=\"".$errors["307"]."\" alt=\"".$errors["307"]."\"></a>&nbsp;\n";
@@ -102,8 +105,8 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
 
   // Setting time limits for ldapsearch
 
-  $tlim = 20;
-  $tout = 21;
+  $tlim = 10;
+  $tout = 11;
   if($debug) dbgmsg("<div align=\"left\"><i>:::&gt; ".$errors["101"].$tlim.$errors["102"].$tout.$errors["103"]." &lt;:::</i></div>");
   
   // ldapsearch filter string for clusters and queues
@@ -158,6 +161,7 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
       array_push($dsarray,$clconn);
       array_push($hnarray,$clhost);
       array_push($pnarray,$clport);
+      @ldap_set_option($clconn, LDAP_OPT_NETWORK_TIMEOUT, $tout);
       $sitetag[$clhost] = 1; /* filtering tag */
       if ($debug==2) dbgmsg("$k - <i>$clhost:$clport </i>");
     }
@@ -175,9 +179,9 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
   // Search all clusters and queues
   
   $ts1 = time();
-  $srarray = @ldap_search($dsarray,DN_LOCAL,$filter,$lim,0,0,$tlim,LDAP_DEREF_NEVER);
-  // Fall back to a conventional LDAP
-  //  if (!count($srarray)) $srarray = @ldap_search($dsarray,DN_LOCAL,$filter,$lim,0,0,$tlim);
+    $srarray = @ldap_search($dsarray,DN_LOCAL,$filter,$lim,0,0,$tlim,LDAP_DEREF_NEVER);
+  // If using the patched LDAP
+  //$srarray = @ldap_search($dsarray,DN_LOCAL,$filter,$lim,0,0,$tlim,LDAP_DEREF_NEVER,$tout);
   $ts2 = time(); if($debug) dbgmsg("<br><b>".$errors["109"]." (".($ts2-$ts1).$errors["104"].")</b><br>");
   
   /*  
@@ -247,6 +251,8 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
 	  $vo = guess_country($curname,$entries[$i][CLU_ZIPC][0]);
 	  if ($debug==2) dbgmsg("<i>$ids: <b>$curname</b>".$errors["112"]."$vo</i><br>");
 	  $vostring = $_SERVER['PHP_SELF']."?display=vo=$vo";
+    if ( $lang != "default") $vostring .= "&lang=".$lang;
+    if ( $debug ) $vostring .= "&debug=".$debug;
 	  $country  = $vo;
 	  if ( $yazyk !== "en" ) $country = $strings["tlconvert"][$vo];
 	  
@@ -257,15 +263,16 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
 	  
 	  $curalias   = $entries[$i][CLU_ANAM][0];
 	  
-	  // Manipulate alias: replace the string if necessary and cut off at 22 characters
+	  // Manipulate alias: replace the string if necessary and cut off at 22 characters; strip HTML tags
 	  if (file_exists("cnvalias.inc")) include('cnvalias.inc');
+	  $curalias = strip_tags($curalias);
 	  if ( strlen($curalias) > 22 ) $curalias = substr($curalias,0,21) . ">";
 	  
 	  $curtotjobs = @($entries[$i][CLU_TJOB][0]) ? $entries[$i][CLU_TJOB][0] : 0;
 	  $curusedcpu = @($entries[$i][CLU_UCPU][0]) ? $entries[$i][CLU_UCPU][0] : -1;
 	  $totqueued  = @($entries[$i][CLU_QJOB][0]) ? $entries[$i][CLU_QJOB][0] : 0; /* deprecated since 0.5.38 */
 	  $gmqueued   = @($entries[$i][CLU_PQUE][0]) ? $entries[$i][CLU_PQUE][0] : 0; /* new since 0.5.38 */
-	  $clstring   = popup("clusdes.php?host=$curname&port=$curport",700,620,1);
+    $clstring   = popup("clusdes.php?host=$curname&port=$curport",700,620,1,$lang,$debug);
 	  
 	  $nclu++;
 	  
@@ -318,8 +325,8 @@ if ( !$tcont || $debug || $display != "all" ) { // Do LDAP search
       $gridload  = ($curtotcpu > 0)  ? $gridjobs/$curtotcpu : 0;
       $clusload  = ($curtotcpu > 0)  ? $allrun/$curtotcpu   : 0;
       $tstring   = urlencode("$gridjobs+$localrun");
-      $jrstring  = popup("jobstat.php?host=$curname&port=$curport&status=Running&jobdn=all",600,500,2);
-      $jqstring  = popup("jobstat.php?host=$curname&port=$curport&status=Queueing&jobdn=all",600,500,2);
+      $jrstring  = popup("jobstat.php?host=$curname&port=$curport&status=Running&jobdn=all",600,500,2,$lang,$debug);
+      $jqstring  = popup("jobstat.php?host=$curname&port=$curport&status=Queueing&jobdn=all",600,500,2,$lang,$debug);
       
       if ( $toflag2 ) {
 	$tstring .= " (no queue info)"; // not sure if this is localizeable at all
@@ -450,16 +457,45 @@ $rowcont[] = "<b><i>$sumgridqueued + $sumloclqueued</i></b>";
 $ctable->addrow($rowcont, "#ffffff");
 $ctable->close();
 
+// To change language, link back to ALL
+
+$linkback = $_SERVER['PHP_SELF'];
+if ( $debug ) {
+  $linkback .= "?debug=".$debug;
+  $separator = "&";
+ } else {
+  $separator = "?";
+ }
+
+// Show flags if only one country is chosen
+
 if ( @$showvo ) {
   echo "<br><nobr>\n";
   foreach ( $votolink as $volink ) {
-    $vostring  = $_SERVER['PHP_SELF']."?debug=$debug&display=vo=$volink";
+    $vostring  = $_SERVER['PHP_SELF']."?display=vo=$volink";
+    if ( $lang != "default" ) $vostring .= "&lang=".$lang;
+    if ( $debug ) $vostring .= "&debug=".$debug;
     $voimage   = "<img src=\"./mon-icons/$volink.png\" title=\"".$errors["312"]."$volink\" alt=\"".$errors["312"]."\" height=\"10\" width=\"16\" border=\"0\">";
     echo "<a href=\"$vostring\">$voimage</a>&nbsp;&nbsp;";
   }
-  echo "<a href=\"".$_SERVER['PHP_SELF']."\"><b>".$errors["409"]."</b></a><BR>\n";
+  if ( $lang != "default") $linkall = $linkback.$separator."lang=".$lang;
+  echo "<a href=\"".$linkall."\"><b>".$errors["409"]."</b></a><BR>\n";  // Show ALL
   echo "</nobr>\n";
-}
+ } else {
+
+  // Show languages
+  
+  $translations = scandir(getcwd()."/lang");
+  echo "<center><br><nobr>\n";
+  foreach ( $translations as $transfile ) {
+    $twoletcod = substr($transfile,0,2);
+    if ( stristr($transfile,".") == ".inc" && $twoletcod != "us" ) {
+      $linklang = $linkback.$separator."lang=".$twoletcod;
+      echo "<a href=\"".$linklang."\">$twoletcod</a>&nbsp;&nbsp;";
+    }
+  }
+  echo "</nobr><br></center>\n";
+ }
 
 return 0;
 
